diff --git a/Makefile.am b/Makefile.am
index 811b496..8e2e7c6 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -89,7 +89,7 @@ endif
 # * -z2 - Unix style line endings
 # Also add the -n to make it not save .orig files (we have git for that)
 style:
-	astyle -n -p -b -S -t4 -k3 -z2 `find . -name "*.cpp" -o -name "*.h" | egrep -v "(wx-build|xrcDialogs|pgscript/test)"`
+	astyle -n -p -b -S -t4 -k3 -z2 `find . -name "*.cpp" -o -name "*.h" | egrep -v "(wx-build|xrcDialogs|pgscript/test|pgadmin/libssh2|pgadmin/include/libssh2)"`
 
 # Create HTML docs
 doc:
diff --git a/acinclude.m4 b/acinclude.m4
index e9c5a5d..f161a5e 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -666,7 +666,7 @@ AC_DEFUN([SETUP_POSTGRESQL],
 
 		if test "$PG_SSL" = "yes"
 		then
-			CPPFLAGS="$CPPFLAGS -DSSL"
+			CPPFLAGS="$CPPFLAGS -DPG_SSL"
 		fi
 		if test "$HAVE_CONNINFO_PARSE" = "yes"
 		then
@@ -846,6 +846,146 @@ AC_DEFUN([SETUP_LIBXSLT],
 AC_SUBST(XSLT_CONFIG)
 AC_SUBST(pgadmin3_LDADD)
 
+dnl CURL_CHECK_NONBLOCKING_SOCKET
+dnl -------------------------------------------------
+dnl Check for how to set a socket to non-blocking state. There seems to exist
+dnl four known different ways, with the one used almost everywhere being POSIX
+dnl and XPG3, while the other different ways for different systems (old BSD,
+dnl Windows and Amiga).
+dnl
+dnl There are two known platforms (AIX 3.x and SunOS 4.1.x) where the
+dnl O_NONBLOCK define is found but does not work. This condition is attempted
+dnl to get caught in this script by using an excessive number of #ifdefs...
+dnl
+AC_DEFUN([CURL_CHECK_NONBLOCKING_SOCKET],
+[
+  AC_MSG_CHECKING([non-blocking sockets style])
+
+  AC_TRY_COMPILE([
+/* headers for O_NONBLOCK test */
+#include <sys/types.h>
+#include <unistd.h>
+#include <fcntl.h>
+],[
+/* try to compile O_NONBLOCK */
+
+#if defined(sun) || defined(__sun__) || defined(__SUNPRO_C) || defined(__SUNPRO_CC)
+# if defined(__SVR4) || defined(__srv4__)
+#  define PLATFORM_SOLARIS
+# else
+#  define PLATFORM_SUNOS4
+# endif
+#endif
+#if (defined(_AIX) || defined(__xlC__)) && !defined(_AIX41)
+# define PLATFORM_AIX_V3
+#endif
+
+#if defined(PLATFORM_SUNOS4) || defined(PLATFORM_AIX_V3) || defined(__BEOS__)
+#error "O_NONBLOCK does not work on this platform"
+#endif
+  int socket;
+  int flags = fcntl(socket, F_SETFL, flags | O_NONBLOCK);
+],[
+dnl the O_NONBLOCK test was fine
+nonblock="O_NONBLOCK"
+AC_DEFINE(HAVE_O_NONBLOCK, 1, [use O_NONBLOCK for non-blocking sockets])
+],[
+dnl the code was bad, try a different program now, test 2
+
+  AC_TRY_COMPILE([
+/* headers for FIONBIO test */
+#include <unistd.h>
+#include <stropts.h>
+],[
+/* FIONBIO source test (old-style unix) */
+ int socket;
+ int flags = ioctl(socket, FIONBIO, &flags);
+],[
+dnl FIONBIO test was good
+nonblock="FIONBIO"
+AC_DEFINE(HAVE_FIONBIO, 1, [use FIONBIO for non-blocking sockets])
+],[
+dnl FIONBIO test was also bad
+dnl the code was bad, try a different program now, test 3
+
+  AC_TRY_COMPILE([
+/* headers for ioctlsocket test (Windows) */
+#undef inline
+#ifdef HAVE_WINDOWS_H
+#ifndef WIN32_LEAN_AND_MEAN
+#define WIN32_LEAN_AND_MEAN
+#endif
+#include <windows.h>
+#ifdef HAVE_WINSOCK2_H
+#include <winsock2.h>
+#else
+#ifdef HAVE_WINSOCK_H
+#include <winsock.h>
+#endif
+#endif
+#endif
+],[
+/* ioctlsocket source code */
+ SOCKET sd;
+ unsigned long flags = 0;
+ sd = socket(0, 0, 0);
+ ioctlsocket(sd, FIONBIO, &flags);
+],[
+dnl ioctlsocket test was good
+nonblock="ioctlsocket"
+AC_DEFINE(HAVE_IOCTLSOCKET, 1, [use ioctlsocket() for non-blocking sockets])
+],[
+dnl ioctlsocket didnt compile!, go to test 4
+
+  AC_TRY_LINK([
+/* headers for IoctlSocket test (Amiga?) */
+#include <sys/ioctl.h>
+],[
+/* IoctlSocket source code */
+ int socket;
+ int flags = IoctlSocket(socket, FIONBIO, (long)1);
+],[
+dnl ioctlsocket test was good
+nonblock="IoctlSocket"
+AC_DEFINE(HAVE_IOCTLSOCKET_CASE, 1, [use Ioctlsocket() for non-blocking sockets])
+],[
+dnl Ioctlsocket didnt compile, do test 5!
+  AC_TRY_COMPILE([
+/* headers for SO_NONBLOCK test (BeOS) */
+#include <socket.h>
+],[
+/* SO_NONBLOCK source code */
+ long b = 1;
+ int socket;
+ int flags = setsockopt(socket, SOL_SOCKET, SO_NONBLOCK, &b, sizeof(b));
+],[
+dnl the SO_NONBLOCK test was good
+nonblock="SO_NONBLOCK"
+AC_DEFINE(HAVE_SO_NONBLOCK, 1, [use SO_NONBLOCK for non-blocking sockets])
+],[
+dnl test 5 didnt compile!
+nonblock="nada"
+AC_DEFINE(HAVE_DISABLED_NONBLOCKING, 1, [disabled non-blocking sockets])
+])
+dnl end of fifth test
+
+])
+dnl end of forth test
+
+])
+dnl end of third test
+
+])
+dnl end of second test
+
+])
+dnl end of non-blocking try-compile test
+  AC_MSG_RESULT($nonblock)
+
+  if test "$nonblock" = "nada"; then
+    AC_MSG_WARN([non-block sockets disabled])
+  fi
+])
 #########################
 # Configuration summary #
 #########################
@@ -889,6 +1029,25 @@ AC_DEFUN([SUMMARY],
 		echo "Building Database Designer:		No"
 	fi
 	echo
+	if test "$BUILD_SSH_TUNNEL" = yes
+	then
+		echo "Building SSH Tunnel:			Yes"
+		if test "$ac_cv_libssl" = yes
+		then
+			echo "Crypto library:				openssl= yes libgcrypt= no"
+		else test "$ac_cv_libgcrypt" = yes
+			echo "Crypto library:				openssl= no libgcrypt= yes"
+		fi
+		if test "$ac_cv_libz" = yes
+		then
+			echo "libz compression:			yes"
+		else
+			echo "libz compression:			no"
+		fi
+	else
+		echo "Building SSH Tunnel:			No"
+	fi
+	echo
 	if test "$BUILD_DEBUG" = yes
 	then
 		echo "Building a debug version of pgAdmin:	Yes"
diff --git a/bootstrap b/bootstrap
index dba525f..b5dbb72 100755
--- a/bootstrap
+++ b/bootstrap
@@ -97,5 +97,6 @@ set -x
 
 $ACLOCAL && \
 autoheader && \
+cp -f config.rpath.in config/config.rpath &&  \
 $AUTOMAKE --foreign --add-missing --copy && \
 autoconf
diff --git a/configure.ac.in b/configure.ac.in
index 778c1a3..4cbe726 100644
--- a/configure.ac.in
+++ b/configure.ac.in
@@ -22,6 +22,11 @@ AM_CONDITIONAL([SUN_CXX], [test x$SUN_CXX_COMPILER = xyes])
 # Checks for header files.
 AC_HEADER_STDC
 AC_CHECK_HEADERS([arpa/inet.h netdb.h netinet/in.h stdlib.h])
+AC_CHECK_HEADERS([errno.h fcntl.h stdio.h unistd.h sys/uio.h])
+AC_CHECK_HEADERS([sys/select.h sys/socket.h sys/ioctl.h sys/time.h])
+AC_CHECK_HEADERS([sys/un.h], [have_sys_un_h=yes], [have_sys_un_h=no])
+AM_CONDITIONAL([HAVE_SYS_UN_H], test "x$have_sys_un_h" = xyes)
+AM_CONFIG_HEADER([pgadmin/include/libssh2/libssh2_config.h])
 
 # Checks for typedefs, structures, and compiler characteristics.
 AC_HEADER_STDBOOL
@@ -64,6 +69,72 @@ CHECK_LIBXML2
 LOCATE_LIBXSLT
 SETUP_LIBXSLT
 
+# Configure parameters
+AC_ARG_WITH(libgcrypt,
+	AC_HELP_STRING([--with-libgcrypt],[Use Libgcrypt for crypto]),
+	use_libgcrypt=$withval,use_libgcrypt=auto)
+AC_ARG_WITH(openssl,
+	AC_HELP_STRING([--with-openssl],[Use OpenSSL for crypto]),
+	use_openssl=$withval,use_openssl=auto)
+AC_ARG_WITH(libz,
+	AC_HELP_STRING([--with-libz],[Use Libz for compression]),
+	use_libz=$withval,use_libz=auto)
+
+# Look for OpenSSL (default)
+if test "$use_openssl" != "no" && test "$use_libgcrypt" != "yes"; then
+	AC_LIB_HAVE_LINKFLAGS([ssl], [crypto], [#include <openssl/ssl.h>])
+	LIBSREQUIRED=libssl,libcrypto
+fi
+
+# Look for libgcrypt
+if test "$ac_cv_libssl" != "yes" && test "$use_libgcrypt" != "no"; then
+	AC_LIB_HAVE_LINKFLAGS([gcrypt], [], [#include <gcrypt.h>])
+	LIBSREQUIRED=libgcrypt
+fi
+
+AC_SUBST(LIBSREQUIRED)
+
+if test "$ac_cv_libssl" != "yes" && test "$ac_cv_libgcrypt" != "yes"; then
+	AC_MSG_NOTICE([cannot find OpenSSL or Libgcrypt, try --with-libssl-prefix=PATH or --with-libgcrypt-prefix=PATH])
+	BUILD_SSH_TUNNEL="no"
+else
+	BUILD_SSH_TUNNEL="yes"
+fi
+AM_CONDITIONAL([BUILD_SSH_TUNNEL], [test x$BUILD_SSH_TUNNEL = xyes])
+
+if test "$ac_cv_libssl" = "yes"; then
+	CPPFLAGS="$CPPFLAGS -DHAVE_OPENSSL_CRYPTO"
+	LDFLAGS="$LDFLAGS -lssl -lcrypto"
+fi
+
+if test "$ac_cv_libgcrypt" = "yes"; then
+	CPPFLAGS="$CPPFLAGS -DHAVE_GCRYPT"
+	LDFLAGS="$LDFLAGS -lgcrypt"
+	AC_DEFINE(LIBSSH2_LIBGCRYPT, 1, [Use libgcrypt])
+fi
+AM_CONDITIONAL(LIBGCRYPT, test "$ac_cv_libgcrypt" = "yes")
+
+# Not all OpenSSL have AES-CTR functions.
+if test "$ac_cv_libssl" = "yes"; then
+  save_LDFLAGS="$LDFLAGS"
+  LDFLAGS="$LDFLAGS $LIBSSL"
+  AC_CHECK_FUNCS(EVP_aes_128_ctr)
+  LDFLAGS="$save_LDFLAGS"
+fi
+
+# Look for Libz
+if test "$use_libz" != "no"; then
+  AC_LIB_HAVE_LINKFLAGS([z], [], [#include <zlib.h>])
+  if test "$ac_cv_libz" != yes; then
+    AC_MSG_NOTICE([Cannot find libz, disabling compression])
+    AC_MSG_NOTICE([Try --with-libz-prefix=PATH if you know you have it])
+  else
+    AC_DEFINE(LIBSSH2_HAVE_ZLIB, 1, [Compile in zlib support])
+  fi
+fi
+
+CURL_CHECK_NONBLOCKING_SOCKET
+
 LOCATE_SPHINX
 AM_CONDITIONAL([SPHINX_BUILD], [test x$SPHINX_BUILD != x])
 
diff --git a/pgadmin/Makefile.am b/pgadmin/Makefile.am
index d17bca9..e73819d 100644
--- a/pgadmin/Makefile.am
+++ b/pgadmin/Makefile.am
@@ -49,6 +49,7 @@ include gqb/module.mk
 include hotdraw/module.mk
 include ui/module.mk
 include utils/module.mk
+include libssh2/module.mk
 
 if SUN_CC
   __CFLAGS=""
diff --git a/pgadmin/db/pgConn.cpp b/pgadmin/db/pgConn.cpp
index 3bfb268..2447ac2 100644
--- a/pgadmin/db/pgConn.cpp
+++ b/pgadmin/db/pgConn.cpp
@@ -634,7 +634,7 @@ wxString pgConn::GetName() const
 	return str;
 }
 
-#ifdef SSL
+#ifdef PG_SSL
 // we don't define USE_SSL so we don't get ssl.h included
 extern "C"
 {
diff --git a/pgadmin/dlg/dlgServer.cpp b/pgadmin/dlg/dlgServer.cpp
index 31e84a2..0b2692a 100644
--- a/pgadmin/dlg/dlgServer.cpp
+++ b/pgadmin/dlg/dlgServer.cpp
@@ -53,7 +53,20 @@
 #define pickerSSLRootCert CTRL_FILEPICKER("pickerSSLRootCert")
 #define pickerSSLCrl      CTRL_FILEPICKER("pickerSSLCrl")
 #define chkSSLCompression CTRL_CHECKBOX("chkSSLCompression")
-
+#define nbNotebook        CTRL_NOTEBOOK("nbNotebook")
+
+// SSH Tunnel Tab
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+#define chkSSHTunnel		 CTRL_CHECKBOX("chkSSHTunnel")
+#define txtTunnelHost		 CTRL_TEXT("txtTunnelHost")
+#define txtTunnelUsername	 CTRL_TEXT("txtTunnelUsername")
+#define radioBtnPassword	 CTRL_RADIOBUTTON("radioBtnPassword")
+#define radioBtnKeyfile      CTRL_RADIOBUTTON("radioBtnKeyfile")
+#define txtTunnelPassword	 CTRL_TEXT("txtTunnelPassword")
+#define pickerPublicKeyFile	 CTRL_FILEPICKER("pickerPublicKeyFile")
+#define pickerIdentityFile	 CTRL_FILEPICKER("pickerIdentityFile")
+#define stPublicKeyFile		 CTRL_STATIC("stPublicKeyFile")
+#endif
 
 BEGIN_EVENT_TABLE(dlgServer, dlgProperty)
 	EVT_NOTEBOOK_PAGE_CHANGED(XRCID("nbNotebook"),     dlgServer::OnPageSelect)
@@ -80,6 +93,13 @@ BEGIN_EVENT_TABLE(dlgServer, dlgProperty)
 	EVT_COMBOBOX(XRCID("cbGroup"),                     dlgProperty::OnChange)
 	EVT_CHECKBOX(XRCID("chkSSLCompression"),           dlgProperty::OnChange)
 	EVT_BUTTON(wxID_OK,                                dlgServer::OnOK)
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	EVT_TEXT(XRCID("txtTunnelHost"),                   dlgProperty::OnChange)
+	EVT_TEXT(XRCID("txtTunnelUsername"),               dlgProperty::OnChange)
+	EVT_CHECKBOX(XRCID("chkSSHTunnel"),                dlgServer::OnCheckSSHTunnel)
+	EVT_RADIOBUTTON(XRCID("radioBtnPassword"),         dlgServer::OnChangeAuthOption)
+	EVT_RADIOBUTTON(XRCID("radioBtnKeyfile"),          dlgServer::OnChangeAuthOption)
+#endif
 END_EVENT_TABLE();
 
 
@@ -134,6 +154,25 @@ dlgServer::dlgServer(pgaFactory *f, frmMain *frame, pgServer *node)
 			groupitem = browser->GetNextChild(browser->GetRootItem(), groupcookie);
 		}
 	}
+
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	EnableSSHTunnelControls(false);
+	radioBtnPassword->SetValue(true);
+	radioBtnKeyfile->SetValue(false);
+	txtTunnelPassword->SetMaxLength(SSH_MAX_PASSWORD_LEN);
+#ifdef HAVE_OPENSSL_CRYPTO
+	stPublicKeyFile->Show(false);
+	pickerPublicKeyFile->Show(false);
+#endif
+#else
+	for(size_t i = 0; i < nbNotebook->GetPageCount(); i++)
+	{
+		if(nbNotebook->GetPageText(i).compare(wxT("SSH Tunnel")) == 0)
+		{
+			nbNotebook->RemovePage(i);
+		}
+	}
+#endif
 }
 
 
@@ -197,6 +236,15 @@ void dlgServer::OnOK(wxCommandEvent &ev)
 		server->SetSSLRootCert(pickerSSLRootCert->GetPath());
 		server->SetSSLCrl(pickerSSLCrl->GetPath());
 		server->iSetSSLCompression(chkSSLCompression->GetValue());
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+		server->iSetSSHTunnel(chkSSHTunnel->GetValue());
+		server->SetTunnelHost(txtTunnelHost->GetValue());
+		server->SetTunnelUserName(txtTunnelUsername->GetValue());
+		server->iSetAuthModePwd(radioBtnPassword->GetValue());
+		server->SetTunnelPassword(txtTunnelPassword->GetValue());
+		server->SetPublicKeyFile(pickerPublicKeyFile->GetPath());
+		server->SetIdentityFile(pickerIdentityFile->GetPath());
+#endif
 		wxColour colour = colourPicker->GetColour();
 		wxString sColour = colour.GetAsString(wxC2S_HTML_SYNTAX);
 		server->iSetColour(sColour);
@@ -225,7 +273,18 @@ void dlgServer::OnOK(wxCommandEvent &ev)
 			    server->GetRestore(),
 			    server->GetSSL(),
 			    server->GetColour(),
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+			    server->GetGroup(),
+			    server->GetSSHTunnel(),
+			    server->GetTunnelHost(),
+			    server->GetTunnelUserName(),
+			    server->GetAuthModePwd(),
+			    server->GetTunnelPassword(),
+			    server->GetPublicKeyFile(),
+			    server->GetIdentityFile());
+#else
 			    server->GetGroup());
+#endif
 			newserver->iSetDbRestriction(server->GetDbRestriction().Trim());
 			newserver->iSetServiceID(server->GetServiceID().Trim());
 			newserver->iSetDiscoveryID(server->GetDiscoveryID().Trim());
@@ -366,7 +425,7 @@ int dlgServer::Go(bool modal)
 	cbSSL->Clear();
 	cbSSL->Append(wxT(" "));
 
-#ifdef SSL
+#ifdef PG_SSL
 	cbSSL->Append(_("require"));
 	cbSSL->Append(_("prefer"));
 
@@ -414,6 +473,29 @@ int dlgServer::Go(bool modal)
 
 		chkSSLCompression->SetValue(server->GetSSLCompression());
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+		chkSSHTunnel->SetValue(server->GetSSHTunnel());
+		if(server->GetSSHTunnel())
+		{
+			chkStorePwd->SetValue(false);
+			chkStorePwd->Enable(false);
+		}
+		txtTunnelHost->SetValue(server->GetTunnelHost());
+		txtTunnelUsername->SetValue(server->GetTunnelUserName());
+		if (server->GetAuthModePwd())
+		{
+			radioBtnPassword->SetValue(true);
+			radioBtnKeyfile->SetValue(false);
+		}
+		else
+		{
+			radioBtnPassword->SetValue(false);
+			radioBtnKeyfile->SetValue(true);
+		}
+		txtTunnelPassword->SetValue(server->GetTunnelPassword());
+		pickerPublicKeyFile->SetPath(server->GetPublicKeyFile());
+		pickerIdentityFile->SetPath(server->GetIdentityFile());
+#endif
 		stPassword->Disable();
 		txtPassword->Disable();
 		if (connection)
@@ -439,6 +521,19 @@ int dlgServer::Go(bool modal)
 			pickerSSLCrl->Disable();
 			chkSSLCompression->Disable();
 			EnableOK(false);
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+			chkSSHTunnel->Enable(false);
+			EnableSSHTunnelControls(false);
+		}
+		else
+		{
+			if (server->GetSSHTunnel())
+			{
+				chkSSHTunnel->Enable(true);
+				EnableSSHTunnelControls(true);
+				EnableAuthenticationOptions();
+			}
+#endif
 		}
 	}
 	else
@@ -468,13 +563,32 @@ wxString dlgServer::GetPassword()
 pgObject *dlgServer::CreateObject(pgCollection *collection)
 {
 	wxString name = GetName();
+	pgServer *obj = NULL;
 
-	pgServer *obj = new pgServer(GetName(), txtHostAddr->GetValue(), txtDescription->GetValue(),
-	                             txtService->GetValue(), cbDatabase->GetValue(),
-	                             txtUsername->GetValue(), StrToLong(txtPort->GetValue()),
-	                             chkTryConnect->GetValue() && chkStorePwd->GetValue(),
-	                             txtRolename->GetValue(), chkRestore->GetValue(), cbSSL->GetCurrentSelection(),
-	                             colourPicker->GetColourString(), cbGroup->GetValue());
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	if (chkSSHTunnel->GetValue())
+	{
+		obj = new pgServer(GetName(), txtHostAddr->GetValue(), txtDescription->GetValue(),
+		                   txtService->GetValue(), cbDatabase->GetValue(),
+		                   txtUsername->GetValue(), StrToLong(txtPort->GetValue()),
+		                   chkTryConnect->GetValue() && chkStorePwd->GetValue(),
+		                   txtRolename->GetValue(), chkRestore->GetValue(), cbSSL->GetCurrentSelection(),
+		                   colourPicker->GetColourString(), cbGroup->GetValue(),
+		                   chkSSHTunnel->GetValue(), txtTunnelHost->GetValue(), txtTunnelUsername->GetValue(),
+		                   radioBtnPassword->GetValue(),
+		                   txtTunnelPassword->GetValue(), pickerPublicKeyFile->GetPath(),
+		                   pickerIdentityFile->GetPath());
+	}
+	else
+#endif
+	{
+		obj = new pgServer(GetName(), txtHostAddr->GetValue(), txtDescription->GetValue(),
+		                   txtService->GetValue(), cbDatabase->GetValue(),
+		                   txtUsername->GetValue(), StrToLong(txtPort->GetValue()),
+		                   chkTryConnect->GetValue() && chkStorePwd->GetValue(),
+		                   txtRolename->GetValue(), chkRestore->GetValue(), cbSSL->GetCurrentSelection(),
+		                   colourPicker->GetColourString(), cbGroup->GetValue());
+	}
 
 	obj->iSetDbRestriction(txtDbRestriction->GetValue().Trim());
 
@@ -543,6 +657,14 @@ void dlgServer::CheckChange()
 	}
 	CheckValid(enable, dbRestrictionOk, _("Restriction not valid."));
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	if(chkSSHTunnel->GetValue())
+	{
+		CheckValid(enable, !txtTunnelHost->GetValue().IsEmpty(), _("Please specify ssh tunnel host."));
+		CheckValid(enable, !txtTunnelUsername->GetValue().IsEmpty(), _("Please specify ssh tunnel user name."));
+	}
+#endif
+
 	EnableOK(enable && !connection);
 }
 
@@ -551,3 +673,58 @@ wxString dlgServer::GetSql()
 {
 	return wxEmptyString;
 }
+
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+
+void dlgServer::OnCheckSSHTunnel(wxCommandEvent &ev)
+{
+	if (chkSSHTunnel->IsChecked())
+	{
+		if(chkStorePwd->GetValue())
+		{
+			wxMessageBox(_("Database passwords cannot be stored when using SSH tunnelling. The 'Store password' option has been turned off."), _("Stored Password"), wxICON_EXCLAMATION | wxOK, this);
+		}
+		chkStorePwd->SetValue(false);
+		chkStorePwd->Enable(false);
+		EnableSSHTunnelControls(true);
+		EnableAuthenticationOptions();
+	}
+	else
+	{
+		chkStorePwd->Enable();
+		EnableSSHTunnelControls(false);
+	}
+
+	CheckChange();
+}
+
+void dlgServer::OnChangeAuthOption(wxCommandEvent &ev)
+{
+	EnableAuthenticationOptions();
+}
+
+void dlgServer::EnableSSHTunnelControls(const bool &bEnable)
+{
+	txtTunnelHost->Enable(bEnable);
+	txtTunnelUsername->Enable(bEnable);
+	pickerPublicKeyFile->Enable(bEnable);
+	pickerIdentityFile->Enable(bEnable);
+	radioBtnPassword->Enable(bEnable);
+	radioBtnKeyfile->Enable(bEnable);
+	txtTunnelPassword->Enable(bEnable);
+}
+
+void dlgServer::EnableAuthenticationOptions()
+{
+	if (radioBtnPassword->GetValue())
+	{
+		pickerIdentityFile->Enable(false);
+		pickerPublicKeyFile->Enable(false);
+	}
+	else
+	{
+		pickerIdentityFile->Enable(true);
+		pickerPublicKeyFile->Enable(true);
+	}
+}
+#endif
diff --git a/pgadmin/frm/events.cpp b/pgadmin/frm/events.cpp
index 150f3c1..1111d9b 100644
--- a/pgadmin/frm/events.cpp
+++ b/pgadmin/frm/events.cpp
@@ -77,6 +77,11 @@ BEGIN_EVENT_TABLE(frmMain, pgFrame)
 #ifdef __WXGTK__
 	EVT_TREE_KEY_DOWN(CTL_BROWSER,          frmMain::OnTreeKeyDown)
 #endif
+
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	EVT_COMMAND (wxID_ANY, SSH_TUNNEL_ERROR_EVENT, frmMain::OnSSHTunnelEvent)
+#endif
+
 END_EVENT_TABLE()
 
 void frmMain::OnChildFocus(wxChildFocusEvent &event)
diff --git a/pgadmin/frm/frmMain.cpp b/pgadmin/frm/frmMain.cpp
index 4b8db5a..e771ff2 100644
--- a/pgadmin/frm/frmMain.cpp
+++ b/pgadmin/frm/frmMain.cpp
@@ -85,11 +85,18 @@
 #include "schema/pgCheck.h"
 #include "schema/pgDomain.h"
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+#include "utils/sshTunnel.h"
+#endif
 
 #if wxDIALOG_UNIT_COMPATIBILITY
 #error wxWindows must be compiled with wxDIALOG_UNIT_COMPATIBILITY=0!
 #endif
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+DEFINE_EVENT_TYPE(SSH_TUNNEL_ERROR_EVENT);
+#endif
+
 frmMain::frmMain(const wxString &title)
 	: pgFrame((wxFrame *)NULL, title)
 {
@@ -243,6 +250,14 @@ frmMain::~frmMain()
 
 	if (treeContextMenu)
 		delete treeContextMenu;
+
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	if(pgadminTunnelThread && pgadminTunnelThread->IsAlive())
+	{
+		pgadminTunnelThread->Cleanup();
+		pgadminTunnelThread = NULL;
+	}
+#endif
 }
 
 
@@ -1025,7 +1040,7 @@ int frmMain::ReconnectServer(pgServer *server, bool restore)
 	wxMilliSleep(100);
 	wxSafeYield();
 
-	int res = server->Connect(this, true);
+	int res = server->Connect(this, true, wxEmptyString, false, true);
 
 	// Check the result, and handle it as appropriate
 	wxTreeItemId item;
@@ -1196,7 +1211,14 @@ void frmMain::StoreServers()
 					settings->Write(key + wxT("SSLRootCert"), server->GetSSLRootCert());
 					settings->Write(key + wxT("SSLCrl"), server->GetSSLCrl());
 					settings->WriteBool(key + wxT("SSLCompression"), server->GetSSLCompression());
-
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+					settings->WriteBool(key + wxT("SSHTunnel"), server->GetSSHTunnel());
+					settings->Write(key + wxT("TunnelHost"), server->GetTunnelHost());
+					settings->Write(key + wxT("TunnelUserName"), server->GetTunnelUserName());
+					settings->WriteBool(key + wxT("TunnelModePwd"), server->GetAuthModePwd());
+					settings->Write(key + wxT("PublicKeyFile"), server->GetPublicKeyFile());
+					settings->Write(key + wxT("IdentityFile"), server->GetIdentityFile());
+#endif
 					pgCollection *coll = browser->FindCollection(databaseFactory, server->GetId());
 					if (coll)
 					{
@@ -1344,6 +1366,12 @@ void frmMain::SetItemBackgroundColour(wxTreeItemId item, wxColour colour)
 	}
 }
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+void frmMain::OnSSHTunnelEvent(wxCommandEvent &event)
+{
+	wxLogError(event.GetString());
+}
+#endif
 
 /////////////////////////////////////////
 
diff --git a/pgadmin/include/dlg/dlgServer.h b/pgadmin/include/dlg/dlgServer.h
index 0fd8f33..f0aa6f5 100644
--- a/pgadmin/include/dlg/dlgServer.h
+++ b/pgadmin/include/dlg/dlgServer.h
@@ -47,6 +47,12 @@ private:
 	void OnChangeColour(wxColourPickerEvent &ev);
 	void OnChangeFile(wxFileDirPickerEvent &ev);
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	void OnCheckSSHTunnel(wxCommandEvent &ev);
+	void OnChangeAuthOption(wxCommandEvent &ev);
+	void EnableSSHTunnelControls(const bool &bEnable);
+	void EnableAuthenticationOptions();
+#endif
 	DECLARE_EVENT_TABLE()
 };
 
diff --git a/pgadmin/include/frm/frmMain.h b/pgadmin/include/frm/frmMain.h
index cff48e2..5b129cc 100644
--- a/pgadmin/include/frm/frmMain.h
+++ b/pgadmin/include/frm/frmMain.h
@@ -82,6 +82,12 @@ enum
     REFRESH_OBJECT_AND_CHILDREN
 };
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+BEGIN_DECLARE_EVENT_TYPES()
+extern const wxEventType SSH_TUNNEL_ERROR_EVENT;
+END_DECLARE_EVENT_TYPES()
+#endif
+
 // Class declarations
 class frmMain : public pgFrame
 {
@@ -166,6 +172,11 @@ public:
 		m_refreshing = refresh;
 	}
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	void OnSSHTunnelEvent(wxCommandEvent &event);
+#endif
+
+
 private:
 	wxAuiManager manager;
 	ctlTree *browser;
diff --git a/pgadmin/include/module.mk b/pgadmin/include/module.mk
index 593c298..f6b6438 100644
--- a/pgadmin/include/module.mk
+++ b/pgadmin/include/module.mk
@@ -36,4 +36,5 @@ include include/gqb/module.mk
 include include/hotdraw/module.mk
 include include/utils/module.mk
 include include/ogl/module.mk
+include include/libssh2/module.mk
 
diff --git a/pgadmin/include/pgAdmin3.h b/pgadmin/include/pgAdmin3.h
index 7a9bbdd..90cbd51 100644
--- a/pgadmin/include/pgAdmin3.h
+++ b/pgadmin/include/pgAdmin3.h
@@ -19,6 +19,10 @@
 #include <wx/listctrl.h>
 #include <wx/xrc/xmlres.h>
 
+#ifdef WIN32
+#include <winsock2.h>
+#endif
+
 #include "utils/misc.h"
 #include <ctl/ctlTree.h>
 #include "ctl/ctlSQLBox.h"
@@ -91,6 +95,11 @@ extern wxLocale *locale;                // Application locale
 extern wxArrayInt existingLangs;        // Language IDs
 extern wxArrayString existingLangNames; // Language Names
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+class CSSHTunnelThread;
+extern CSSHTunnelThread *pgadminTunnelThread; // SSH Tunneling Thread Object
+#endif
+
 // Helper app paths - PG
 extern wxString pgBackupExecutable;
 extern wxString pgBackupAllExecutable;
diff --git a/pgadmin/include/schema/pgServer.h b/pgadmin/include/schema/pgServer.h
index c73cec3..347faf2 100644
--- a/pgadmin/include/schema/pgServer.h
+++ b/pgadmin/include/schema/pgServer.h
@@ -15,9 +15,8 @@
 #include "db/pgConn.h"
 #include "pgCollection.h"
 
-
 class frmMain;
-
+class pgServer;
 
 class pgServerFactory : public pgaFactory
 {
@@ -37,11 +36,19 @@ protected:
 };
 extern pgServerFactory serverFactory;
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+class CSSHTunnelThread;
+#endif
 
 class pgServer : public pgObject
 {
 public:
-	pgServer(const wxString &newServer = wxT(""), const wxString &newHostAddr = wxT(""), const wxString &newDescription = wxT(""), const wxString &newService = wxT(""), const wxString &newDatabase = wxT(""), const wxString &newUsername = wxT(""), int newPort = 5432, bool storePwd = false, const wxString &newRolename = wxT(""), bool restore = true, int sslMode = 0, const wxString &colour = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW).GetAsString(wxC2S_HTML_SYNTAX), const wxString &group = wxEmptyString);
+	pgServer(const wxString &newServer = wxT(""), const wxString &newHostAddr = wxT(""), const wxString &newDescription = wxT(""),
+	         const wxString &newService = wxT(""), const wxString &newDatabase = wxT(""), const wxString &newUsername = wxT(""), int newPort = 5432,
+	         bool storePwd = false, const wxString &newRolename = wxT(""), bool restore = true, int sslMode = 0,
+	         const wxString &colour = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW).GetAsString(wxC2S_HTML_SYNTAX), const wxString &group = wxEmptyString,
+	         bool sshTunnel = false, const wxString &newTunnelHost = wxEmptyString, const wxString &newTunnelUserName = wxEmptyString, bool authModePwd = true,
+	         const wxString &newTunnelPassword = wxEmptyString, const wxString &newPublicKey = wxEmptyString, const wxString &newIdentityFile = wxEmptyString);
 	~pgServer();
 	int GetIconId();
 
@@ -50,7 +57,7 @@ public:
 		return wxT("Server");
 	}
 	wxString GetTranslatedMessage(int kindOfMessage) const;
-	int Connect(frmMain *form, bool askPassword = true, const wxString &pwd = wxEmptyString, bool forceStorePassword = false);
+	int Connect(frmMain *form, bool askPassword = true, const wxString &pwd = wxEmptyString, bool forceStorePassword = false, bool askTunnelPassword = false);
 	bool Disconnect(frmMain *form);
 	void StorePassword();
 	bool GetPasswordIsStored();
@@ -390,7 +397,6 @@ public:
 		return conn;
 	}
 
-
 	wxString GetSSLCert() const
 	{
 		return sslcert;
@@ -433,6 +439,82 @@ public:
 		sslcompression = b;
 	}
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	//SSH Tunnel
+	bool GetSSHTunnel() const
+	{
+		return sshTunnel;
+	}
+	void iSetSSHTunnel(const bool b)
+	{
+		sshTunnel = b;
+	}
+	bool GetAuthModePwd() const
+	{
+		return authModePwd;
+	}
+	void iSetAuthModePwd(const bool b)
+	{
+		authModePwd = b;
+	}
+	wxString GetLocalListenHost() const
+	{
+		return local_listenhost;
+	}
+	void SetLocalListenHost(const wxString &s)
+	{
+		local_listenhost = s;
+	}
+	int GetLocalListenPort() const
+	{
+		return local_listenport;
+	}
+	void SetLocalListenPort(int newVal)
+	{
+		local_listenport = newVal;
+	}
+	wxString GetTunnelHost() const
+	{
+		return tunnelHost;
+	}
+	void SetTunnelHost(const wxString &s)
+	{
+		tunnelHost = s;
+	}
+	wxString GetTunnelUserName() const
+	{
+		return tunnelUserName;
+	}
+	void SetTunnelUserName(const wxString &s)
+	{
+		tunnelUserName = s;
+	}
+	wxString GetTunnelPassword() const
+	{
+		return tunnelPassword;
+	}
+	void SetTunnelPassword(const wxString &s)
+	{
+		tunnelPassword = s;
+	}
+	wxString GetPublicKeyFile() const
+	{
+		return publicKeyFile;
+	}
+	void SetPublicKeyFile(const wxString &s)
+	{
+		publicKeyFile = s;
+	}
+	wxString GetIdentityFile() const
+	{
+		return identityFile;
+	}
+	void SetIdentityFile(const wxString &s)
+	{
+		identityFile = s;
+	}
+#endif
+
 	void ShowDependencies(frmMain *form, ctlListView *Dependencies, const wxString &where = wxEmptyString);
 	void ShowDependents(frmMain *form, ctlListView *referencedBy, const wxString &where = wxEmptyString);
 
@@ -455,11 +537,22 @@ private:
 	wxString group;
 	wxString sslcert, sslkey, sslrootcert, sslcrl;
 	bool sslcompression;
+	bool sshTunnel;
 
 	bool inRecovery, replayPaused;
 	wxString receiveLoc, replayLoc, replayTimestamp;
 	wxDateTime confLoadedSince;
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	bool createSSHTunnel();
+
+	//SSH Tunnel
+	CSSHTunnelThread *tunnelObj;
+	bool authModePwd;
+	int local_listenport;
+	wxString tunnelHost, tunnelUserName, tunnelPassword, publicKeyFile, identityFile, local_listenhost;
+#endif
+
 #ifdef WIN32
 	SC_HANDLE scmHandle;
 	SC_HANDLE serviceHandle;
diff --git a/pgadmin/include/utils/misc.h b/pgadmin/include/utils/misc.h
index 69403f3..d0d09e4 100644
--- a/pgadmin/include/utils/misc.h
+++ b/pgadmin/include/utils/misc.h
@@ -26,6 +26,7 @@ class wxHelpControllerBase;
 #define __(str) wxT(str)
 
 typedef unsigned long OID;
+#define SSH_MAX_PASSWORD_LEN 256
 
 // we dont have an appropriate wxLongLong method
 #ifdef __WIN32__
diff --git a/pgadmin/include/utils/module.mk b/pgadmin/include/utils/module.mk
index e05ddef..a729415 100644
--- a/pgadmin/include/utils/module.mk
+++ b/pgadmin/include/utils/module.mk
@@ -24,6 +24,11 @@ pgadmin3_SOURCES += \
 	include/utils/utffile.h \
 	include/utils/macros.h
 
+if BUILD_SSH_TUNNEL
+pgadmin3_SOURCES += \
+	include/utils/sshTunnel.h
+endif
+
 EXTRA_DIST += \
         include/utils/module.mk
 
diff --git a/pgadmin/pgAdmin3.cpp b/pgadmin/pgAdmin3.cpp
index 5c93179..64d1d19 100644
--- a/pgadmin/pgAdmin3.cpp
+++ b/pgadmin/pgAdmin3.cpp
@@ -84,6 +84,11 @@
 frmMain *winMain = 0;
 wxThread *updateThread = 0;
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+#include "utils/sshTunnel.h"
+CSSHTunnelThread *pgadminTunnelThread = 0;
+#endif
+
 sysSettings *settings;
 wxArrayInt existingLangs;
 wxArrayString existingLangNames;
@@ -356,7 +361,7 @@ bool pgAdmin3::OnInit()
 	wxLogInfo(wxT("%s"), msg.c_str());
 	wxLogInfo(wxT("##############################################################"));
 
-#ifdef SSL
+#ifdef PG_SSL
 	wxLogInfo(wxT("Compiled with dynamically linked SSL support"));
 #endif
 
diff --git a/pgadmin/pgAdmin3.vcxproj b/pgadmin/pgAdmin3.vcxproj
index 521b1e1..296aa55 100644
--- a/pgadmin/pgAdmin3.vcxproj
+++ b/pgadmin/pgAdmin3.vcxproj
@@ -1,2242 +1,2415 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug (2.9)|Win32">
-      <Configuration>Debug (2.9)</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Debug (2.9)|x64">
-      <Configuration>Debug (2.9)</Configuration>
-      <Platform>x64</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Debug|x64">
-      <Configuration>Debug</Configuration>
-      <Platform>x64</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release (2.9)|Win32">
-      <Configuration>Release (2.9)</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release (2.9)|x64">
-      <Configuration>Release (2.9)</Configuration>
-      <Platform>x64</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|x64">
-      <Configuration>Release</Configuration>
-      <Platform>x64</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <ProjectGuid>{5C2D73BA-1F24-48F8-8233-85F5D672AA6A}</ProjectGuid>
-    <RootNamespace>pgAdmin3</RootNamespace>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-    <Import Project="..\pgAdmin3.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup>
-    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">.\Release\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">.\Release\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(Platform)\$(Configuration)\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(Platform)\$(Configuration)\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|x64'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">.\Debug\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">.\Debug\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(Platform)\$(Configuration)\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(Platform)\$(Configuration)\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(Configuration)\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(Configuration)\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(Platform)\$(Configuration)\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(Platform)\$(Configuration)\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(Configuration)\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(Configuration)\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">true</LinkIncremental>
-    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(Platform)\$(Configuration)\</OutDir>
-    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(Platform)\$(Configuration)\</IntDir>
-    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">true</LinkIncremental>
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <PreBuildEvent>
-      <Message>Extracting source code repository version</Message>
-      <Command>ver_svn.bat</Command>
-    </PreBuildEvent>
-    <Midl>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>Win32</TargetEnvironment>
-      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>MaxSpeed</Optimization>
-      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <StringPooling>true</StringPooling>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
-      <ObjectFileName>.\Release/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase28u.lib;wxbase28u_xml.lib;wxbase28u_net.lib;wxmsw28u_adv.lib;wxmsw28u_core.lib;wxmsw28u_html.lib;wxmsw28u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw28u_stc.lib;wxmsw28u_xrc.lib;wxexpat.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
-    <Midl>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>X64</TargetEnvironment>
-      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>MaxSpeed</Optimization>
-      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <StringPooling>true</StringPooling>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
-      <ObjectFileName>.\Release/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase28u.lib;wxbase28u_xml.lib;wxbase28u_net.lib;wxmsw28u_adv.lib;wxmsw28u_core.lib;wxmsw28u_html.lib;wxmsw28u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw28u_stc.lib;wxmsw28u_xrc.lib;wxexpat.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX64</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <PreBuildEvent>
-      <Message>Extracting source code repository version</Message>
-      <Command>ver_svn.bat</Command>
-    </PreBuildEvent>
-    <Midl>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>Win32</TargetEnvironment>
-      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
-      <ObjectFileName>.\Debug/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase28ud.lib;wxbase28ud_xml.lib;wxbase28ud_net.lib;wxmsw28ud_adv.lib;wxmsw28ud_core.lib;wxmsw28ud_html.lib;wxmsw28ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw28ud_stc.lib;wxmsw28ud_xrc.lib;wxexpatd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <NoEntryPoint>false</NoEntryPoint>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
-    <PreBuildEvent>
-      <Message>Extracting subversion repository version</Message>
-      <Command>ver_svn.bat</Command>
-    </PreBuildEvent>
-    <Midl>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>X64</TargetEnvironment>
-      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
-      <ObjectFileName>.\Debug/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase28ud.lib;wxbase28ud_xml.lib;wxbase28ud_net.lib;wxmsw28ud_adv.lib;wxmsw28ud_core.lib;wxmsw28ud_html.lib;wxmsw28ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw28ud_stc.lib;wxmsw28ud_xrc.lib;wxexpatd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <NoEntryPoint>false</NoEntryPoint>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX64</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
-    <PreBuildEvent>
-      <Message>Extracting source code repository version</Message>
-      <Command>ver_svn.bat</Command>
-    </PreBuildEvent>
-    <Midl>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>Win32</TargetEnvironment>
-      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
-      <ObjectFileName>.\Debug/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase29ud.lib;wxbase29ud_xml.lib;wxbase29ud_net.lib;wxmsw29ud_adv.lib;wxmsw29ud_core.lib;wxmsw29ud_html.lib;wxmsw29ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw29ud_stc.lib;wxmsw29ud_xrc.lib;wxexpatd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <NoEntryPoint>false</NoEntryPoint>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
-    <PreBuildEvent>
-      <Message>Extracting subversion repository version</Message>
-      <Command>ver_svn.bat</Command>
-    </PreBuildEvent>
-    <Midl>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>X64</TargetEnvironment>
-      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>Disabled</Optimization>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MinimalRebuild>true</MinimalRebuild>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
-      <ObjectFileName>.\Debug/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase29ud.lib;wxbase29ud_xml.lib;wxbase29ud_net.lib;wxmsw29ud_adv.lib;wxmsw29ud_core.lib;wxmsw29ud_html.lib;wxmsw29ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw29ud_stc.lib;wxmsw29ud_xrc.lib;wxexpatd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <NoEntryPoint>false</NoEntryPoint>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX64</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
-    <PreBuildEvent>
-      <Message>Extracting source code repository version</Message>
-      <Command>ver_svn.bat</Command>
-    </PreBuildEvent>
-    <Midl>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>Win32</TargetEnvironment>
-      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>MaxSpeed</Optimization>
-      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <StringPooling>true</StringPooling>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
-      <ObjectFileName>.\Release/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase29u.lib;wxbase29u_xml.lib;wxbase29u_net.lib;wxmsw29u_adv.lib;wxmsw29u_core.lib;wxmsw29u_html.lib;wxmsw29u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw29u_stc.lib;wxmsw29u_xrc.lib;wxexpat.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX86</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
-    <Midl>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <TargetEnvironment>X64</TargetEnvironment>
-      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
-      <HeaderFileName>
-      </HeaderFileName>
-    </Midl>
-    <ClCompile>
-      <Optimization>MaxSpeed</Optimization>
-      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
-      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <StringPooling>true</StringPooling>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
-      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
-      <AssemblerOutput>All</AssemblerOutput>
-      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
-      <ObjectFileName>.\Release/</ObjectFileName>
-      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
-      <BrowseInformation>true</BrowseInformation>
-      <WarningLevel>Level3</WarningLevel>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-    </ClCompile>
-    <ResourceCompile>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <Culture>0x0809</Culture>
-      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-    </ResourceCompile>
-    <Link>
-      <AdditionalDependencies>wxbase29u.lib;wxbase29u_xml.lib;wxbase29u_net.lib;wxmsw29u_adv.lib;wxmsw29u_core.lib;wxmsw29u_html.lib;wxmsw29u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw29u_stc.lib;wxmsw29u_xrc.lib;wxexpat.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
-      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
-      <GenerateMapFile>true</GenerateMapFile>
-      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
-      <SubSystem>Windows</SubSystem>
-      <RandomizedBaseAddress>false</RandomizedBaseAddress>
-      <DataExecutionPrevention>
-      </DataExecutionPrevention>
-      <TargetMachine>MachineX64</TargetMachine>
-    </Link>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
-    </Bscmake>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClCompile Include="agent\dlgJob.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="agent\dlgSchedule.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="agent\dlgStep.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="agent\pgaJob.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="agent\pgaSchedule.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="agent\pgaStep.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="ctl\calbox.cpp" />
-    <ClCompile Include="ctl\ctlAuiNotebook.cpp" />
-    <ClCompile Include="ctl\ctlCheckTreeView.cpp" />
-    <ClCompile Include="ctl\ctlColourPicker.cpp" />
-    <ClCompile Include="ctl\ctlComboBox.cpp" />
-    <ClCompile Include="ctl\ctlDefaultSecurityPanel.cpp" />
-    <ClCompile Include="ctl\ctlListView.cpp" />
-    <ClCompile Include="ctl\ctlMenuToolbar.cpp" />
-    <ClCompile Include="ctl\ctlSeclabelPanel.cpp" />
-    <ClCompile Include="ctl\ctlSecurityPanel.cpp" />
-    <ClCompile Include="ctl\ctlSQLBox.cpp" />
-    <ClCompile Include="ctl\ctlSQLGrid.cpp" />
-    <ClCompile Include="ctl\ctlSQLResult.cpp" />
-    <ClCompile Include="ctl\ctlTree.cpp" />
-    <ClCompile Include="ctl\explainCanvas.cpp" />
-    <ClCompile Include="ctl\explainShape.cpp" />
-    <ClCompile Include="ctl\timespin.cpp" />
-    <ClCompile Include="ctl\xh_calb.cpp" />
-    <ClCompile Include="ctl\xh_ctlchecktreeview.cpp" />
-    <ClCompile Include="ctl\xh_ctlcolourpicker.cpp" />
-    <ClCompile Include="ctl\xh_ctlcombo.cpp" />
-    <ClCompile Include="ctl\xh_ctltree.cpp" />
-    <ClCompile Include="ctl\xh_sqlbox.cpp" />
-    <ClCompile Include="ctl\xh_timespin.cpp" />
-    <ClCompile Include="db\keywords.c">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-      </PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
-      </PrecompiledHeader>
-    </ClCompile>
-    <ClCompile Include="db\pgConn.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="db\pgQueryThread.cpp" />
-    <ClCompile Include="db\pgSet.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgAddFavourite.cpp" />
-    <ClCompile Include="dlg\dlgAggregate.cpp" />
-    <ClCompile Include="dlg\dlgCast.cpp" />
-    <ClCompile Include="dlg\dlgCheck.cpp" />
-    <ClCompile Include="dlg\dlgClasses.cpp" />
-    <ClCompile Include="dlg\dlgCollation.cpp" />
-    <ClCompile Include="dlg\dlgColumn.cpp" />
-    <ClCompile Include="dlg\dlgConnect.cpp" />
-    <ClCompile Include="dlg\dlgConversion.cpp" />
-    <ClCompile Include="dlg\dlgDatabase.cpp" />
-    <ClCompile Include="dlg\dlgDomain.cpp" />
-    <ClCompile Include="dlg\dlgEditGridOptions.cpp" />
-    <ClCompile Include="dlg\dlgExtension.cpp" />
-    <ClCompile Include="dlg\dlgExtTable.cpp" />
-    <ClCompile Include="dlg\dlgFindReplace.cpp" />
-    <ClCompile Include="dlg\dlgForeignDataWrapper.cpp" />
-    <ClCompile Include="dlg\dlgForeignKey.cpp" />
-    <ClCompile Include="dlg\dlgForeignServer.cpp" />
-    <ClCompile Include="dlg\dlgForeignTable.cpp" />
-    <ClCompile Include="dlg\dlgFunction.cpp" />
-    <ClCompile Include="dlg\dlgGroup.cpp" />
-    <ClCompile Include="dlg\dlgHbaConfig.cpp" />
-    <ClCompile Include="dlg\dlgIndex.cpp" />
-    <ClCompile Include="dlg\dlgIndexConstraint.cpp" />
-    <ClCompile Include="dlg\dlgLanguage.cpp" />
-    <ClCompile Include="dlg\dlgMainConfig.cpp" />
-    <ClCompile Include="dlg\dlgManageFavourites.cpp" />
-    <ClCompile Include="dlg\dlgManageMacros.cpp" />
-    <ClCompile Include="dlg\dlgOperator.cpp" />
-    <ClCompile Include="dlg\dlgPackage.cpp" />
-    <ClCompile Include="dlg\dlgPgpassConfig.cpp" />
-    <ClCompile Include="dlg\dlgProperty.cpp" />
-    <ClCompile Include="dlg\dlgReassignDropOwned.cpp" />
-    <ClCompile Include="dlg\dlgRole.cpp" />
-    <ClCompile Include="dlg\dlgRule.cpp" />
-    <ClCompile Include="dlg\dlgSchema.cpp" />
-    <ClCompile Include="dlg\dlgSearchObject.cpp" />
-    <ClCompile Include="dlg\dlgSelectConnection.cpp" />
-    <ClCompile Include="dlg\dlgSelectDatabase.cpp" />
-    <ClCompile Include="dlg\dlgSequence.cpp" />
-    <ClCompile Include="dlg\dlgServer.cpp" />
-    <ClCompile Include="dlg\dlgSynonym.cpp" />
-    <ClCompile Include="dlg\dlgTable.cpp" />
-    <ClCompile Include="dlg\dlgTablespace.cpp" />
-    <ClCompile Include="dlg\dlgTextSearchConfiguration.cpp" />
-    <ClCompile Include="dlg\dlgTextSearchDictionary.cpp" />
-    <ClCompile Include="dlg\dlgTextSearchParser.cpp" />
-    <ClCompile Include="dlg\dlgTextSearchTemplate.cpp" />
-    <ClCompile Include="dlg\dlgTrigger.cpp" />
-    <ClCompile Include="dlg\dlgType.cpp" />
-    <ClCompile Include="dlg\dlgUser.cpp" />
-    <ClCompile Include="dlg\dlgUserMapping.cpp" />
-    <ClCompile Include="dlg\dlgView.cpp" />
-    <ClCompile Include="frm\events.cpp" />
-    <ClCompile Include="frm\frmAbout.cpp" />
-    <ClCompile Include="frm\frmBackup.cpp" />
-    <ClCompile Include="frm\frmBackupGlobals.cpp" />
-    <ClCompile Include="frm\frmBackupServer.cpp" />
-    <ClCompile Include="frm\frmConfig.cpp" />
-    <ClCompile Include="frm\frmDatabaseDesigner.cpp" />
-    <ClCompile Include="frm\frmEditGrid.cpp" />
-    <ClCompile Include="frm\frmExport.cpp" />
-    <ClCompile Include="frm\frmGrantWizard.cpp" />
-    <ClCompile Include="frm\frmHbaConfig.cpp" />
-    <ClCompile Include="frm\frmHint.cpp" />
-    <ClCompile Include="frm\frmImport.cpp" />
-    <ClCompile Include="frm\frmMain.cpp" />
-    <ClCompile Include="frm\frmMainConfig.cpp" />
-    <ClCompile Include="frm\frmMaintenance.cpp" />
-    <ClCompile Include="frm\frmOptions.cpp" />
-    <ClCompile Include="frm\frmPassword.cpp" />
-    <ClCompile Include="frm\frmPgpassConfig.cpp" />
-    <ClCompile Include="frm\frmQuery.cpp" />
-    <ClCompile Include="frm\frmReport.cpp" />
-    <ClCompile Include="frm\frmRestore.cpp" />
-    <ClCompile Include="frm\frmSplash.cpp" />
-    <ClCompile Include="frm\frmStatus.cpp" />
-    <ClCompile Include="frm\plugins.cpp" />
-    <ClCompile Include="schema\edbPackage.cpp" />
-    <ClCompile Include="schema\edbPackageFunction.cpp" />
-    <ClCompile Include="schema\edbPackageVariable.cpp" />
-    <ClCompile Include="schema\edbPrivateSynonym.cpp" />
-    <ClCompile Include="schema\edbSynonym.cpp" />
-    <ClCompile Include="schema\gpExtTable.cpp" />
-    <ClCompile Include="schema\gpPartition.cpp" />
-    <ClCompile Include="schema\gpResQueue.cpp" />
-    <ClCompile Include="schema\pgAggregate.cpp" />
-    <ClCompile Include="schema\pgCast.cpp" />
-    <ClCompile Include="schema\pgCatalogObject.cpp" />
-    <ClCompile Include="schema\pgCheck.cpp" />
-    <ClCompile Include="schema\pgCollation.cpp" />
-    <ClCompile Include="schema\pgCollection.cpp" />
-    <ClCompile Include="schema\pgColumn.cpp" />
-    <ClCompile Include="schema\pgConstraints.cpp" />
-    <ClCompile Include="schema\pgConversion.cpp" />
-    <ClCompile Include="schema\pgDatabase.cpp" />
-    <ClCompile Include="schema\pgDatatype.cpp" />
-    <ClCompile Include="schema\pgDomain.cpp" />
-    <ClCompile Include="schema\pgExtension.cpp" />
-    <ClCompile Include="schema\pgForeignDataWrapper.cpp" />
-    <ClCompile Include="schema\pgForeignKey.cpp" />
-    <ClCompile Include="schema\pgForeignServer.cpp" />
-    <ClCompile Include="schema\pgForeignTable.cpp" />
-    <ClCompile Include="schema\pgFunction.cpp" />
-    <ClCompile Include="schema\pgGroup.cpp" />
-    <ClCompile Include="schema\pgIndex.cpp" />
-    <ClCompile Include="schema\pgIndexConstraint.cpp" />
-    <ClCompile Include="schema\pgLanguage.cpp" />
-    <ClCompile Include="schema\pgObject.cpp" />
-    <ClCompile Include="schema\pgOperator.cpp" />
-    <ClCompile Include="schema\pgOperatorClass.cpp" />
-    <ClCompile Include="schema\pgOperatorFamily.cpp" />
-    <ClCompile Include="schema\pgRole.cpp" />
-    <ClCompile Include="schema\pgRule.cpp" />
-    <ClCompile Include="schema\pgSchema.cpp" />
-    <ClCompile Include="schema\pgSequence.cpp" />
-    <ClCompile Include="schema\pgServer.cpp" />
-    <ClCompile Include="schema\pgTable.cpp" />
-    <ClCompile Include="schema\pgTablespace.cpp" />
-    <ClCompile Include="schema\pgTextSearchConfiguration.cpp" />
-    <ClCompile Include="schema\pgTextSearchDictionary.cpp" />
-    <ClCompile Include="schema\pgTextSearchParser.cpp" />
-    <ClCompile Include="schema\pgTextSearchTemplate.cpp" />
-    <ClCompile Include="schema\pgTrigger.cpp" />
-    <ClCompile Include="schema\pgType.cpp" />
-    <ClCompile Include="schema\pgUser.cpp" />
-    <ClCompile Include="schema\pgUserMapping.cpp" />
-    <ClCompile Include="schema\pgView.cpp" />
-    <ClCompile Include="slony\dlgRepCluster.cpp" />
-    <ClCompile Include="slony\dlgRepListen.cpp" />
-    <ClCompile Include="slony\dlgRepNode.cpp" />
-    <ClCompile Include="slony\dlgRepPath.cpp" />
-    <ClCompile Include="slony\dlgRepProperty.cpp" />
-    <ClCompile Include="slony\dlgRepSequence.cpp" />
-    <ClCompile Include="slony\dlgRepSet.cpp" />
-    <ClCompile Include="slony\dlgRepSubscription.cpp" />
-    <ClCompile Include="slony\dlgRepTable.cpp" />
-    <ClCompile Include="slony\slCluster.cpp" />
-    <ClCompile Include="slony\slListen.cpp" />
-    <ClCompile Include="slony\slNode.cpp" />
-    <ClCompile Include="slony\slPath.cpp" />
-    <ClCompile Include="slony\slSequence.cpp" />
-    <ClCompile Include="slony\slSet.cpp" />
-    <ClCompile Include="slony\slSubscription.cpp" />
-    <ClCompile Include="slony\slTable.cpp" />
-    <ClCompile Include="ui\xrcDialogs.cpp">
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
-      </PrecompiledHeader>
-    </ClCompile>
-    <ClCompile Include="utils\csvfiles.cpp" />
-    <ClCompile Include="utils\factory.cpp" />
-    <ClCompile Include="utils\favourites.cpp" />
-    <ClCompile Include="utils\macros.cpp" />
-    <ClCompile Include="utils\misc.cpp" />
-    <ClCompile Include="utils\pgconfig.cpp" />
-    <ClCompile Include="utils\registry.cpp" />
-    <ClCompile Include="utils\sysLogger.cpp" />
-    <ClCompile Include="utils\sysProcess.cpp" />
-    <ClCompile Include="utils\sysSettings.cpp" />
-    <ClCompile Include="utils\tabcomplete.c">
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-      </PrecompiledHeader>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
-      </PrecompiledHeader>
-    </ClCompile>
-    <ClCompile Include="utils\utffile.cpp" />
-    <ClCompile Include="debugger\ctlCodeWindow.cpp" />
-    <ClCompile Include="debugger\ctlMessageWindow.cpp" />
-    <ClCompile Include="debugger\ctlResultGrid.cpp" />
-    <ClCompile Include="debugger\ctlStackWindow.cpp" />
-    <ClCompile Include="debugger\ctlTabWindow.cpp" />
-    <ClCompile Include="debugger\ctlVarWindow.cpp" />
-    <ClCompile Include="debugger\dbgBreakPoint.cpp" />
-    <ClCompile Include="debugger\dbgDbResult.cpp" />
-    <ClCompile Include="debugger\dbgPgConn.cpp" />
-    <ClCompile Include="debugger\dbgPgThread.cpp" />
-    <ClCompile Include="debugger\dbgResultset.cpp" />
-    <ClCompile Include="debugger\dbgTargetInfo.cpp" />
-    <ClCompile Include="debugger\debugger.cpp" />
-    <ClCompile Include="debugger\dlgDirectDbg.cpp" />
-    <ClCompile Include="debugger\frmDebugger.cpp" />
-    <ClCompile Include="gqb\gqbArrayCollection.cpp" />
-    <ClCompile Include="gqb\gqbBrowser.cpp" />
-    <ClCompile Include="gqb\gqbCollection.cpp" />
-    <ClCompile Include="gqb\gqbColumn.cpp" />
-    <ClCompile Include="gqb\gqbController.cpp" />
-    <ClCompile Include="gqb\gqbDatabase.cpp" />
-    <ClCompile Include="gqb\gqbGraphSimple.cpp" />
-    <ClCompile Include="gqb\gqbGridJoinTable.cpp" />
-    <ClCompile Include="gqb\gqbGridOrderTable.cpp" />
-    <ClCompile Include="gqb\gqbGridProjTable.cpp" />
-    <ClCompile Include="gqb\gqbGridRestTable.cpp" />
-    <ClCompile Include="gqb\gqbModel.cpp" />
-    <ClCompile Include="gqb\gqbObject.cpp" />
-    <ClCompile Include="gqb\gqbObjectCollection.cpp" />
-    <ClCompile Include="gqb\gqbQueryObjs.cpp" />
-    <ClCompile Include="gqb\gqbSchema.cpp" />
-    <ClCompile Include="gqb\gqbTable.cpp" />
-    <ClCompile Include="gqb\gqbView.cpp" />
-    <ClCompile Include="gqb\gqbViewPanels.cpp" />
-    <ClCompile Include="pgscript\lex.pgs.cc" />
-    <ClCompile Include="pgscript\parser.tab.cc" />
-    <ClCompile Include="pgscript\pgsApplication.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsArithmeticException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsAssertException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsBreakException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsCastException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsContinueException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsInterruptException.cpp" />
-    <ClCompile Include="pgscript\exceptions\pgsParameterException.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsAnd.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsAssign.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsAssignToRecord.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsCast.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsColumns.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsDifferent.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsEqual.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsExecute.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsExpression.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenDate.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenDateTime.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenDictionary.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenInt.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenReal.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenReference.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenRegex.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenString.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGenTime.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGreater.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsGreaterEqual.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsIdent.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsIdentRecord.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsLines.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsLower.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsLowerEqual.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsMinus.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsModulo.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsNegate.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsNot.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsOperation.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsOr.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsOver.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsParenthesis.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsPlus.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsRemoveLine.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsTimes.cpp" />
-    <ClCompile Include="pgscript\expressions\pgsTrim.cpp" />
-    <ClCompile Include="pgscript\generators\pgsDateGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsDateTimeGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsDictionaryGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsIntegerGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsNumberGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsObjectGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsRealGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsReferenceGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsRegexGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsStringGen.cpp" />
-    <ClCompile Include="pgscript\generators\pgsTimeGen.cpp" />
-    <ClCompile Include="pgscript\objects\pgsGenerator.cpp" />
-    <ClCompile Include="pgscript\objects\pgsNumber.cpp" />
-    <ClCompile Include="pgscript\objects\pgsRecord.cpp" />
-    <ClCompile Include="pgscript\objects\pgsString.cpp" />
-    <ClCompile Include="pgscript\objects\pgsVariable.cpp" />
-    <ClCompile Include="pgscript\statements\pgsAssertStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsBreakStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsContinueStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsDeclareRecordStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsExpressionStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsIfStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsPrintStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsProgram.cpp" />
-    <ClCompile Include="pgscript\statements\pgsStmt.cpp" />
-    <ClCompile Include="pgscript\statements\pgsStmtList.cpp" />
-    <ClCompile Include="pgscript\statements\pgsWhileStmt.cpp" />
-    <ClCompile Include="pgscript\utilities\pgsAlloc.cpp" />
-    <ClCompile Include="pgscript\utilities\pgsContext.cpp" />
-    <ClCompile Include="pgscript\utilities\pgsDriver.cpp" />
-    <ClCompile Include="pgscript\utilities\pgsMapm.cpp" />
-    <ClCompile Include="pgscript\utilities\pgsThread.cpp" />
-    <ClCompile Include="pgscript\utilities\pgsUtilities.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm5sin.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_add.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_cpi.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_div.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_exp.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_fam.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_fft.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_flr.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_fpf.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_gcd.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg2.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg3.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg4.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_log.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_mul.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_pow.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_rcp.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_rnd.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_set.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_sin.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmasin.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmasn0.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmcbrt.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmcnst.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmfact.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmfmul.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmgues.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmhasn.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmhsin.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmipwr.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmistr.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmpwr2.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmrsin.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmsqrt.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmstck.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmutil.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmutl1.cpp" />
-    <ClCompile Include="pgscript\utilities\m_apm\mapmutl2.cpp" />
-    <ClCompile Include="ogl\basic.cpp" />
-    <ClCompile Include="ogl\basic2.cpp" />
-    <ClCompile Include="ogl\bmpshape.cpp" />
-    <ClCompile Include="ogl\canvas.cpp" />
-    <ClCompile Include="ogl\composit.cpp" />
-    <ClCompile Include="ogl\constrnt.cpp" />
-    <ClCompile Include="ogl\divided.cpp" />
-    <ClCompile Include="ogl\drawn.cpp" />
-    <ClCompile Include="ogl\lines.cpp" />
-    <ClCompile Include="ogl\mfutils.cpp" />
-    <ClCompile Include="ogl\ogldiag.cpp" />
-    <ClCompile Include="ogl\oglmisc.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddColumnFigure.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddColumnKindIcon.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddColumnOptionIcon.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddRelationshipFigure.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddRelationshipItem.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddRelationshipTerminal.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddTableFigure.cpp" />
-    <ClCompile Include="dd\dditems\figures\ddTextTableItemFigure.cpp" />
-    <ClCompile Include="dd\dditems\figures\xml\ddXmlStorage.cpp" />
-    <ClCompile Include="dd\dditems\handles\ddAddColButtonHandle.cpp" />
-    <ClCompile Include="dd\dditems\handles\ddAddFkButtonHandle.cpp" />
-    <ClCompile Include="dd\dditems\handles\ddMinMaxTableButtonHandle.cpp" />
-    <ClCompile Include="dd\dditems\handles\ddRemoveTableButtonHandle.cpp" />
-    <ClCompile Include="dd\dditems\handles\ddScrollBarHandle.cpp" />
-    <ClCompile Include="dd\dditems\handles\ddSouthTableSizeHandle.cpp" />
-    <ClCompile Include="dd\dditems\locators\ddAddColLocator.cpp" />
-    <ClCompile Include="dd\dditems\locators\ddAddFkLocator.cpp" />
-    <ClCompile Include="dd\dditems\locators\ddMinMaxTableLocator.cpp" />
-    <ClCompile Include="dd\dditems\locators\ddRemoveTableLocator.cpp" />
-    <ClCompile Include="dd\dditems\locators\ddScrollBarTableLocator.cpp" />
-    <ClCompile Include="dd\dditems\locators\ddTableBottomLocator.cpp" />
-    <ClCompile Include="dd\dditems\tools\ddColumnFigureTool.cpp" />
-    <ClCompile Include="dd\dditems\tools\ddColumnTextTool.cpp" />
-    <ClCompile Include="dd\dditems\utilities\ddPrecisionScaleDialog.cpp" />
-    <ClCompile Include="dd\dditems\utilities\ddSelectKindFksDialog.cpp" />
-    <ClCompile Include="dd\dditems\utilities\ddTableNameDialog.cpp" />
-    <ClCompile Include="dd\ddmodel\ddBrowserDataContainer.cpp" />
-    <ClCompile Include="dd\ddmodel\ddDatabaseDesign.cpp" />
-    <ClCompile Include="dd\ddmodel\ddDBReverseEnginering.cpp" />
-    <ClCompile Include="dd\ddmodel\ddDrawingEditor.cpp" />
-    <ClCompile Include="dd\ddmodel\ddDrawingView.cpp" />
-    <ClCompile Include="dd\ddmodel\ddGenerationWizard.cpp" />
-    <ClCompile Include="dd\ddmodel\ddModelBrowser.cpp" />
-    <ClCompile Include="hotdraw\connectors\hdChopBoxConnector.cpp" />
-    <ClCompile Include="hotdraw\connectors\hdIConnector.cpp" />
-    <ClCompile Include="hotdraw\connectors\hdLocatorConnector.cpp" />
-    <ClCompile Include="hotdraw\connectors\hdStickyRectangleConnector.cpp" />
-    <ClCompile Include="hotdraw\figures\hdAbstractFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdAbstractMenuFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdAttribute.cpp" />
-    <ClCompile Include="hotdraw\figures\hdAttributeFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdBitmapFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdCompositeFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdIConnectionFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdIFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdLineConnection.cpp" />
-    <ClCompile Include="hotdraw\figures\hdLineTerminal.cpp" />
-    <ClCompile Include="hotdraw\figures\hdPolyLineFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdRectangleFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\hdSimpleTextFigure.cpp" />
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFillAttribute.cpp" />
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontAttribute.cpp" />
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontColorAttribute.cpp" />
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdLineAttribute.cpp" />
-    <ClCompile Include="hotdraw\figures\xml\hdStorage.cpp" />
-    <ClCompile Include="hotdraw\handles\hdButtonHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdChangeConnectionEndHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdChangeConnectionHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdChangeConnectionStartHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdIHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdLineConnectionHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdLocatorHandle.cpp" />
-    <ClCompile Include="hotdraw\handles\hdPolyLineHandle.cpp" />
-    <ClCompile Include="hotdraw\locators\hdILocator.cpp" />
-    <ClCompile Include="hotdraw\locators\hdPolyLineLocator.cpp" />
-    <ClCompile Include="hotdraw\main\hdDrawing.cpp" />
-    <ClCompile Include="hotdraw\main\hdDrawingEditor.cpp" />
-    <ClCompile Include="hotdraw\main\hdDrawingView.cpp" />
-    <ClCompile Include="hotdraw\tools\hdAbstractTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdCanvasMenuTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdCompositeFigureTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdConnectionCreationTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdCreationTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdDragCreationTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdDragTrackerTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdFigureTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdHandleTrackerTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdITool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdMenuTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdPolyLineFigureTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdSelectAreaTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdSelectionTool.cpp" />
-    <ClCompile Include="hotdraw\tools\hdSimpleTextTool.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdArrayCollection.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdCollection.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdGeometry.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdKeyEvent.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdMouseEvent.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdMultiPosRect.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdPoint.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdRect.cpp" />
-    <ClCompile Include="hotdraw\utilities\hdRemoveDeleteDialog.cpp" />
-    <ClCompile Include="pgAdmin3.cpp">
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Use</PrecompiledHeader>
-      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">Use</PrecompiledHeader>
-    </ClCompile>
-    <ClCompile Include="precomp.cpp">
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">Create</PrecompiledHeader>
-      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
-      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
-    </ClCompile>
-  </ItemGroup>
-  <ItemGroup>
-    <None Include="agent\module.mk" />
-    <None Include="ctl\module.mk" />
-    <None Include="db\module.mk" />
-    <None Include="dlg\module.mk" />
-    <None Include="frm\module.mk" />
-    <None Include="include\module.mk" />
-    <None Include="include\utils\module.mk" />
-    <None Include="include\ctl\module.mk" />
-    <None Include="include\images\module.mk" />
-    <None Include="include\images\pgAdmin3.ico" />
-    <None Include="include\images\sql.ico" />
-    <None Include="include\parser\module.mk" />
-    <None Include="include\agent\module.mk" />
-    <None Include="include\slony\module.mk" />
-    <None Include="include\dlg\module.mk" />
-    <None Include="include\frm\module.mk" />
-    <None Include="include\schema\module.mk" />
-    <None Include="include\db\module.mk" />
-    <None Include="include\gqb\module.mk" />
-    <None Include="include\pgscript\location.hh" />
-    <None Include="include\pgscript\parser.tab.hh" />
-    <None Include="include\pgscript\position.hh" />
-    <None Include="include\pgscript\stack.hh" />
-    <None Include="include\pgscript\exceptions\module.mk" />
-    <None Include="include\pgscript\expressions\module.mk" />
-    <None Include="include\pgscript\generators\module.mk" />
-    <None Include="include\pgscript\objects\module.mk" />
-    <None Include="include\pgscript\statements\module.mk" />
-    <None Include="include\pgscript\utilities\module.mk" />
-    <None Include="include\pgscript\utilities\mapm-lib\license.txt" />
-    <None Include="include\pgscript\utilities\mapm-lib\module.mk" />
-    <None Include="include\ogl\module.mk" />
-    <None Include="include\ogl\README" />
-    <None Include="include\dd\module.mk" />
-    <None Include="include\dd\dditems\module.mk" />
-    <None Include="include\dd\dditems\figures\module.mk" />
-    <None Include="include\dd\dditems\figures\xml\module.mk" />
-    <None Include="include\dd\dditems\handles\module.mk" />
-    <None Include="include\dd\dditems\locators\module.mk" />
-    <None Include="include\dd\dditems\tools\module.mk" />
-    <None Include="include\dd\dditems\utilities\module.mk" />
-    <None Include="include\dd\ddmodel\module.mk" />
-    <None Include="include\hotdraw\module.mk" />
-    <None Include="include\hotdraw\connectors\module.mk" />
-    <None Include="include\hotdraw\figures\module.mk" />
-    <None Include="include\hotdraw\figures\defaultAttributes\module.mk" />
-    <None Include="include\hotdraw\handles\module.mk" />
-    <None Include="include\hotdraw\locators\module.mk" />
-    <None Include="include\hotdraw\main\module.mk" />
-    <None Include="include\hotdraw\tools\module.mk" />
-    <None Include="include\hotdraw\utilities\module.mk" />
-    <None Include="schema\module.mk" />
-    <None Include="slony\module.mk" />
-    <None Include="ui\dlgAddFavourite.xrc" />
-    <None Include="ui\dlgAggregate.xrc" />
-    <None Include="ui\dlgCast.xrc" />
-    <None Include="ui\dlgCheck.xrc" />
-    <None Include="ui\dlgCollation.xrc" />
-    <None Include="ui\dlgColumn.xrc" />
-    <None Include="ui\dlgConnect.xrc" />
-    <None Include="ui\dlgConversion.xrc" />
-    <None Include="ui\dlgDatabase.xrc" />
-    <None Include="ui\dlgDirectDbg.xrc" />
-    <None Include="ui\dlgDomain.xrc" />
-    <None Include="ui\dlgEditGridOptions.xrc" />
-    <None Include="ui\dlgExtension.xrc" />
-    <None Include="ui\dlgExtTable.xrc" />
-    <None Include="ui\dlgFindReplace.xrc" />
-    <None Include="ui\dlgForeignDataWrapper.xrc" />
-    <None Include="ui\dlgForeignKey.xrc" />
-    <None Include="ui\dlgForeignServer.xrc" />
-    <None Include="ui\dlgForeignTable.xrc" />
-    <None Include="ui\dlgFunction.xrc" />
-    <None Include="ui\dlgGroup.xrc" />
-    <None Include="ui\dlgHbaConfig.xrc" />
-    <None Include="ui\dlgIndex.xrc" />
-    <None Include="ui\dlgIndexConstraint.xrc" />
-    <None Include="ui\dlgJob.xrc" />
-    <None Include="ui\dlgLanguage.xrc" />
-    <None Include="ui\dlgMainConfig.xrc" />
-    <None Include="ui\dlgManageFavourites.xrc" />
-    <None Include="ui\dlgManageMacros.xrc" />
-    <None Include="ui\dlgOperator.xrc" />
-    <None Include="ui\dlgPackage.xrc" />
-    <None Include="ui\dlgPgpassConfig.xrc" />
-    <None Include="ui\dlgReassignDropOwned.xrc" />
-    <None Include="ui\dlgRepCluster.xrc" />
-    <None Include="ui\dlgRepClusterUpgrade.xrc" />
-    <None Include="ui\dlgRepListen.xrc" />
-    <None Include="ui\dlgRepNode.xrc" />
-    <None Include="ui\dlgRepPath.xrc" />
-    <None Include="ui\dlgRepSequence.xrc" />
-    <None Include="ui\dlgRepSet.xrc" />
-    <None Include="ui\dlgRepSetMerge.xrc" />
-    <None Include="ui\dlgRepSetMove.xrc" />
-    <None Include="ui\dlgRepSubscription.xrc" />
-    <None Include="ui\dlgRepTable.xrc" />
-    <None Include="ui\dlgRole.xrc" />
-    <None Include="ui\dlgRule.xrc" />
-    <None Include="ui\dlgSchedule.xrc" />
-    <None Include="ui\dlgSchema.xrc" />
-    <None Include="ui\dlgSearchObject.xrc" />
-    <None Include="ui\dlgSelectConnection.xrc" />
-    <None Include="ui\dlgSequence.xrc" />
-    <None Include="ui\dlgServer.xrc" />
-    <None Include="ui\dlgStep.xrc" />
-    <None Include="ui\dlgSynonym.xrc" />
-    <None Include="ui\dlgTable.xrc" />
-    <None Include="ui\dlgTablespace.xrc" />
-    <None Include="ui\dlgTextSearchConfiguration.xrc" />
-    <None Include="ui\dlgTextSearchDictionary.xrc" />
-    <None Include="ui\dlgTextSearchParser.xrc" />
-    <None Include="ui\dlgTextSearchTemplate.xrc" />
-    <None Include="ui\dlgTrigger.xrc" />
-    <None Include="ui\dlgType.xrc" />
-    <None Include="ui\dlgUser.xrc" />
-    <None Include="ui\dlgUserMapping.xrc" />
-    <None Include="ui\dlgView.xrc" />
-    <None Include="ui\embed-xrc" />
-    <None Include="ui\embed-xrc.bat" />
-    <None Include="ui\frmBackup.xrc" />
-    <None Include="ui\frmBackupGlobals.xrc" />
-    <None Include="ui\frmBackupServer.xrc" />
-    <None Include="ui\frmExport.xrc" />
-    <None Include="ui\frmGrantWizard.xrc" />
-    <None Include="ui\frmHint.xrc" />
-    <None Include="ui\frmMaintenance.xrc" />
-    <None Include="ui\frmOptions.xrc" />
-    <None Include="ui\frmPassword.xrc" />
-    <None Include="ui\frmReport.xrc" />
-    <None Include="ui\frmRestore.xrc" />
-    <None Include="ui\module.mk" />
-    <None Include="utils\module.mk" />
-    <None Include="utils\tab-complete.inc" />
-    <None Include="utils\tabcomplete.pl" />
-    <None Include="gqb\module.mk" />
-    <None Include="pgscript\module.mk" />
-    <None Include="pgscript\parser.sh" />
-    <None Include="pgscript\pgsParser.yy" />
-    <None Include="pgscript\pgsScanner.ll" />
-    <None Include="pgscript\README" />
-    <None Include="pgscript\exceptions\module.mk" />
-    <None Include="pgscript\expressions\module.mk" />
-    <None Include="pgscript\generators\module.mk" />
-    <None Include="pgscript\objects\module.mk" />
-    <None Include="pgscript\statements\module.mk" />
-    <None Include="pgscript\utilities\module.mk" />
-    <None Include="pgscript\utilities\m_apm\module.mk" />
-    <None Include="ogl\module.mk" />
-    <None Include="ogl\README" />
-    <None Include="dd\module.mk" />
-    <None Include="dd\dditems\module.mk" />
-    <None Include="dd\dditems\figures\module.mk" />
-    <None Include="dd\dditems\handles\module.mk" />
-    <None Include="dd\dditems\locators\module.mk" />
-    <None Include="dd\dditems\tools\module.mk" />
-    <None Include="dd\dditems\utilities\module.mk" />
-    <None Include="dd\ddmodel\module.mk" />
-    <None Include="hotdraw\module.mk" />
-    <None Include="hotdraw\connectors\module.mk" />
-    <None Include="hotdraw\figures\module.mk" />
-    <None Include="hotdraw\figures\defaultAttributes\module.mk" />
-    <None Include="hotdraw\figures\xml\module.mk" />
-    <None Include="hotdraw\handles\module.mk" />
-    <None Include="hotdraw\locators\module.mk" />
-    <None Include="hotdraw\main\module.mk" />
-    <None Include="hotdraw\tools\module.mk" />
-    <None Include="hotdraw\utilities\module.mk" />
-    <None Include="Makefile.am" />
-    <None Include="plugins.ini" />
-    <None Include="settings.ini" />
-    <None Include="ver_svn.bat" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClInclude Include="include\copyright.h" />
-    <ClInclude Include="include\pgAdmin3.h" />
-    <ClInclude Include="include\postgres.h" />
-    <ClInclude Include="include\precomp.h" />
-    <ClInclude Include="include\svnversion.h" />
-    <ClInclude Include="include\version.h" />
-    <ClInclude Include="include\utils\csvfiles.h" />
-    <ClInclude Include="include\utils\factory.h" />
-    <ClInclude Include="include\utils\favourites.h" />
-    <ClInclude Include="include\utils\macros.h" />
-    <ClInclude Include="include\utils\misc.h" />
-    <ClInclude Include="include\utils\pgconfig.h" />
-    <ClInclude Include="include\utils\pgDefs.h" />
-    <ClInclude Include="include\utils\pgfeatures.h" />
-    <ClInclude Include="include\utils\registr.h" />
-    <ClInclude Include="include\utils\registry.h" />
-    <ClInclude Include="include\utils\sysLogger.h" />
-    <ClInclude Include="include\utils\sysProcess.h" />
-    <ClInclude Include="include\utils\sysSettings.h" />
-    <ClInclude Include="include\utils\utffile.h" />
-    <ClInclude Include="include\ctl\calbox.h" />
-    <ClInclude Include="include\ctl\ctlAuiNotebook.h" />
-    <ClInclude Include="include\ctl\ctlCheckTreeView.h" />
-    <ClInclude Include="include\ctl\ctlColourPicker.h" />
-    <ClInclude Include="include\ctl\ctlComboBox.h" />
-    <ClInclude Include="include\ctl\ctlDefaultSecurityPanel.h" />
-    <ClInclude Include="include\ctl\ctlListView.h" />
-    <ClInclude Include="include\ctl\ctlMenuToolbar.h" />
-    <ClInclude Include="include\ctl\ctlSeclabelPanel.h" />
-    <ClInclude Include="include\ctl\ctlSecurityPanel.h" />
-    <ClInclude Include="include\ctl\ctlSQLBox.h" />
-    <ClInclude Include="include\ctl\ctlSQLGrid.h" />
-    <ClInclude Include="include\ctl\ctlSQLResult.h" />
-    <ClInclude Include="include\ctl\ctlTree.h" />
-    <ClInclude Include="include\ctl\explainCanvas.h" />
-    <ClInclude Include="include\ctl\timespin.h" />
-    <ClInclude Include="include\ctl\wxgridsel.h" />
-    <ClInclude Include="include\ctl\xh_calb.h" />
-    <ClInclude Include="include\ctl\xh_ctlchecktreeview.h" />
-    <ClInclude Include="include\ctl\xh_ctlcolourpicker.h" />
-    <ClInclude Include="include\ctl\xh_ctlcombo.h" />
-    <ClInclude Include="include\ctl\xh_ctltree.h" />
-    <ClInclude Include="include\ctl\xh_sqlbox.h" />
-    <ClInclude Include="include\ctl\xh_timespin.h" />
-    <ClInclude Include="include\parser\keywords.h" />
-    <ClInclude Include="include\agent\dlgJob.h" />
-    <ClInclude Include="include\agent\dlgSchedule.h" />
-    <ClInclude Include="include\agent\dlgStep.h" />
-    <ClInclude Include="include\agent\pgaJob.h" />
-    <ClInclude Include="include\agent\pgaSchedule.h" />
-    <ClInclude Include="include\agent\pgaStep.h" />
-    <ClInclude Include="include\slony\dlgRepCluster.h" />
-    <ClInclude Include="include\slony\dlgRepListen.h" />
-    <ClInclude Include="include\slony\dlgRepNode.h" />
-    <ClInclude Include="include\slony\dlgRepPath.h" />
-    <ClInclude Include="include\slony\dlgRepProperty.h" />
-    <ClInclude Include="include\slony\dlgRepSequence.h" />
-    <ClInclude Include="include\slony\dlgRepSet.h" />
-    <ClInclude Include="include\slony\dlgRepSubscription.h" />
-    <ClInclude Include="include\slony\dlgRepTable.h" />
-    <ClInclude Include="include\slony\slCluster.h" />
-    <ClInclude Include="include\slony\slListen.h" />
-    <ClInclude Include="include\slony\slNode.h" />
-    <ClInclude Include="include\slony\slPath.h" />
-    <ClInclude Include="include\slony\slSequence.h" />
-    <ClInclude Include="include\slony\slSet.h" />
-    <ClInclude Include="include\slony\slSubscription.h" />
-    <ClInclude Include="include\slony\slTable.h" />
-    <ClInclude Include="include\dlg\dlgAddFavourite.h" />
-    <ClInclude Include="include\dlg\dlgAggregate.h" />
-    <ClInclude Include="include\dlg\dlgCast.h" />
-    <ClInclude Include="include\dlg\dlgCheck.h" />
-    <ClInclude Include="include\dlg\dlgClasses.h" />
-    <ClInclude Include="include\dlg\dlgCollation.h" />
-    <ClInclude Include="include\dlg\dlgColumn.h" />
-    <ClInclude Include="include\dlg\dlgConnect.h" />
-    <ClInclude Include="include\dlg\dlgConversion.h" />
-    <ClInclude Include="include\dlg\dlgDatabase.h" />
-    <ClInclude Include="include\dlg\dlgDomain.h" />
-    <ClInclude Include="include\dlg\dlgEditGridOptions.h" />
-    <ClInclude Include="include\dlg\dlgExtension.h" />
-    <ClInclude Include="include\dlg\dlgExtTable.h" />
-    <ClInclude Include="include\dlg\dlgFindReplace.h" />
-    <ClInclude Include="include\dlg\dlgForeignDataWrapper.h" />
-    <ClInclude Include="include\dlg\dlgForeignKey.h" />
-    <ClInclude Include="include\dlg\dlgForeignServer.h" />
-    <ClInclude Include="include\dlg\dlgForeignTable.h" />
-    <ClInclude Include="include\dlg\dlgFunction.h" />
-    <ClInclude Include="include\dlg\dlgGroup.h" />
-    <ClInclude Include="include\dlg\dlgHbaConfig.h" />
-    <ClInclude Include="include\dlg\dlgIndex.h" />
-    <ClInclude Include="include\dlg\dlgIndexConstraint.h" />
-    <ClInclude Include="include\dlg\dlgLanguage.h" />
-    <ClInclude Include="include\dlg\dlgMainConfig.h" />
-    <ClInclude Include="include\dlg\dlgManageFavourites.h" />
-    <ClInclude Include="include\dlg\dlgManageMacros.h" />
-    <ClInclude Include="include\dlg\dlgOperator.h" />
-    <ClInclude Include="include\dlg\dlgPackage.h" />
-    <ClInclude Include="include\dlg\dlgPgpassConfig.h" />
-    <ClInclude Include="include\dlg\dlgProperty.h" />
-    <ClInclude Include="include\dlg\dlgReassignDropOwned.h" />
-    <ClInclude Include="include\dlg\dlgRole.h" />
-    <ClInclude Include="include\dlg\dlgRule.h" />
-    <ClInclude Include="include\dlg\dlgSchema.h" />
-    <ClInclude Include="include\dlg\dlgSearchObject.h" />
-    <ClInclude Include="include\dlg\dlgSelectConnection.h" />
-    <ClInclude Include="include\dlg\dlgSelectDatabase.h" />
-    <ClInclude Include="include\dlg\dlgSequence.h" />
-    <ClInclude Include="include\dlg\dlgServer.h" />
-    <ClInclude Include="include\dlg\dlgSynonym.h" />
-    <ClInclude Include="include\dlg\dlgTable.h" />
-    <ClInclude Include="include\dlg\dlgTablespace.h" />
-    <ClInclude Include="include\dlg\dlgTextSearchConfiguration.h" />
-    <ClInclude Include="include\dlg\dlgTextSearchDictionary.h" />
-    <ClInclude Include="include\dlg\dlgTextSearchParser.h" />
-    <ClInclude Include="include\dlg\dlgTextSearchTemplate.h" />
-    <ClInclude Include="include\dlg\dlgTrigger.h" />
-    <ClInclude Include="include\dlg\dlgType.h" />
-    <ClInclude Include="include\dlg\dlgUser.h" />
-    <ClInclude Include="include\dlg\dlgUserMapping.h" />
-    <ClInclude Include="include\dlg\dlgView.h" />
-    <ClInclude Include="include\frm\frmAbout.h" />
-    <ClInclude Include="include\frm\frmBackup.h" />
-    <ClInclude Include="include\frm\frmBackupGlobals.h" />
-    <ClInclude Include="include\frm\frmBackupServer.h" />
-    <ClInclude Include="include\frm\frmConfig.h" />
-    <ClInclude Include="include\frm\frmDatabaseDesigner.h" />
-    <ClInclude Include="include\frm\frmEditGrid.h" />
-    <ClInclude Include="include\frm\frmExport.h" />
-    <ClInclude Include="include\frm\frmGrantWizard.h" />
-    <ClInclude Include="include\frm\frmHbaConfig.h" />
-    <ClInclude Include="include\frm\frmHint.h" />
-    <ClInclude Include="include\frm\frmImport.h" />
-    <ClInclude Include="include\frm\frmMain.h" />
-    <ClInclude Include="include\frm\frmMainConfig.h" />
-    <ClInclude Include="include\frm\frmMaintenance.h" />
-    <ClInclude Include="include\frm\frmOptions.h" />
-    <ClInclude Include="include\frm\frmPassword.h" />
-    <ClInclude Include="include\frm\frmPgpassConfig.h" />
-    <ClInclude Include="include\frm\frmQuery.h" />
-    <ClInclude Include="include\frm\frmReport.h" />
-    <ClInclude Include="include\frm\frmRestore.h" />
-    <ClInclude Include="include\frm\frmSplash.h" />
-    <ClInclude Include="include\frm\frmStatus.h" />
-    <ClInclude Include="include\frm\menu.h" />
-    <ClInclude Include="include\schema\edbPackage.h" />
-    <ClInclude Include="include\schema\edbPackageFunction.h" />
-    <ClInclude Include="include\schema\edbPackageVariable.h" />
-    <ClInclude Include="include\schema\edbPrivateSynonym.h" />
-    <ClInclude Include="include\schema\edbSynonym.h" />
-    <ClInclude Include="include\schema\gpExtTable.h" />
-    <ClInclude Include="include\schema\gpPartition.h" />
-    <ClInclude Include="include\schema\gpResQueue.h" />
-    <ClInclude Include="include\schema\pgAggregate.h" />
-    <ClInclude Include="include\schema\pgCast.h" />
-    <ClInclude Include="include\schema\pgCatalogObject.h" />
-    <ClInclude Include="include\schema\pgCheck.h" />
-    <ClInclude Include="include\schema\pgCollation.h" />
-    <ClInclude Include="include\schema\pgCollection.h" />
-    <ClInclude Include="include\schema\pgColumn.h" />
-    <ClInclude Include="include\schema\pgConstraints.h" />
-    <ClInclude Include="include\schema\pgConversion.h" />
-    <ClInclude Include="include\schema\pgDatabase.h" />
-    <ClInclude Include="include\schema\pgDatatype.h" />
-    <ClInclude Include="include\schema\pgDomain.h" />
-    <ClInclude Include="include\schema\pgExtension.h" />
-    <ClInclude Include="include\schema\pgForeignDataWrapper.h" />
-    <ClInclude Include="include\schema\pgForeignKey.h" />
-    <ClInclude Include="include\schema\pgForeignServer.h" />
-    <ClInclude Include="include\schema\pgForeignTable.h" />
-    <ClInclude Include="include\schema\pgFunction.h" />
-    <ClInclude Include="include\schema\pgGroup.h" />
-    <ClInclude Include="include\schema\pgIndex.h" />
-    <ClInclude Include="include\schema\pgIndexConstraint.h" />
-    <ClInclude Include="include\schema\pgLanguage.h" />
-    <ClInclude Include="include\schema\pgObject.h" />
-    <ClInclude Include="include\schema\pgOperator.h" />
-    <ClInclude Include="include\schema\pgOperatorClass.h" />
-    <ClInclude Include="include\schema\pgOperatorFamily.h" />
-    <ClInclude Include="include\schema\pgRole.h" />
-    <ClInclude Include="include\schema\pgRule.h" />
-    <ClInclude Include="include\schema\pgSchema.h" />
-    <ClInclude Include="include\schema\pgSequence.h" />
-    <ClInclude Include="include\schema\pgServer.h" />
-    <ClInclude Include="include\schema\pgTable.h" />
-    <ClInclude Include="include\schema\pgTablespace.h" />
-    <ClInclude Include="include\schema\pgTextSearchConfiguration.h" />
-    <ClInclude Include="include\schema\pgTextSearchDictionary.h" />
-    <ClInclude Include="include\schema\pgTextSearchParser.h" />
-    <ClInclude Include="include\schema\pgTextSearchTemplate.h" />
-    <ClInclude Include="include\schema\pgTrigger.h" />
-    <ClInclude Include="include\schema\pgType.h" />
-    <ClInclude Include="include\schema\pgUser.h" />
-    <ClInclude Include="include\schema\pgUserMapping.h" />
-    <ClInclude Include="include\schema\pgView.h" />
-    <ClInclude Include="include\db\pgConn.h" />
-    <ClInclude Include="include\db\pgQueryThread.h" />
-    <ClInclude Include="include\db\pgSet.h" />
-    <ClInclude Include="include\debugger\ctlCodeWindow.h" />
-    <ClInclude Include="include\debugger\ctlMessageWindow.h" />
-    <ClInclude Include="include\debugger\ctlResultGrid.h" />
-    <ClInclude Include="include\debugger\ctlStackWindow.h" />
-    <ClInclude Include="include\debugger\ctlTabWindow.h" />
-    <ClInclude Include="include\debugger\ctlVarWindow.h" />
-    <ClInclude Include="include\debugger\dbgBreakPoint.h" />
-    <ClInclude Include="include\debugger\dbgConnProp.h" />
-    <ClInclude Include="include\debugger\dbgConst.h" />
-    <ClInclude Include="include\debugger\dbgDbResult.h" />
-    <ClInclude Include="include\debugger\dbgPgConn.h" />
-    <ClInclude Include="include\debugger\dbgPgThread.h" />
-    <ClInclude Include="include\debugger\dbgResultset.h" />
-    <ClInclude Include="include\debugger\dbgTargetInfo.h" />
-    <ClInclude Include="include\debugger\debugger.h" />
-    <ClInclude Include="include\debugger\dlgDirectDbg.h" />
-    <ClInclude Include="include\debugger\frmDebugger.h" />
-    <ClInclude Include="include\gqb\gqbArrayCollection.h" />
-    <ClInclude Include="include\gqb\gqbBrowser.h" />
-    <ClInclude Include="include\gqb\gqbCollection.h" />
-    <ClInclude Include="include\gqb\gqbCollectionBase.h" />
-    <ClInclude Include="include\gqb\gqbColumn.h" />
-    <ClInclude Include="include\gqb\gqbDatabase.h" />
-    <ClInclude Include="include\gqb\gqbEvents.h" />
-    <ClInclude Include="include\gqb\gqbGraphBehavior.h" />
-    <ClInclude Include="include\gqb\gqbGraphSimple.h" />
-    <ClInclude Include="include\gqb\gqbGridJoinTable.h" />
-    <ClInclude Include="include\gqb\gqbGridOrderTable.h" />
-    <ClInclude Include="include\gqb\gqbGridProjTable.h" />
-    <ClInclude Include="include\gqb\gqbGridRestTable.h" />
-    <ClInclude Include="include\gqb\gqbModel.h" />
-    <ClInclude Include="include\gqb\gqbObject.h" />
-    <ClInclude Include="include\gqb\gqbObjectCollection.h" />
-    <ClInclude Include="include\gqb\gqbQueryObjs.h" />
-    <ClInclude Include="include\gqb\gqbSchema.h" />
-    <ClInclude Include="include\gqb\gqbTable.h" />
-    <ClInclude Include="include\gqb\gqbViewController.h" />
-    <ClInclude Include="include\gqb\gqbViewPanels.h" />
-    <ClInclude Include="include\pgscript\FlexLexer.h" />
-    <ClInclude Include="include\pgscript\pgsApplication.h" />
-    <ClInclude Include="include\pgscript\pgScript.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsArithmeticException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsAssertException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsBreakException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsCastException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsContinueException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsInterruptException.h" />
-    <ClInclude Include="include\pgscript\exceptions\pgsParameterException.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsAnd.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsAssign.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsAssignToRecord.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsCast.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsColumns.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsDifferent.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsEqual.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsExecute.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsExpression.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsExpressions.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenDate.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenDateTime.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenDictionary.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenInt.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenReal.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenReference.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenRegex.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenString.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGenTime.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGreater.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsGreaterEqual.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsIdent.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsIdentRecord.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsLines.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsLower.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsLowerEqual.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsMinus.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsModulo.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsNegate.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsNot.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsOperation.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsOr.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsOver.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsParenthesis.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsPlus.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsRemoveLine.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsTimes.h" />
-    <ClInclude Include="include\pgscript\expressions\pgsTrim.h" />
-    <ClInclude Include="include\pgscript\generators\pgsDateGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsDateTimeGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsDictionaryGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsIntegerGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsNumberGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsObjectGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsRealGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsReferenceGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsRegexGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsStringGen.h" />
-    <ClInclude Include="include\pgscript\generators\pgsTimeGen.h" />
-    <ClInclude Include="include\pgscript\objects\pgsGenerator.h" />
-    <ClInclude Include="include\pgscript\objects\pgsNumber.h" />
-    <ClInclude Include="include\pgscript\objects\pgsObjects.h" />
-    <ClInclude Include="include\pgscript\objects\pgsRecord.h" />
-    <ClInclude Include="include\pgscript\objects\pgsString.h" />
-    <ClInclude Include="include\pgscript\objects\pgsVariable.h" />
-    <ClInclude Include="include\pgscript\statements\pgsAssertStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsBreakStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsContinueStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsDeclareRecordStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsExpressionStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsIfStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsPrintStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsProgram.h" />
-    <ClInclude Include="include\pgscript\statements\pgsStatements.h" />
-    <ClInclude Include="include\pgscript\statements\pgsStmt.h" />
-    <ClInclude Include="include\pgscript\statements\pgsStmtList.h" />
-    <ClInclude Include="include\pgscript\statements\pgsWhileStmt.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsAlloc.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsContext.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsCopiedPtr.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsDriver.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsMapm.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsScanner.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsSharedPtr.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsThread.h" />
-    <ClInclude Include="include\pgscript\utilities\pgsUtilities.h" />
-    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm.h" />
-    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm_lc.h" />
-    <ClInclude Include="include\ogl\basic.h" />
-    <ClInclude Include="include\ogl\basicp.h" />
-    <ClInclude Include="include\ogl\bmpshape.h" />
-    <ClInclude Include="include\ogl\canvas.h" />
-    <ClInclude Include="include\ogl\composit.h" />
-    <ClInclude Include="include\ogl\constrnt.h" />
-    <ClInclude Include="include\ogl\divided.h" />
-    <ClInclude Include="include\ogl\drawn.h" />
-    <ClInclude Include="include\ogl\drawnp.h" />
-    <ClInclude Include="include\ogl\lines.h" />
-    <ClInclude Include="include\ogl\linesp.h" />
-    <ClInclude Include="include\ogl\mfutils.h" />
-    <ClInclude Include="include\ogl\misc.h" />
-    <ClInclude Include="include\ogl\ogl.h" />
-    <ClInclude Include="include\ogl\ogldiag.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddColumnFigure.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddColumnKindIcon.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddColumnOptionIcon.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddRelationshipFigure.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddRelationshipItem.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddRelationshipTerminal.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddTableFigure.h" />
-    <ClInclude Include="include\dd\dditems\figures\ddTextTableItemFigure.h" />
-    <ClInclude Include="include\dd\dditems\figures\xml\ddXmlStorage.h" />
-    <ClInclude Include="include\dd\dditems\handles\ddAddColButtonHandle.h" />
-    <ClInclude Include="include\dd\dditems\handles\ddAddFkButtonHandle.h" />
-    <ClInclude Include="include\dd\dditems\handles\ddMinMaxTableButtonHandle.h" />
-    <ClInclude Include="include\dd\dditems\handles\ddRemoveTableButtonHandle.h" />
-    <ClInclude Include="include\dd\dditems\handles\ddScrollBarHandle.h" />
-    <ClInclude Include="include\dd\dditems\handles\ddSouthTableSizeHandle.h" />
-    <ClInclude Include="include\dd\dditems\locators\ddAddColLocator.h" />
-    <ClInclude Include="include\dd\dditems\locators\ddAddFkLocator.h" />
-    <ClInclude Include="include\dd\dditems\locators\ddMinMaxTableLocator.h" />
-    <ClInclude Include="include\dd\dditems\locators\ddRemoveTableLocator.h" />
-    <ClInclude Include="include\dd\dditems\locators\ddScrollBarTableLocator.h" />
-    <ClInclude Include="include\dd\dditems\locators\ddTableBottomLocator.h" />
-    <ClInclude Include="include\dd\dditems\tools\ddColumnFigureTool.h" />
-    <ClInclude Include="include\dd\dditems\tools\ddColumnTextTool.h" />
-    <ClInclude Include="include\dd\dditems\utilities\ddDataType.h" />
-    <ClInclude Include="include\dd\dditems\utilities\ddPrecisionScaleDialog.h" />
-    <ClInclude Include="include\dd\dditems\utilities\ddSelectKindFksDialog.h" />
-    <ClInclude Include="include\dd\dditems\utilities\ddTableNameDialog.h" />
-    <ClInclude Include="include\dd\ddmodel\ddBrowserDataContainer.h" />
-    <ClInclude Include="include\dd\ddmodel\ddDatabaseDesign.h" />
-    <ClInclude Include="include\dd\ddmodel\ddDBReverseEngineering.h" />
-    <ClInclude Include="include\dd\ddmodel\ddDrawingEditor.h" />
-    <ClInclude Include="include\dd\ddmodel\ddDrawingView.h" />
-    <ClInclude Include="include\dd\ddmodel\ddGenerationWizard.h" />
-    <ClInclude Include="include\dd\ddmodel\ddModelBrowser.h" />
-    <ClInclude Include="include\hotdraw\connectors\hdChopBoxConnector.h" />
-    <ClInclude Include="include\hotdraw\connectors\hdIConnector.h" />
-    <ClInclude Include="include\hotdraw\connectors\hdLocatorConnector.h" />
-    <ClInclude Include="include\hotdraw\connectors\hdStickyRectangleConnector.h" />
-    <ClInclude Include="include\hotdraw\figures\hdAbstractFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdAbstractMenuFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdAttribute.h" />
-    <ClInclude Include="include\hotdraw\figures\hdAttributeFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdBitmapFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdCompositeFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdIConnectionFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdIFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdLineConnection.h" />
-    <ClInclude Include="include\hotdraw\figures\hdLineTerminal.h" />
-    <ClInclude Include="include\hotdraw\figures\hdPolyLineFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdRectangleFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\hdSimpleTextFigure.h" />
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFillAttribute.h" />
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontAttribute.h" />
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontColorAttribute.h" />
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdLineAttribute.h" />
-    <ClInclude Include="include\hotdraw\figures\xml\hdStorage.h" />
-    <ClInclude Include="include\hotdraw\handles\hdButtonHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionEndHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionStartHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdIHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdLineConnectionHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdLocatorHandle.h" />
-    <ClInclude Include="include\hotdraw\handles\hdPolyLineHandle.h" />
-    <ClInclude Include="include\hotdraw\locators\hdILocator.h" />
-    <ClInclude Include="include\hotdraw\locators\hdPolyLineLocator.h" />
-    <ClInclude Include="include\hotdraw\main\hdDrawing.h" />
-    <ClInclude Include="include\hotdraw\main\hdDrawingEditor.h" />
-    <ClInclude Include="include\hotdraw\main\hdDrawingView.h" />
-    <ClInclude Include="include\hotdraw\main\hdObject.h" />
-    <ClInclude Include="include\hotdraw\tools\hdAbstractTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdCanvasMenuTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdCompositeFigureTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdConnectionCreationTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdCreationTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdDragCreationTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdDragTrackerTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdFigureTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdHandleTrackerTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdITool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdMenuTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdPolyLineFigureTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdSelectAreaTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdSelectionTool.h" />
-    <ClInclude Include="include\hotdraw\tools\hdSimpleTextTool.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdArrayCollection.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdCollection.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdCollectionBase.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdGeometry.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdKeyEvent.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdMouseEvent.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdMultiPosRect.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdPoint.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdRect.h" />
-    <ClInclude Include="include\hotdraw\utilities\hdRemoveDeleteDialog.h" />
-  </ItemGroup>
-  <ItemGroup>
-    <png2c Include="include\images\aggregate-sm.png" />
-    <png2c Include="include\images\aggregate.png" />
-    <png2c Include="include\images\aggregates.png" />
-    <png2c Include="include\images\back.png" />
-    <png2c Include="include\images\backup.png" />
-    <png2c Include="include\images\baddatabase.png" />
-    <png2c Include="include\images\cast-sm.png" />
-    <png2c Include="include\images\cast.png" />
-    <png2c Include="include\images\casts.png" />
-    <png2c Include="include\images\catalog-sm.png" />
-    <png2c Include="include\images\catalog.png" />
-    <png2c Include="include\images\catalogobject-sm.png" />
-    <png2c Include="include\images\catalogobject.png" />
-    <png2c Include="include\images\catalogobjects.png" />
-    <png2c Include="include\images\catalogs.png" />
-    <png2c Include="include\images\check.png" />
-    <png2c Include="include\images\checkbad.png" />
-    <png2c Include="include\images\checked.png" />
-    <png2c Include="include\images\clearAll.png" />
-    <png2c Include="include\images\clip_copy.png" />
-    <png2c Include="include\images\clip_cut.png" />
-    <png2c Include="include\images\clip_paste.png" />
-    <png2c Include="include\images\closeddatabase-sm.png" />
-    <png2c Include="include\images\closeddatabase.png" />
-    <png2c Include="include\images\collation-sm.png" />
-    <png2c Include="include\images\collation.png" />
-    <png2c Include="include\images\collations.png" />
-    <png2c Include="include\images\column-sm.png" />
-    <png2c Include="include\images\column.png" />
-    <png2c Include="include\images\columns.png" />
-    <png2c Include="include\images\configuration.png" />
-    <png2c Include="include\images\configurations.png" />
-    <png2c Include="include\images\connect.png" />
-    <png2c Include="include\images\constraints.png" />
-    <png2c Include="include\images\continue.png" />
-    <png2c Include="include\images\conversion.png" />
-    <png2c Include="include\images\conversions.png" />
-    <png2c Include="include\images\create.png" />
-    <png2c Include="include\images\database-sm.png" />
-    <png2c Include="include\images\database.png" />
-    <png2c Include="include\images\databases.png" />
-    <png2c Include="include\images\ddAddColumn.png" />
-    <png2c Include="include\images\ddAddColumnCursor.png" />
-    <png2c Include="include\images\ddAddForeignKey.png" />
-    <png2c Include="include\images\ddcancel.png" />
-    <png2c Include="include\images\ddDeleteTableCursor.png" />
-    <png2c Include="include\images\ddDown.png" />
-    <png2c Include="include\images\ddforeignkey.png" />
-    <png2c Include="include\images\ddforeignkeyfromuk.png" />
-    <png2c Include="include\images\ddforeignkeyuniquekey.png" />
-    <png2c Include="include\images\ddforeignkeyuniquekeyfromuk.png" />
-    <png2c Include="include\images\ddgendiagram.png" />
-    <png2c Include="include\images\ddMaximizeTable.png" />
-    <png2c Include="include\images\ddMinimizeTable.png" />
-    <png2c Include="include\images\ddMinMaxCursor.png" />
-    <png2c Include="include\images\ddmodel-32.png" />
-    <png2c Include="include\images\ddnewdiagram.png" />
-    <png2c Include="include\images\ddnotnull.png" />
-    <png2c Include="include\images\ddnull.png" />
-    <png2c Include="include\images\ddprimaryforeignkey.png" />
-    <png2c Include="include\images\ddprimaryforeignkeyfromuk.png" />
-    <png2c Include="include\images\ddprimarykey.png" />
-    <png2c Include="include\images\ddprimarykeyuniquekey.png" />
-    <png2c Include="include\images\ddRelationshipCursor.png" />
-    <png2c Include="include\images\ddRemoveColumn.png" />
-    <png2c Include="include\images\ddRemoveColumnCursor.png" />
-    <png2c Include="include\images\ddRemoveTable.png" />
-    <png2c Include="include\images\ddRemoveTable2.png" />
-    <png2c Include="include\images\ddunique.png" />
-    <png2c Include="include\images\ddUp.png" />
-    <png2c Include="include\images\debugger.png" />
-    <png2c Include="include\images\delete.png" />
-    <png2c Include="include\images\dictionaries.png" />
-    <png2c Include="include\images\dictionary.png" />
-    <png2c Include="include\images\disabled.png" />
-    <png2c Include="include\images\dnd_copy.png" />
-    <png2c Include="include\images\dnd_move.png" />
-    <png2c Include="include\images\dnd_none.png" />
-    <png2c Include="include\images\domain-sm.png" />
-    <png2c Include="include\images\domain.png" />
-    <png2c Include="include\images\domains.png" />
-    <png2c Include="include\images\down.png" />
-    <png2c Include="include\images\drop.png" />
-    <png2c Include="include\images\edit_clear.png" />
-    <png2c Include="include\images\edit_find.png" />
-    <png2c Include="include\images\edit_redo.png" />
-    <png2c Include="include\images\edit_undo.png" />
-    <png2c Include="include\images\enumeration.png" />
-    <png2c Include="include\images\enumerations.png" />
-    <png2c Include="include\images\ex_aggregate.png" />
-    <png2c Include="include\images\ex_append.png" />
-    <png2c Include="include\images\ex_bmp_heap.png" />
-    <png2c Include="include\images\ex_bmp_index.png" />
-    <png2c Include="include\images\ex_broadcast_motion.png" />
-    <png2c Include="include\images\ex_cte_scan.png" />
-    <png2c Include="include\images\ex_gather_motion.png" />
-    <png2c Include="include\images\ex_group.png" />
-    <png2c Include="include\images\ex_hash.png" />
-    <png2c Include="include\images\ex_hash_anti_join.png" />
-    <png2c Include="include\images\ex_hash_semi_join.png" />
-    <png2c Include="include\images\ex_hash_setop_except.png" />
-    <png2c Include="include\images\ex_hash_setop_except_all.png" />
-    <png2c Include="include\images\ex_hash_setop_intersect.png" />
-    <png2c Include="include\images\ex_hash_setop_intersect_all.png" />
-    <png2c Include="include\images\ex_hash_setop_unknown.png" />
-    <png2c Include="include\images\ex_index_scan.png" />
-    <png2c Include="include\images\ex_join.png" />
-    <png2c Include="include\images\ex_limit.png" />
-    <png2c Include="include\images\ex_materialize.png" />
-    <png2c Include="include\images\ex_merge.png" />
-    <png2c Include="include\images\ex_merge_anti_join.png" />
-    <png2c Include="include\images\ex_merge_semi_join.png" />
-    <png2c Include="include\images\ex_nested.png" />
-    <png2c Include="include\images\ex_nested_loop_anti_join.png" />
-    <png2c Include="include\images\ex_nested_loop_semi_join.png" />
-    <png2c Include="include\images\ex_recursive_union.png" />
-    <png2c Include="include\images\ex_redistribute_motion.png" />
-    <png2c Include="include\images\ex_result.png" />
-    <png2c Include="include\images\ex_scan.png" />
-    <png2c Include="include\images\ex_seek.png" />
-    <png2c Include="include\images\ex_setop.png" />
-    <png2c Include="include\images\ex_sort.png" />
-    <png2c Include="include\images\ex_subplan.png" />
-    <png2c Include="include\images\ex_tid_scan.png" />
-    <png2c Include="include\images\ex_unique.png" />
-    <png2c Include="include\images\ex_unknown.png" />
-    <png2c Include="include\images\ex_window_aggregate.png" />
-    <png2c Include="include\images\ex_worktable_scan.png" />
-    <png2c Include="include\images\exclude.png" />
-    <png2c Include="include\images\extension-sm.png" />
-    <png2c Include="include\images\extension.png" />
-    <png2c Include="include\images\extensions.png" />
-    <png2c Include="include\images\exttable-sm.png" />
-    <png2c Include="include\images\exttable.png" />
-    <png2c Include="include\images\exttables.png" />
-    <png2c Include="include\images\favourite.png" />
-    <png2c Include="include\images\file_new.png" />
-    <png2c Include="include\images\file_open.png" />
-    <png2c Include="include\images\file_save.png" />
-    <png2c Include="include\images\folder.png" />
-    <png2c Include="include\images\foreigndatawrapper-sm.png" />
-    <png2c Include="include\images\foreigndatawrapper.png" />
-    <png2c Include="include\images\foreigndatawrappers.png" />
-    <png2c Include="include\images\foreignkey.png" />
-    <png2c Include="include\images\foreignkeybad.png" />
-    <png2c Include="include\images\foreignserver-sm.png" />
-    <png2c Include="include\images\foreignserver.png" />
-    <png2c Include="include\images\foreignservers.png" />
-    <png2c Include="include\images\foreigntable.png" />
-    <png2c Include="include\images\foreigntables.png" />
-    <png2c Include="include\images\forward.png" />
-    <png2c Include="include\images\function.png" />
-    <png2c Include="include\images\functions.png" />
-    <png2c Include="include\images\gqbAdd.png" />
-    <png2c Include="include\images\gqbAddRest.png" />
-    <png2c Include="include\images\gqbColNotSel.png" />
-    <png2c Include="include\images\gqbColSel.png" />
-    <png2c Include="include\images\gqbDown.png" />
-    <png2c Include="include\images\gqbDownBottom.png" />
-    <png2c Include="include\images\gqbJoin.png" />
-    <png2c Include="include\images\gqbJoinCursor.png" />
-    <png2c Include="include\images\gqbOrderAdd.png" />
-    <png2c Include="include\images\gqbOrderAddAll.png" />
-    <png2c Include="include\images\gqbOrderRemove.png" />
-    <png2c Include="include\images\gqbOrderRemoveAll.png" />
-    <png2c Include="include\images\gqbRemove.png" />
-    <png2c Include="include\images\gqbRemoveRest.png" />
-    <png2c Include="include\images\gqbUp.png" />
-    <png2c Include="include\images\gqbUpTop.png" />
-    <png2c Include="include\images\group.png" />
-    <png2c Include="include\images\groups.png" />
-    <png2c Include="include\images\help.png" />
-    <png2c Include="include\images\help2.png" />
-    <png2c Include="include\images\hint.png" />
-    <png2c Include="include\images\hint2.png" />
-    <png2c Include="include\images\index.png" />
-    <png2c Include="include\images\indexes.png" />
-    <png2c Include="include\images\job.png" />
-    <png2c Include="include\images\jobdisabled.png" />
-    <png2c Include="include\images\jobs.png" />
-    <png2c Include="include\images\key.png" />
-    <png2c Include="include\images\language-sm.png" />
-    <png2c Include="include\images\language.png" />
-    <png2c Include="include\images\languages.png" />
-    <png2c Include="include\images\loginroles.png" />
-    <png2c Include="include\images\namespace-sm.png" />
-    <png2c Include="include\images\namespace.png" />
-    <png2c Include="include\images\namespaces.png" />
-    <png2c Include="include\images\operator.png" />
-    <png2c Include="include\images\operatorclass.png" />
-    <png2c Include="include\images\operatorclasses.png" />
-    <png2c Include="include\images\operatorfamilies.png" />
-    <png2c Include="include\images\operatorfamily.png" />
-    <png2c Include="include\images\operators.png" />
-    <png2c Include="include\images\package.png" />
-    <png2c Include="include\images\packages.png" />
-    <png2c Include="include\images\parser.png" />
-    <png2c Include="include\images\parsers.png" />
-    <png2c Include="include\images\pgAdmin3-16.png" />
-    <png2c Include="include\images\pgAdmin3-32.png" />
-    <png2c Include="include\images\pgAdmin3.png" />
-    <png2c Include="include\images\plugins.png" />
-    <png2c Include="include\images\primarykey.png" />
-    <png2c Include="include\images\procedure.png" />
-    <png2c Include="include\images\procedures.png" />
-    <png2c Include="include\images\properties.png" />
-    <png2c Include="include\images\property.png" />
-    <png2c Include="include\images\query_cancel.png" />
-    <png2c Include="include\images\query_execfile.png" />
-    <png2c Include="include\images\query_execute.png" />
-    <png2c Include="include\images\query_explain.png" />
-    <png2c Include="include\images\query_pgscript.png" />
-    <png2c Include="include\images\readdata.png" />
-    <png2c Include="include\images\refresh.png" />
-    <png2c Include="include\images\reload.png" />
-    <png2c Include="include\images\restore.png" />
-    <png2c Include="include\images\roles.png" />
-    <png2c Include="include\images\rule.png" />
-    <png2c Include="include\images\rulebad.png" />
-    <png2c Include="include\images\rules.png" />
-    <png2c Include="include\images\schedule.png" />
-    <png2c Include="include\images\schedules.png" />
-    <png2c Include="include\images\sequence-repl.png" />
-    <png2c Include="include\images\sequence.png" />
-    <png2c Include="include\images\sequences.png" />
-    <png2c Include="include\images\server-sm.png" />
-    <png2c Include="include\images\server.png" />
-    <png2c Include="include\images\serverbad-sm.png" />
-    <png2c Include="include\images\serverbad.png" />
-    <png2c Include="include\images\servers.png" />
-    <png2c Include="include\images\setBreak.png" />
-    <png2c Include="include\images\slcluster.png" />
-    <png2c Include="include\images\slclusters.png" />
-    <png2c Include="include\images\sllisten.png" />
-    <png2c Include="include\images\sllistens.png" />
-    <png2c Include="include\images\slnode-disabled.png" />
-    <png2c Include="include\images\slnode-local.png" />
-    <png2c Include="include\images\slnode.png" />
-    <png2c Include="include\images\slnodes.png" />
-    <png2c Include="include\images\slpath.png" />
-    <png2c Include="include\images\slpaths.png" />
-    <png2c Include="include\images\slset.png" />
-    <png2c Include="include\images\slset2.png" />
-    <png2c Include="include\images\slsets.png" />
-    <png2c Include="include\images\slsubscription.png" />
-    <png2c Include="include\images\slsubscription2.png" />
-    <png2c Include="include\images\slsubscriptions.png" />
-    <png2c Include="include\images\sortfilter.png" />
-    <png2c Include="include\images\splash.png" />
-    <png2c Include="include\images\sql-16.png" />
-    <png2c Include="include\images\sql-32.png" />
-    <png2c Include="include\images\sql.png" />
-    <png2c Include="include\images\statistics.png" />
-    <png2c Include="include\images\step.png" />
-    <png2c Include="include\images\stepInto.png" />
-    <png2c Include="include\images\stepOver.png" />
-    <png2c Include="include\images\steps.png" />
-    <png2c Include="include\images\stop.png" />
-    <png2c Include="include\images\storedata.png" />
-    <png2c Include="include\images\synonym.png" />
-    <png2c Include="include\images\synonyms.png" />
-    <png2c Include="include\images\table-repl-sm.png" />
-    <png2c Include="include\images\table-repl.png" />
-    <png2c Include="include\images\table-sm.png" />
-    <png2c Include="include\images\table.png" />
-    <png2c Include="include\images\tables.png" />
-    <png2c Include="include\images\tablespace.png" />
-    <png2c Include="include\images\tablespaces.png" />
-    <png2c Include="include\images\template.png" />
-    <png2c Include="include\images\templates.png" />
-    <png2c Include="include\images\terminate_backend.png" />
-    <png2c Include="include\images\textsearch.png" />
-    <png2c Include="include\images\trigger.png" />
-    <png2c Include="include\images\triggerbad.png" />
-    <png2c Include="include\images\triggerfunction.png" />
-    <png2c Include="include\images\triggerfunctions.png" />
-    <png2c Include="include\images\triggers.png" />
-    <png2c Include="include\images\type.png" />
-    <png2c Include="include\images\types.png" />
-    <png2c Include="include\images\uncheck.png" />
-    <png2c Include="include\images\unchecked.png" />
-    <png2c Include="include\images\unique.png" />
-    <png2c Include="include\images\up.png" />
-    <png2c Include="include\images\user.png" />
-    <png2c Include="include\images\usermapping-sm.png" />
-    <png2c Include="include\images\usermapping.png" />
-    <png2c Include="include\images\usermappings.png" />
-    <png2c Include="include\images\users.png" />
-    <png2c Include="include\images\vacuum.png" />
-    <png2c Include="include\images\variable.png" />
-    <png2c Include="include\images\variables.png" />
-    <png2c Include="include\images\view-sm.png" />
-    <png2c Include="include\images\view.png" />
-    <png2c Include="include\images\viewdata.png" />
-    <png2c Include="include\images\viewfiltereddata.png" />
-    <png2c Include="include\images\views.png" />
-  </ItemGroup>
-  <ItemGroup>
-    <ResourceCompile Include="pgAdmin3.rc" />
-  </ItemGroup>
-  <ItemGroup>
-    <ProjectReference Include="..\xtra\png2c\png2c.vcxproj">
-      <Project>{01191fb5-0037-4e36-ba56-07ce9d9d8cc0}</Project>
-      <ReferenceOutputAssembly>false</ReferenceOutputAssembly>
-    </ProjectReference>
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-    <Import Project="..\pgAdmin3.targets" />
-  </ImportGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug (2.9)|Win32">
+      <Configuration>Debug (2.9)</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Debug (2.9)|x64">
+      <Configuration>Debug (2.9)</Configuration>
+      <Platform>x64</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Debug|x64">
+      <Configuration>Debug</Configuration>
+      <Platform>x64</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release (2.9)|Win32">
+      <Configuration>Release (2.9)</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release (2.9)|x64">
+      <Configuration>Release (2.9)</Configuration>
+      <Platform>x64</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|x64">
+      <Configuration>Release</Configuration>
+      <Platform>x64</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{5C2D73BA-1F24-48F8-8233-85F5D672AA6A}</ProjectGuid>
+    <RootNamespace>pgAdmin3</RootNamespace>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseOfMfc>false</UseOfMfc>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+    <Import Project="..\pgAdmin3.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'" Label="PropertySheets">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+    <Import Project="$(VCTargetsPath)Microsoft.CPP.UpgradeFromVC60.props" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup>
+    <_ProjectFileVersion>10.0.30319.1</_ProjectFileVersion>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">.\Release\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">.\Release\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(Platform)\$(Configuration)\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(Platform)\$(Configuration)\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release|x64'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">.\Debug\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">.\Debug\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(Platform)\$(Configuration)\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(Platform)\$(Configuration)\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(Configuration)\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(Configuration)\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(Platform)\$(Configuration)\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(Platform)\$(Configuration)\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(Configuration)\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(Configuration)\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">true</LinkIncremental>
+    <OutDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(Platform)\$(Configuration)\</OutDir>
+    <IntDir Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(Platform)\$(Configuration)\</IntDir>
+    <LinkIncremental Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">true</LinkIncremental>
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <PreBuildEvent>
+      <Message>Extracting source code repository version</Message>
+      <Command>ver_svn.bat</Command>
+    </PreBuildEvent>
+    <Midl>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>Win32</TargetEnvironment>
+      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>MaxSpeed</Optimization>
+      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
+      <AdditionalIncludeDirectories>$(OPENSSL)/include;$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;$(PROJECTDIR)/include;$(PGDIR)/include/server;$(PROJECTDIR)/include/libssh2;$(PROJECTDIR)/include/libssh2/Win32;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;HAVE_OPENSSL_CRYPTO;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <StringPooling>true</StringPooling>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
+      <ObjectFileName>.\Release/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase28u.lib;wxbase28u_xml.lib;wxbase28u_net.lib;wxmsw28u_adv.lib;wxmsw28u_core.lib;wxmsw28u_html.lib;wxmsw28u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw28u_stc.lib;wxmsw28u_xrc.lib;wxexpat.lib;libeay32MD.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(OPENSSL)/lib/VC;$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
+    <Midl>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>X64</TargetEnvironment>
+      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>MaxSpeed</Optimization>
+      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
+      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <StringPooling>true</StringPooling>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
+      <ObjectFileName>.\Release/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase28u.lib;wxbase28u_xml.lib;wxbase28u_net.lib;wxmsw28u_adv.lib;wxmsw28u_core.lib;wxmsw28u_html.lib;wxmsw28u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw28u_stc.lib;wxmsw28u_xrc.lib;wxexpat.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX64</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <PreBuildEvent>
+      <Message>Extracting source code repository version</Message>
+      <Command>ver_svn.bat</Command>
+    </PreBuildEvent>
+    <Midl>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>Win32</TargetEnvironment>
+      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(OPENSSL)/include;$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;$(PROJECTDIR)/include;$(PGDIR)/include/server;$(PROJECTDIR)/include/libssh2;$(PROJECTDIR)/include/libssh2/Win32;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;HAVE_OPENSSL_CRYPTO;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
+      <ObjectFileName>.\Debug/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase28ud.lib;wxbase28ud_xml.lib;wxbase28ud_net.lib;wxmsw28ud_adv.lib;wxmsw28ud_core.lib;wxmsw28ud_html.lib;wxmsw28ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw28ud_stc.lib;wxmsw28ud_xrc.lib;wxexpatd.lib;libeay32MDd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(OPENSSL)/lib/VC;$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <NoEntryPoint>false</NoEntryPoint>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
+    <PreBuildEvent>
+      <Message>Extracting subversion repository version</Message>
+      <Command>ver_svn.bat</Command>
+    </PreBuildEvent>
+    <Midl>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>X64</TargetEnvironment>
+      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
+      <ObjectFileName>.\Debug/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase28ud.lib;wxbase28ud_xml.lib;wxbase28ud_net.lib;wxmsw28ud_adv.lib;wxmsw28ud_core.lib;wxmsw28ud_html.lib;wxmsw28ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw28ud_stc.lib;wxmsw28ud_xrc.lib;wxexpatd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <NoEntryPoint>false</NoEntryPoint>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX64</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
+    <PreBuildEvent>
+      <Message>Extracting source code repository version</Message>
+      <Command>ver_svn.bat</Command>
+    </PreBuildEvent>
+    <Midl>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>Win32</TargetEnvironment>
+      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(OPENSSL)/include;$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;$(PROJECTDIR)/include;$(PGDIR)/include/server;$(PROJECTDIR)/include/libssh2;$(PROJECTDIR)/include/libssh2/Win32;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;HAVE_OPENSSL_CRYPTO;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
+      <ObjectFileName>.\Debug/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase29ud.lib;wxbase29ud_xml.lib;wxbase29ud_net.lib;wxmsw29ud_adv.lib;wxmsw29ud_core.lib;wxmsw29ud_html.lib;wxmsw29ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw29ud_stc.lib;wxmsw29ud_xrc.lib;wxexpatd.lib;libeay32MDd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(OPENSSL)/lib/VC;$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <NoEntryPoint>false</NoEntryPoint>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
+    <PreBuildEvent>
+      <Message>Extracting subversion repository version</Message>
+      <Command>ver_svn.bat</Command>
+    </PreBuildEvent>
+    <Midl>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>X64</TargetEnvironment>
+      <TypeLibraryName>.\Debug/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>Disabled</Optimization>
+      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswud/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;WIN32;_DEBUG;_WINDOWS;__WINDOWS__;__WXMSW__;WXUSINGDLL;DEBUG=1;__WXDEBUG__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;wxUSE_UNICODE=1;UNICODE;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MinimalRebuild>true</MinimalRebuild>
+      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Debug/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Debug/</AssemblerListingLocation>
+      <ObjectFileName>.\Debug/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Debug/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <BrowseInformationFile>.\Debug/</BrowseInformationFile>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <DebugInformationFormat>ProgramDatabase</DebugInformationFormat>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase29ud.lib;wxbase29ud_xml.lib;wxbase29ud_net.lib;wxmsw29ud_adv.lib;wxmsw29ud_core.lib;wxmsw29ud_html.lib;wxmsw29ud_aui.lib;wxregexud.lib;wxpngd.lib;wxzlibd.lib;wxjpegd.lib;wxtiffd.lib;wxmsw29ud_stc.lib;wxmsw29ud_xrc.lib;wxexpatd.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;oleaut32.lib;ole32.lib;shell32.lib;odbc32.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Debug/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrt.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Debug/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Debug/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <NoEntryPoint>false</NoEntryPoint>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX64</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Debug/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
+    <PreBuildEvent>
+      <Message>Extracting source code repository version</Message>
+      <Command>ver_svn.bat</Command>
+    </PreBuildEvent>
+    <Midl>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>Win32</TargetEnvironment>
+      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>MaxSpeed</Optimization>
+      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
+      <AdditionalIncludeDirectories>$(OPENSSL)/include;$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;$(PROJECTDIR)/include;$(PGDIR)/include/server;$(PROJECTDIR)/include/libssh2;$(PROJECTDIR)/include/libssh2/Win32;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;HAVE_OPENSSL_CRYPTO;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <StringPooling>true</StringPooling>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
+      <ObjectFileName>.\Release/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase29u.lib;wxbase29u_xml.lib;wxbase29u_net.lib;wxmsw29u_adv.lib;wxmsw29u_core.lib;wxmsw29u_html.lib;wxmsw29u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw29u_stc.lib;wxmsw29u_xrc.lib;wxexpat.lib;libeay32MD.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(OPENSSL)/lib/VC;$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX86</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
+    <Midl>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <MkTypLibCompatible>true</MkTypLibCompatible>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <TargetEnvironment>X64</TargetEnvironment>
+      <TypeLibraryName>.\Release/pgAdmin3.tlb</TypeLibraryName>
+      <HeaderFileName>
+      </HeaderFileName>
+    </Midl>
+    <ClCompile>
+      <Optimization>MaxSpeed</Optimization>
+      <InlineFunctionExpansion>AnySuitable</InlineFunctionExpansion>
+      <AdditionalIncludeDirectories>$(WXWIN)/lib/vc_dll/mswu/;$(WXWIN)/include;$(WXWIN)/contrib/include;$(PGDIR)/include;$(PGBUILD)/include/;$(PGBUILD)/libxml2/include/;$(PGBUILD)/libxslt/include/;$(PGBUILD)/iconv/include/;include/;$(PGDIR)/include/server;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions>_CRT_SECURE_NO_DEPRECATE=1;NDEBUG;WIN32;_WINDOWS;__WINDOWS__;__WIN95__;__WIN32__;WINVER=0x0400;STRICT;__WXMSW__;WXUSINGDLL;wxUSE_UNICODE=1;UNICODE;EMBED_XRC;PG_SSL;HAVE_CONNINFO_PARSE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <StringPooling>true</StringPooling>
+      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <PrecompiledHeaderFile>pgadmin3.h</PrecompiledHeaderFile>
+      <PrecompiledHeaderOutputFile>.\Release/pgAdmin3.pch</PrecompiledHeaderOutputFile>
+      <AssemblerOutput>All</AssemblerOutput>
+      <AssemblerListingLocation>.\Release/</AssemblerListingLocation>
+      <ObjectFileName>.\Release/</ObjectFileName>
+      <ProgramDataBaseFileName>.\Release/</ProgramDataBaseFileName>
+      <BrowseInformation>true</BrowseInformation>
+      <WarningLevel>Level3</WarningLevel>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+    </ClCompile>
+    <ResourceCompile>
+      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <Culture>0x0809</Culture>
+      <AdditionalIncludeDirectories>$(WXWIN)/include;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+    </ResourceCompile>
+    <Link>
+      <AdditionalDependencies>wxbase29u.lib;wxbase29u_xml.lib;wxbase29u_net.lib;wxmsw29u_adv.lib;wxmsw29u_core.lib;wxmsw29u_html.lib;wxmsw29u_aui.lib;wxregexu.lib;wxpng.lib;wxzlib.lib;wxjpeg.lib;wxtiff.lib;wxmsw29u_stc.lib;wxmsw29u_xrc.lib;wxexpat.lib;libpq.lib;libxml2.lib;libxslt.lib;iconv.lib;comctl32.lib;rpcrt4.lib;wsock32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
+      <OutputFile>.\Release/pgAdmin3.exe</OutputFile>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <AdditionalLibraryDirectories>$(WXWIN)/lib/vc_dll;$(PGDIR)/lib;$(PGBUILD)/lib;$(PGBUILD)/libxml2/lib;$(PGBUILD)/libxslt/lib;$(PGBUILD)/iconv/lib;%(AdditionalLibraryDirectories)</AdditionalLibraryDirectories>
+      <IgnoreSpecificDefaultLibraries>libcd.lib;libcid.lib;msvcrtd.lib;%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <ProgramDatabaseFile>.\Release/pgAdmin3.pdb</ProgramDatabaseFile>
+      <GenerateMapFile>true</GenerateMapFile>
+      <MapFileName>.\Release/pgAdmin3.map</MapFileName>
+      <SubSystem>Windows</SubSystem>
+      <RandomizedBaseAddress>false</RandomizedBaseAddress>
+      <DataExecutionPrevention>
+      </DataExecutionPrevention>
+      <TargetMachine>MachineX64</TargetMachine>
+    </Link>
+    <Bscmake>
+      <SuppressStartupBanner>true</SuppressStartupBanner>
+      <OutputFile>.\Release/pgAdmin3.bsc</OutputFile>
+    </Bscmake>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <ClCompile Include="agent\dlgJob.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="agent\dlgSchedule.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="agent\dlgStep.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="agent\pgaJob.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="agent\pgaSchedule.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="agent\pgaStep.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="ctl\calbox.cpp" />
+    <ClCompile Include="ctl\ctlAuiNotebook.cpp" />
+    <ClCompile Include="ctl\ctlCheckTreeView.cpp" />
+    <ClCompile Include="ctl\ctlColourPicker.cpp" />
+    <ClCompile Include="ctl\ctlComboBox.cpp" />
+    <ClCompile Include="ctl\ctlDefaultSecurityPanel.cpp" />
+    <ClCompile Include="ctl\ctlListView.cpp" />
+    <ClCompile Include="ctl\ctlMenuToolbar.cpp" />
+    <ClCompile Include="ctl\ctlSeclabelPanel.cpp" />
+    <ClCompile Include="ctl\ctlSecurityPanel.cpp" />
+    <ClCompile Include="ctl\ctlSQLBox.cpp" />
+    <ClCompile Include="ctl\ctlSQLGrid.cpp" />
+    <ClCompile Include="ctl\ctlSQLResult.cpp" />
+    <ClCompile Include="ctl\ctlTree.cpp" />
+    <ClCompile Include="ctl\explainCanvas.cpp" />
+    <ClCompile Include="ctl\explainShape.cpp" />
+    <ClCompile Include="ctl\timespin.cpp" />
+    <ClCompile Include="ctl\xh_calb.cpp" />
+    <ClCompile Include="ctl\xh_ctlchecktreeview.cpp" />
+    <ClCompile Include="ctl\xh_ctlcolourpicker.cpp" />
+    <ClCompile Include="ctl\xh_ctlcombo.cpp" />
+    <ClCompile Include="ctl\xh_ctltree.cpp" />
+    <ClCompile Include="ctl\xh_sqlbox.cpp" />
+    <ClCompile Include="ctl\xh_timespin.cpp" />
+    <ClCompile Include="db\keywords.c">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+      </PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
+      </PrecompiledHeader>
+    </ClCompile>
+    <ClCompile Include="db\pgConn.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="db\pgQueryThread.cpp" />
+    <ClCompile Include="db\pgSet.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgAddFavourite.cpp" />
+    <ClCompile Include="dlg\dlgAggregate.cpp" />
+    <ClCompile Include="dlg\dlgCast.cpp" />
+    <ClCompile Include="dlg\dlgCheck.cpp" />
+    <ClCompile Include="dlg\dlgClasses.cpp" />
+    <ClCompile Include="dlg\dlgCollation.cpp" />
+    <ClCompile Include="dlg\dlgColumn.cpp" />
+    <ClCompile Include="dlg\dlgConnect.cpp" />
+    <ClCompile Include="dlg\dlgConversion.cpp" />
+    <ClCompile Include="dlg\dlgDatabase.cpp" />
+    <ClCompile Include="dlg\dlgDomain.cpp" />
+    <ClCompile Include="dlg\dlgEditGridOptions.cpp" />
+    <ClCompile Include="dlg\dlgExtension.cpp" />
+    <ClCompile Include="dlg\dlgExtTable.cpp" />
+    <ClCompile Include="dlg\dlgFindReplace.cpp" />
+    <ClCompile Include="dlg\dlgForeignDataWrapper.cpp" />
+    <ClCompile Include="dlg\dlgForeignKey.cpp" />
+    <ClCompile Include="dlg\dlgForeignServer.cpp" />
+    <ClCompile Include="dlg\dlgForeignTable.cpp" />
+    <ClCompile Include="dlg\dlgFunction.cpp" />
+    <ClCompile Include="dlg\dlgGroup.cpp" />
+    <ClCompile Include="dlg\dlgHbaConfig.cpp" />
+    <ClCompile Include="dlg\dlgIndex.cpp" />
+    <ClCompile Include="dlg\dlgIndexConstraint.cpp" />
+    <ClCompile Include="dlg\dlgLanguage.cpp" />
+    <ClCompile Include="dlg\dlgMainConfig.cpp" />
+    <ClCompile Include="dlg\dlgManageFavourites.cpp" />
+    <ClCompile Include="dlg\dlgManageMacros.cpp" />
+    <ClCompile Include="dlg\dlgOperator.cpp" />
+    <ClCompile Include="dlg\dlgPackage.cpp" />
+    <ClCompile Include="dlg\dlgPgpassConfig.cpp" />
+    <ClCompile Include="dlg\dlgProperty.cpp" />
+    <ClCompile Include="dlg\dlgReassignDropOwned.cpp" />
+    <ClCompile Include="dlg\dlgRole.cpp" />
+    <ClCompile Include="dlg\dlgRule.cpp" />
+    <ClCompile Include="dlg\dlgSchema.cpp" />
+    <ClCompile Include="dlg\dlgSearchObject.cpp" />
+    <ClCompile Include="dlg\dlgSelectConnection.cpp" />
+    <ClCompile Include="dlg\dlgSelectDatabase.cpp" />
+    <ClCompile Include="dlg\dlgSequence.cpp" />
+    <ClCompile Include="dlg\dlgServer.cpp" />
+    <ClCompile Include="dlg\dlgSynonym.cpp" />
+    <ClCompile Include="dlg\dlgTable.cpp" />
+    <ClCompile Include="dlg\dlgTablespace.cpp" />
+    <ClCompile Include="dlg\dlgTextSearchConfiguration.cpp" />
+    <ClCompile Include="dlg\dlgTextSearchDictionary.cpp" />
+    <ClCompile Include="dlg\dlgTextSearchParser.cpp" />
+    <ClCompile Include="dlg\dlgTextSearchTemplate.cpp" />
+    <ClCompile Include="dlg\dlgTrigger.cpp" />
+    <ClCompile Include="dlg\dlgType.cpp" />
+    <ClCompile Include="dlg\dlgUser.cpp" />
+    <ClCompile Include="dlg\dlgUserMapping.cpp" />
+    <ClCompile Include="dlg\dlgView.cpp" />
+    <ClCompile Include="frm\events.cpp" />
+    <ClCompile Include="frm\frmAbout.cpp" />
+    <ClCompile Include="frm\frmBackup.cpp" />
+    <ClCompile Include="frm\frmBackupGlobals.cpp" />
+    <ClCompile Include="frm\frmBackupServer.cpp" />
+    <ClCompile Include="frm\frmConfig.cpp" />
+    <ClCompile Include="frm\frmDatabaseDesigner.cpp" />
+    <ClCompile Include="frm\frmEditGrid.cpp" />
+    <ClCompile Include="frm\frmExport.cpp" />
+    <ClCompile Include="frm\frmGrantWizard.cpp" />
+    <ClCompile Include="frm\frmHbaConfig.cpp" />
+    <ClCompile Include="frm\frmHint.cpp" />
+    <ClCompile Include="frm\frmImport.cpp" />
+    <ClCompile Include="frm\frmMain.cpp" />
+    <ClCompile Include="frm\frmMainConfig.cpp" />
+    <ClCompile Include="frm\frmMaintenance.cpp" />
+    <ClCompile Include="frm\frmOptions.cpp" />
+    <ClCompile Include="frm\frmPassword.cpp" />
+    <ClCompile Include="frm\frmPgpassConfig.cpp" />
+    <ClCompile Include="frm\frmQuery.cpp" />
+    <ClCompile Include="frm\frmReport.cpp" />
+    <ClCompile Include="frm\frmRestore.cpp" />
+    <ClCompile Include="frm\frmSplash.cpp" />
+    <ClCompile Include="frm\frmStatus.cpp" />
+    <ClCompile Include="frm\plugins.cpp" />
+    <ClCompile Include="libssh2\agent.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\channel.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\comp.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\crypt.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\global.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\hostkey.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\keepalive.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\kex.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\knownhost.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\libgcrypt.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\mac.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\misc.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\openssl.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\packet.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\pem.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\publickey.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\scp.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\session.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\sftp.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\transport.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\userauth.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="libssh2\version.c">
+      <PrecompiledHeader>NotUsing</PrecompiledHeader>
+      <AssemblerListingLocation>./$(Configuration)/$(Platform)/libssh2/</AssemblerListingLocation>
+      <ObjectFileName>./$(Configuration)/$(Platform)/libssh2/</ObjectFileName>
+      <ProgramDataBaseFileName>./$(Configuration)/$(Platform)/libssh2/</ProgramDataBaseFileName>
+      <XMLDocumentationFileName>$(IntDir)/libssh2</XMLDocumentationFileName>
+    </ClCompile>
+    <ClCompile Include="schema\edbPackage.cpp" />
+    <ClCompile Include="schema\edbPackageFunction.cpp" />
+    <ClCompile Include="schema\edbPackageVariable.cpp" />
+    <ClCompile Include="schema\edbPrivateSynonym.cpp" />
+    <ClCompile Include="schema\edbSynonym.cpp" />
+    <ClCompile Include="schema\gpExtTable.cpp" />
+    <ClCompile Include="schema\gpPartition.cpp" />
+    <ClCompile Include="schema\gpResQueue.cpp" />
+    <ClCompile Include="schema\pgAggregate.cpp" />
+    <ClCompile Include="schema\pgCast.cpp" />
+    <ClCompile Include="schema\pgCatalogObject.cpp" />
+    <ClCompile Include="schema\pgCheck.cpp" />
+    <ClCompile Include="schema\pgCollation.cpp" />
+    <ClCompile Include="schema\pgCollection.cpp" />
+    <ClCompile Include="schema\pgColumn.cpp" />
+    <ClCompile Include="schema\pgConstraints.cpp" />
+    <ClCompile Include="schema\pgConversion.cpp" />
+    <ClCompile Include="schema\pgDatabase.cpp" />
+    <ClCompile Include="schema\pgDatatype.cpp" />
+    <ClCompile Include="schema\pgDomain.cpp" />
+    <ClCompile Include="schema\pgExtension.cpp" />
+    <ClCompile Include="schema\pgForeignDataWrapper.cpp" />
+    <ClCompile Include="schema\pgForeignKey.cpp" />
+    <ClCompile Include="schema\pgForeignServer.cpp" />
+    <ClCompile Include="schema\pgForeignTable.cpp" />
+    <ClCompile Include="schema\pgFunction.cpp" />
+    <ClCompile Include="schema\pgGroup.cpp" />
+    <ClCompile Include="schema\pgIndex.cpp" />
+    <ClCompile Include="schema\pgIndexConstraint.cpp" />
+    <ClCompile Include="schema\pgLanguage.cpp" />
+    <ClCompile Include="schema\pgObject.cpp" />
+    <ClCompile Include="schema\pgOperator.cpp" />
+    <ClCompile Include="schema\pgOperatorClass.cpp" />
+    <ClCompile Include="schema\pgOperatorFamily.cpp" />
+    <ClCompile Include="schema\pgRole.cpp" />
+    <ClCompile Include="schema\pgRule.cpp" />
+    <ClCompile Include="schema\pgSchema.cpp" />
+    <ClCompile Include="schema\pgSequence.cpp" />
+    <ClCompile Include="schema\pgServer.cpp" />
+    <ClCompile Include="schema\pgTable.cpp" />
+    <ClCompile Include="schema\pgTablespace.cpp" />
+    <ClCompile Include="schema\pgTextSearchConfiguration.cpp" />
+    <ClCompile Include="schema\pgTextSearchDictionary.cpp" />
+    <ClCompile Include="schema\pgTextSearchParser.cpp" />
+    <ClCompile Include="schema\pgTextSearchTemplate.cpp" />
+    <ClCompile Include="schema\pgTrigger.cpp" />
+    <ClCompile Include="schema\pgType.cpp" />
+    <ClCompile Include="schema\pgUser.cpp" />
+    <ClCompile Include="schema\pgUserMapping.cpp" />
+    <ClCompile Include="schema\pgView.cpp" />
+    <ClCompile Include="slony\dlgRepCluster.cpp" />
+    <ClCompile Include="slony\dlgRepListen.cpp" />
+    <ClCompile Include="slony\dlgRepNode.cpp" />
+    <ClCompile Include="slony\dlgRepPath.cpp" />
+    <ClCompile Include="slony\dlgRepProperty.cpp" />
+    <ClCompile Include="slony\dlgRepSequence.cpp" />
+    <ClCompile Include="slony\dlgRepSet.cpp" />
+    <ClCompile Include="slony\dlgRepSubscription.cpp" />
+    <ClCompile Include="slony\dlgRepTable.cpp" />
+    <ClCompile Include="slony\slCluster.cpp" />
+    <ClCompile Include="slony\slListen.cpp" />
+    <ClCompile Include="slony\slNode.cpp" />
+    <ClCompile Include="slony\slPath.cpp" />
+    <ClCompile Include="slony\slSequence.cpp" />
+    <ClCompile Include="slony\slSet.cpp" />
+    <ClCompile Include="slony\slSubscription.cpp" />
+    <ClCompile Include="slony\slTable.cpp" />
+    <ClCompile Include="ui\xrcDialogs.cpp">
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
+      </PrecompiledHeader>
+    </ClCompile>
+    <ClCompile Include="utils\csvfiles.cpp" />
+    <ClCompile Include="utils\factory.cpp" />
+    <ClCompile Include="utils\favourites.cpp" />
+    <ClCompile Include="utils\macros.cpp" />
+    <ClCompile Include="utils\misc.cpp" />
+    <ClCompile Include="utils\pgconfig.cpp" />
+    <ClCompile Include="utils\registry.cpp" />
+    <ClCompile Include="utils\sshTunnel.cpp" />
+    <ClCompile Include="utils\sysLogger.cpp" />
+    <ClCompile Include="utils\sysProcess.cpp" />
+    <ClCompile Include="utils\sysSettings.cpp" />
+    <ClCompile Include="utils\tabcomplete.c">
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+      </PrecompiledHeader>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
+      </PrecompiledHeader>
+    </ClCompile>
+    <ClCompile Include="utils\utffile.cpp" />
+    <ClCompile Include="debugger\ctlCodeWindow.cpp" />
+    <ClCompile Include="debugger\ctlMessageWindow.cpp" />
+    <ClCompile Include="debugger\ctlResultGrid.cpp" />
+    <ClCompile Include="debugger\ctlStackWindow.cpp" />
+    <ClCompile Include="debugger\ctlTabWindow.cpp" />
+    <ClCompile Include="debugger\ctlVarWindow.cpp" />
+    <ClCompile Include="debugger\dbgBreakPoint.cpp" />
+    <ClCompile Include="debugger\dbgDbResult.cpp" />
+    <ClCompile Include="debugger\dbgPgConn.cpp" />
+    <ClCompile Include="debugger\dbgPgThread.cpp" />
+    <ClCompile Include="debugger\dbgResultset.cpp" />
+    <ClCompile Include="debugger\dbgTargetInfo.cpp" />
+    <ClCompile Include="debugger\debugger.cpp" />
+    <ClCompile Include="debugger\dlgDirectDbg.cpp" />
+    <ClCompile Include="debugger\frmDebugger.cpp" />
+    <ClCompile Include="gqb\gqbArrayCollection.cpp" />
+    <ClCompile Include="gqb\gqbBrowser.cpp" />
+    <ClCompile Include="gqb\gqbCollection.cpp" />
+    <ClCompile Include="gqb\gqbColumn.cpp" />
+    <ClCompile Include="gqb\gqbController.cpp" />
+    <ClCompile Include="gqb\gqbDatabase.cpp" />
+    <ClCompile Include="gqb\gqbGraphSimple.cpp" />
+    <ClCompile Include="gqb\gqbGridJoinTable.cpp" />
+    <ClCompile Include="gqb\gqbGridOrderTable.cpp" />
+    <ClCompile Include="gqb\gqbGridProjTable.cpp" />
+    <ClCompile Include="gqb\gqbGridRestTable.cpp" />
+    <ClCompile Include="gqb\gqbModel.cpp" />
+    <ClCompile Include="gqb\gqbObject.cpp" />
+    <ClCompile Include="gqb\gqbObjectCollection.cpp" />
+    <ClCompile Include="gqb\gqbQueryObjs.cpp" />
+    <ClCompile Include="gqb\gqbSchema.cpp" />
+    <ClCompile Include="gqb\gqbTable.cpp" />
+    <ClCompile Include="gqb\gqbView.cpp" />
+    <ClCompile Include="gqb\gqbViewPanels.cpp" />
+    <ClCompile Include="pgscript\lex.pgs.cc" />
+    <ClCompile Include="pgscript\parser.tab.cc" />
+    <ClCompile Include="pgscript\pgsApplication.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsArithmeticException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsAssertException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsBreakException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsCastException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsContinueException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsInterruptException.cpp" />
+    <ClCompile Include="pgscript\exceptions\pgsParameterException.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsAnd.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsAssign.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsAssignToRecord.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsCast.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsColumns.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsDifferent.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsEqual.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsExecute.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsExpression.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenDate.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenDateTime.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenDictionary.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenInt.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenReal.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenReference.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenRegex.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenString.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGenTime.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGreater.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsGreaterEqual.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsIdent.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsIdentRecord.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsLines.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsLower.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsLowerEqual.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsMinus.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsModulo.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsNegate.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsNot.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsOperation.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsOr.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsOver.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsParenthesis.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsPlus.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsRemoveLine.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsTimes.cpp" />
+    <ClCompile Include="pgscript\expressions\pgsTrim.cpp" />
+    <ClCompile Include="pgscript\generators\pgsDateGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsDateTimeGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsDictionaryGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsIntegerGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsNumberGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsObjectGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsRealGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsReferenceGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsRegexGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsStringGen.cpp" />
+    <ClCompile Include="pgscript\generators\pgsTimeGen.cpp" />
+    <ClCompile Include="pgscript\objects\pgsGenerator.cpp" />
+    <ClCompile Include="pgscript\objects\pgsNumber.cpp" />
+    <ClCompile Include="pgscript\objects\pgsRecord.cpp" />
+    <ClCompile Include="pgscript\objects\pgsString.cpp" />
+    <ClCompile Include="pgscript\objects\pgsVariable.cpp" />
+    <ClCompile Include="pgscript\statements\pgsAssertStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsBreakStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsContinueStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsDeclareRecordStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsExpressionStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsIfStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsPrintStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsProgram.cpp" />
+    <ClCompile Include="pgscript\statements\pgsStmt.cpp" />
+    <ClCompile Include="pgscript\statements\pgsStmtList.cpp" />
+    <ClCompile Include="pgscript\statements\pgsWhileStmt.cpp" />
+    <ClCompile Include="pgscript\utilities\pgsAlloc.cpp" />
+    <ClCompile Include="pgscript\utilities\pgsContext.cpp" />
+    <ClCompile Include="pgscript\utilities\pgsDriver.cpp" />
+    <ClCompile Include="pgscript\utilities\pgsMapm.cpp" />
+    <ClCompile Include="pgscript\utilities\pgsThread.cpp" />
+    <ClCompile Include="pgscript\utilities\pgsUtilities.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm5sin.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_add.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_cpi.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_div.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_exp.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_fam.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_fft.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_flr.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_fpf.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_gcd.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg2.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg3.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg4.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_log.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_mul.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_pow.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_rcp.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_rnd.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_set.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_sin.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmasin.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmasn0.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmcbrt.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmcnst.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmfact.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmfmul.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmgues.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmhasn.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmhsin.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmipwr.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmistr.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmpwr2.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmrsin.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmsqrt.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmstck.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmutil.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmutl1.cpp" />
+    <ClCompile Include="pgscript\utilities\m_apm\mapmutl2.cpp" />
+    <ClCompile Include="ogl\basic.cpp" />
+    <ClCompile Include="ogl\basic2.cpp" />
+    <ClCompile Include="ogl\bmpshape.cpp" />
+    <ClCompile Include="ogl\canvas.cpp" />
+    <ClCompile Include="ogl\composit.cpp" />
+    <ClCompile Include="ogl\constrnt.cpp" />
+    <ClCompile Include="ogl\divided.cpp" />
+    <ClCompile Include="ogl\drawn.cpp" />
+    <ClCompile Include="ogl\lines.cpp" />
+    <ClCompile Include="ogl\mfutils.cpp" />
+    <ClCompile Include="ogl\ogldiag.cpp" />
+    <ClCompile Include="ogl\oglmisc.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddColumnFigure.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddColumnKindIcon.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddColumnOptionIcon.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddRelationshipFigure.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddRelationshipItem.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddRelationshipTerminal.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddTableFigure.cpp" />
+    <ClCompile Include="dd\dditems\figures\ddTextTableItemFigure.cpp" />
+    <ClCompile Include="dd\dditems\figures\xml\ddXmlStorage.cpp" />
+    <ClCompile Include="dd\dditems\handles\ddAddColButtonHandle.cpp" />
+    <ClCompile Include="dd\dditems\handles\ddAddFkButtonHandle.cpp" />
+    <ClCompile Include="dd\dditems\handles\ddMinMaxTableButtonHandle.cpp" />
+    <ClCompile Include="dd\dditems\handles\ddRemoveTableButtonHandle.cpp" />
+    <ClCompile Include="dd\dditems\handles\ddScrollBarHandle.cpp" />
+    <ClCompile Include="dd\dditems\handles\ddSouthTableSizeHandle.cpp" />
+    <ClCompile Include="dd\dditems\locators\ddAddColLocator.cpp" />
+    <ClCompile Include="dd\dditems\locators\ddAddFkLocator.cpp" />
+    <ClCompile Include="dd\dditems\locators\ddMinMaxTableLocator.cpp" />
+    <ClCompile Include="dd\dditems\locators\ddRemoveTableLocator.cpp" />
+    <ClCompile Include="dd\dditems\locators\ddScrollBarTableLocator.cpp" />
+    <ClCompile Include="dd\dditems\locators\ddTableBottomLocator.cpp" />
+    <ClCompile Include="dd\dditems\tools\ddColumnFigureTool.cpp" />
+    <ClCompile Include="dd\dditems\tools\ddColumnTextTool.cpp" />
+    <ClCompile Include="dd\dditems\utilities\ddPrecisionScaleDialog.cpp" />
+    <ClCompile Include="dd\dditems\utilities\ddSelectKindFksDialog.cpp" />
+    <ClCompile Include="dd\dditems\utilities\ddTableNameDialog.cpp" />
+    <ClCompile Include="dd\ddmodel\ddBrowserDataContainer.cpp" />
+    <ClCompile Include="dd\ddmodel\ddDatabaseDesign.cpp" />
+    <ClCompile Include="dd\ddmodel\ddDBReverseEnginering.cpp" />
+    <ClCompile Include="dd\ddmodel\ddDrawingEditor.cpp" />
+    <ClCompile Include="dd\ddmodel\ddDrawingView.cpp" />
+    <ClCompile Include="dd\ddmodel\ddGenerationWizard.cpp" />
+    <ClCompile Include="dd\ddmodel\ddModelBrowser.cpp" />
+    <ClCompile Include="hotdraw\connectors\hdChopBoxConnector.cpp" />
+    <ClCompile Include="hotdraw\connectors\hdIConnector.cpp" />
+    <ClCompile Include="hotdraw\connectors\hdLocatorConnector.cpp" />
+    <ClCompile Include="hotdraw\connectors\hdStickyRectangleConnector.cpp" />
+    <ClCompile Include="hotdraw\figures\hdAbstractFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdAbstractMenuFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdAttribute.cpp" />
+    <ClCompile Include="hotdraw\figures\hdAttributeFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdBitmapFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdCompositeFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdIConnectionFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdIFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdLineConnection.cpp" />
+    <ClCompile Include="hotdraw\figures\hdLineTerminal.cpp" />
+    <ClCompile Include="hotdraw\figures\hdPolyLineFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdRectangleFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\hdSimpleTextFigure.cpp" />
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFillAttribute.cpp" />
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontAttribute.cpp" />
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontColorAttribute.cpp" />
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdLineAttribute.cpp" />
+    <ClCompile Include="hotdraw\figures\xml\hdStorage.cpp" />
+    <ClCompile Include="hotdraw\handles\hdButtonHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdChangeConnectionEndHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdChangeConnectionHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdChangeConnectionStartHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdIHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdLineConnectionHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdLocatorHandle.cpp" />
+    <ClCompile Include="hotdraw\handles\hdPolyLineHandle.cpp" />
+    <ClCompile Include="hotdraw\locators\hdILocator.cpp" />
+    <ClCompile Include="hotdraw\locators\hdPolyLineLocator.cpp" />
+    <ClCompile Include="hotdraw\main\hdDrawing.cpp" />
+    <ClCompile Include="hotdraw\main\hdDrawingEditor.cpp" />
+    <ClCompile Include="hotdraw\main\hdDrawingView.cpp" />
+    <ClCompile Include="hotdraw\tools\hdAbstractTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdCanvasMenuTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdCompositeFigureTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdConnectionCreationTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdCreationTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdDragCreationTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdDragTrackerTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdFigureTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdHandleTrackerTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdITool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdMenuTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdPolyLineFigureTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdSelectAreaTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdSelectionTool.cpp" />
+    <ClCompile Include="hotdraw\tools\hdSimpleTextTool.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdArrayCollection.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdCollection.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdGeometry.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdKeyEvent.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdMouseEvent.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdMultiPosRect.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdPoint.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdRect.cpp" />
+    <ClCompile Include="hotdraw\utilities\hdRemoveDeleteDialog.cpp" />
+    <ClCompile Include="pgAdmin3.cpp">
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Use</PrecompiledHeader>
+      <AdditionalIncludeDirectories Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
+      <PreprocessorDefinitions Condition="'$(Configuration)|$(Platform)'=='Release|x64'">%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">Use</PrecompiledHeader>
+    </ClCompile>
+    <ClCompile Include="precomp.cpp">
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug (2.9)|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release (2.9)|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+      <PrecompiledHeader Condition="'$(Configuration)|$(Platform)'=='Release|x64'">Create</PrecompiledHeader>
+      <ObjectFileName Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(IntDir)%(Filename)1.obj</ObjectFileName>
+      <XMLDocumentationFileName Condition="'$(Configuration)|$(Platform)'=='Release|x64'">$(IntDir)%(Filename)1.xdc</XMLDocumentationFileName>
+    </ClCompile>
+  </ItemGroup>
+  <ItemGroup>
+    <None Include="agent\module.mk" />
+    <None Include="ctl\module.mk" />
+    <None Include="db\module.mk" />
+    <None Include="dlg\module.mk" />
+    <None Include="frm\module.mk" />
+    <None Include="include\module.mk" />
+    <None Include="include\utils\module.mk" />
+    <None Include="include\ctl\module.mk" />
+    <None Include="include\images\module.mk" />
+    <None Include="include\images\pgAdmin3.ico" />
+    <None Include="include\images\sql.ico" />
+    <None Include="include\parser\module.mk" />
+    <None Include="include\agent\module.mk" />
+    <None Include="include\slony\module.mk" />
+    <None Include="include\dlg\module.mk" />
+    <None Include="include\frm\module.mk" />
+    <None Include="include\schema\module.mk" />
+    <None Include="include\db\module.mk" />
+    <None Include="include\gqb\module.mk" />
+    <None Include="include\pgscript\location.hh" />
+    <None Include="include\pgscript\parser.tab.hh" />
+    <None Include="include\pgscript\position.hh" />
+    <None Include="include\pgscript\stack.hh" />
+    <None Include="include\pgscript\exceptions\module.mk" />
+    <None Include="include\pgscript\expressions\module.mk" />
+    <None Include="include\pgscript\generators\module.mk" />
+    <None Include="include\pgscript\objects\module.mk" />
+    <None Include="include\pgscript\statements\module.mk" />
+    <None Include="include\pgscript\utilities\module.mk" />
+    <None Include="include\pgscript\utilities\mapm-lib\license.txt" />
+    <None Include="include\pgscript\utilities\mapm-lib\module.mk" />
+    <None Include="include\ogl\module.mk" />
+    <None Include="include\ogl\README" />
+    <None Include="include\dd\module.mk" />
+    <None Include="include\dd\dditems\module.mk" />
+    <None Include="include\dd\dditems\figures\module.mk" />
+    <None Include="include\dd\dditems\figures\xml\module.mk" />
+    <None Include="include\dd\dditems\handles\module.mk" />
+    <None Include="include\dd\dditems\locators\module.mk" />
+    <None Include="include\dd\dditems\tools\module.mk" />
+    <None Include="include\dd\dditems\utilities\module.mk" />
+    <None Include="include\dd\ddmodel\module.mk" />
+    <None Include="include\hotdraw\module.mk" />
+    <None Include="include\hotdraw\connectors\module.mk" />
+    <None Include="include\hotdraw\figures\module.mk" />
+    <None Include="include\hotdraw\figures\defaultAttributes\module.mk" />
+    <None Include="include\hotdraw\handles\module.mk" />
+    <None Include="include\hotdraw\locators\module.mk" />
+    <None Include="include\hotdraw\main\module.mk" />
+    <None Include="include\hotdraw\tools\module.mk" />
+    <None Include="include\hotdraw\utilities\module.mk" />
+    <None Include="schema\module.mk" />
+    <None Include="slony\module.mk" />
+    <None Include="ui\dlgAddFavourite.xrc" />
+    <None Include="ui\dlgAggregate.xrc" />
+    <None Include="ui\dlgCast.xrc" />
+    <None Include="ui\dlgCheck.xrc" />
+    <None Include="ui\dlgCollation.xrc" />
+    <None Include="ui\dlgColumn.xrc" />
+    <None Include="ui\dlgConnect.xrc" />
+    <None Include="ui\dlgConversion.xrc" />
+    <None Include="ui\dlgDatabase.xrc" />
+    <None Include="ui\dlgDirectDbg.xrc" />
+    <None Include="ui\dlgDomain.xrc" />
+    <None Include="ui\dlgEditGridOptions.xrc" />
+    <None Include="ui\dlgExtension.xrc" />
+    <None Include="ui\dlgExtTable.xrc" />
+    <None Include="ui\dlgFindReplace.xrc" />
+    <None Include="ui\dlgForeignDataWrapper.xrc" />
+    <None Include="ui\dlgForeignKey.xrc" />
+    <None Include="ui\dlgForeignServer.xrc" />
+    <None Include="ui\dlgForeignTable.xrc" />
+    <None Include="ui\dlgFunction.xrc" />
+    <None Include="ui\dlgGroup.xrc" />
+    <None Include="ui\dlgHbaConfig.xrc" />
+    <None Include="ui\dlgIndex.xrc" />
+    <None Include="ui\dlgIndexConstraint.xrc" />
+    <None Include="ui\dlgJob.xrc" />
+    <None Include="ui\dlgLanguage.xrc" />
+    <None Include="ui\dlgMainConfig.xrc" />
+    <None Include="ui\dlgManageFavourites.xrc" />
+    <None Include="ui\dlgManageMacros.xrc" />
+    <None Include="ui\dlgOperator.xrc" />
+    <None Include="ui\dlgPackage.xrc" />
+    <None Include="ui\dlgPgpassConfig.xrc" />
+    <None Include="ui\dlgReassignDropOwned.xrc" />
+    <None Include="ui\dlgRepCluster.xrc" />
+    <None Include="ui\dlgRepClusterUpgrade.xrc" />
+    <None Include="ui\dlgRepListen.xrc" />
+    <None Include="ui\dlgRepNode.xrc" />
+    <None Include="ui\dlgRepPath.xrc" />
+    <None Include="ui\dlgRepSequence.xrc" />
+    <None Include="ui\dlgRepSet.xrc" />
+    <None Include="ui\dlgRepSetMerge.xrc" />
+    <None Include="ui\dlgRepSetMove.xrc" />
+    <None Include="ui\dlgRepSubscription.xrc" />
+    <None Include="ui\dlgRepTable.xrc" />
+    <None Include="ui\dlgRole.xrc" />
+    <None Include="ui\dlgRule.xrc" />
+    <None Include="ui\dlgSchedule.xrc" />
+    <None Include="ui\dlgSchema.xrc" />
+    <None Include="ui\dlgSearchObject.xrc" />
+    <None Include="ui\dlgSelectConnection.xrc" />
+    <None Include="ui\dlgSequence.xrc" />
+    <None Include="ui\dlgServer.xrc" />
+    <None Include="ui\dlgStep.xrc" />
+    <None Include="ui\dlgSynonym.xrc" />
+    <None Include="ui\dlgTable.xrc" />
+    <None Include="ui\dlgTablespace.xrc" />
+    <None Include="ui\dlgTextSearchConfiguration.xrc" />
+    <None Include="ui\dlgTextSearchDictionary.xrc" />
+    <None Include="ui\dlgTextSearchParser.xrc" />
+    <None Include="ui\dlgTextSearchTemplate.xrc" />
+    <None Include="ui\dlgTrigger.xrc" />
+    <None Include="ui\dlgType.xrc" />
+    <None Include="ui\dlgUser.xrc" />
+    <None Include="ui\dlgUserMapping.xrc" />
+    <None Include="ui\dlgView.xrc" />
+    <None Include="ui\embed-xrc" />
+    <None Include="ui\embed-xrc.bat" />
+    <None Include="ui\frmBackup.xrc" />
+    <None Include="ui\frmBackupGlobals.xrc" />
+    <None Include="ui\frmBackupServer.xrc" />
+    <None Include="ui\frmExport.xrc" />
+    <None Include="ui\frmGrantWizard.xrc" />
+    <None Include="ui\frmHint.xrc" />
+    <None Include="ui\frmMaintenance.xrc" />
+    <None Include="ui\frmOptions.xrc" />
+    <None Include="ui\frmPassword.xrc" />
+    <None Include="ui\frmReport.xrc" />
+    <None Include="ui\frmRestore.xrc" />
+    <None Include="ui\module.mk" />
+    <None Include="utils\module.mk" />
+    <None Include="utils\tab-complete.inc" />
+    <None Include="utils\tabcomplete.pl" />
+    <None Include="gqb\module.mk" />
+    <None Include="pgscript\module.mk" />
+    <None Include="pgscript\parser.sh" />
+    <None Include="pgscript\pgsParser.yy" />
+    <None Include="pgscript\pgsScanner.ll" />
+    <None Include="pgscript\README" />
+    <None Include="pgscript\exceptions\module.mk" />
+    <None Include="pgscript\expressions\module.mk" />
+    <None Include="pgscript\generators\module.mk" />
+    <None Include="pgscript\objects\module.mk" />
+    <None Include="pgscript\statements\module.mk" />
+    <None Include="pgscript\utilities\module.mk" />
+    <None Include="pgscript\utilities\m_apm\module.mk" />
+    <None Include="ogl\module.mk" />
+    <None Include="ogl\README" />
+    <None Include="dd\module.mk" />
+    <None Include="dd\dditems\module.mk" />
+    <None Include="dd\dditems\figures\module.mk" />
+    <None Include="dd\dditems\handles\module.mk" />
+    <None Include="dd\dditems\locators\module.mk" />
+    <None Include="dd\dditems\tools\module.mk" />
+    <None Include="dd\dditems\utilities\module.mk" />
+    <None Include="dd\ddmodel\module.mk" />
+    <None Include="hotdraw\module.mk" />
+    <None Include="hotdraw\connectors\module.mk" />
+    <None Include="hotdraw\figures\module.mk" />
+    <None Include="hotdraw\figures\defaultAttributes\module.mk" />
+    <None Include="hotdraw\figures\xml\module.mk" />
+    <None Include="hotdraw\handles\module.mk" />
+    <None Include="hotdraw\locators\module.mk" />
+    <None Include="hotdraw\main\module.mk" />
+    <None Include="hotdraw\tools\module.mk" />
+    <None Include="hotdraw\utilities\module.mk" />
+    <None Include="Makefile.am" />
+    <None Include="plugins.ini" />
+    <None Include="settings.ini" />
+    <None Include="ver_svn.bat" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClInclude Include="include\copyright.h" />
+    <ClInclude Include="include\libssh2\channel.h" />
+    <ClInclude Include="include\libssh2\comp.h" />
+    <ClInclude Include="include\libssh2\crypto.h" />
+    <ClInclude Include="include\libssh2\libgcrypt.h" />
+    <ClInclude Include="include\libssh2\libssh2.h" />
+    <ClInclude Include="include\libssh2\libssh2_priv.h" />
+    <ClInclude Include="include\libssh2\libssh2_publickey.h" />
+    <ClInclude Include="include\libssh2\libssh2_sftp.h" />
+    <ClInclude Include="include\libssh2\mac.h" />
+    <ClInclude Include="include\libssh2\misc.h" />
+    <ClInclude Include="include\libssh2\openssl.h" />
+    <ClInclude Include="include\libssh2\packet.h" />
+    <ClInclude Include="include\libssh2\session.h" />
+    <ClInclude Include="include\libssh2\sftp.h" />
+    <ClInclude Include="include\libssh2\transport.h" />
+    <ClInclude Include="include\libssh2\userauth.h" />
+    <ClInclude Include="include\libssh2\Win32\libssh2_config.h" />
+    <ClInclude Include="include\pgAdmin3.h" />
+    <ClInclude Include="include\postgres.h" />
+    <ClInclude Include="include\precomp.h" />
+    <ClInclude Include="include\svnversion.h" />
+    <ClInclude Include="include\utils\sshTunnel.h" />
+    <ClInclude Include="include\version.h" />
+    <ClInclude Include="include\utils\csvfiles.h" />
+    <ClInclude Include="include\utils\factory.h" />
+    <ClInclude Include="include\utils\favourites.h" />
+    <ClInclude Include="include\utils\macros.h" />
+    <ClInclude Include="include\utils\misc.h" />
+    <ClInclude Include="include\utils\pgconfig.h" />
+    <ClInclude Include="include\utils\pgDefs.h" />
+    <ClInclude Include="include\utils\pgfeatures.h" />
+    <ClInclude Include="include\utils\registr.h" />
+    <ClInclude Include="include\utils\registry.h" />
+    <ClInclude Include="include\utils\sysLogger.h" />
+    <ClInclude Include="include\utils\sysProcess.h" />
+    <ClInclude Include="include\utils\sysSettings.h" />
+    <ClInclude Include="include\utils\utffile.h" />
+    <ClInclude Include="include\ctl\calbox.h" />
+    <ClInclude Include="include\ctl\ctlAuiNotebook.h" />
+    <ClInclude Include="include\ctl\ctlCheckTreeView.h" />
+    <ClInclude Include="include\ctl\ctlColourPicker.h" />
+    <ClInclude Include="include\ctl\ctlComboBox.h" />
+    <ClInclude Include="include\ctl\ctlDefaultSecurityPanel.h" />
+    <ClInclude Include="include\ctl\ctlListView.h" />
+    <ClInclude Include="include\ctl\ctlMenuToolbar.h" />
+    <ClInclude Include="include\ctl\ctlSeclabelPanel.h" />
+    <ClInclude Include="include\ctl\ctlSecurityPanel.h" />
+    <ClInclude Include="include\ctl\ctlSQLBox.h" />
+    <ClInclude Include="include\ctl\ctlSQLGrid.h" />
+    <ClInclude Include="include\ctl\ctlSQLResult.h" />
+    <ClInclude Include="include\ctl\ctlTree.h" />
+    <ClInclude Include="include\ctl\explainCanvas.h" />
+    <ClInclude Include="include\ctl\timespin.h" />
+    <ClInclude Include="include\ctl\wxgridsel.h" />
+    <ClInclude Include="include\ctl\xh_calb.h" />
+    <ClInclude Include="include\ctl\xh_ctlchecktreeview.h" />
+    <ClInclude Include="include\ctl\xh_ctlcolourpicker.h" />
+    <ClInclude Include="include\ctl\xh_ctlcombo.h" />
+    <ClInclude Include="include\ctl\xh_ctltree.h" />
+    <ClInclude Include="include\ctl\xh_sqlbox.h" />
+    <ClInclude Include="include\ctl\xh_timespin.h" />
+    <ClInclude Include="include\parser\keywords.h" />
+    <ClInclude Include="include\agent\dlgJob.h" />
+    <ClInclude Include="include\agent\dlgSchedule.h" />
+    <ClInclude Include="include\agent\dlgStep.h" />
+    <ClInclude Include="include\agent\pgaJob.h" />
+    <ClInclude Include="include\agent\pgaSchedule.h" />
+    <ClInclude Include="include\agent\pgaStep.h" />
+    <ClInclude Include="include\slony\dlgRepCluster.h" />
+    <ClInclude Include="include\slony\dlgRepListen.h" />
+    <ClInclude Include="include\slony\dlgRepNode.h" />
+    <ClInclude Include="include\slony\dlgRepPath.h" />
+    <ClInclude Include="include\slony\dlgRepProperty.h" />
+    <ClInclude Include="include\slony\dlgRepSequence.h" />
+    <ClInclude Include="include\slony\dlgRepSet.h" />
+    <ClInclude Include="include\slony\dlgRepSubscription.h" />
+    <ClInclude Include="include\slony\dlgRepTable.h" />
+    <ClInclude Include="include\slony\slCluster.h" />
+    <ClInclude Include="include\slony\slListen.h" />
+    <ClInclude Include="include\slony\slNode.h" />
+    <ClInclude Include="include\slony\slPath.h" />
+    <ClInclude Include="include\slony\slSequence.h" />
+    <ClInclude Include="include\slony\slSet.h" />
+    <ClInclude Include="include\slony\slSubscription.h" />
+    <ClInclude Include="include\slony\slTable.h" />
+    <ClInclude Include="include\dlg\dlgAddFavourite.h" />
+    <ClInclude Include="include\dlg\dlgAggregate.h" />
+    <ClInclude Include="include\dlg\dlgCast.h" />
+    <ClInclude Include="include\dlg\dlgCheck.h" />
+    <ClInclude Include="include\dlg\dlgClasses.h" />
+    <ClInclude Include="include\dlg\dlgCollation.h" />
+    <ClInclude Include="include\dlg\dlgColumn.h" />
+    <ClInclude Include="include\dlg\dlgConnect.h" />
+    <ClInclude Include="include\dlg\dlgConversion.h" />
+    <ClInclude Include="include\dlg\dlgDatabase.h" />
+    <ClInclude Include="include\dlg\dlgDomain.h" />
+    <ClInclude Include="include\dlg\dlgEditGridOptions.h" />
+    <ClInclude Include="include\dlg\dlgExtension.h" />
+    <ClInclude Include="include\dlg\dlgExtTable.h" />
+    <ClInclude Include="include\dlg\dlgFindReplace.h" />
+    <ClInclude Include="include\dlg\dlgForeignDataWrapper.h" />
+    <ClInclude Include="include\dlg\dlgForeignKey.h" />
+    <ClInclude Include="include\dlg\dlgForeignServer.h" />
+    <ClInclude Include="include\dlg\dlgForeignTable.h" />
+    <ClInclude Include="include\dlg\dlgFunction.h" />
+    <ClInclude Include="include\dlg\dlgGroup.h" />
+    <ClInclude Include="include\dlg\dlgHbaConfig.h" />
+    <ClInclude Include="include\dlg\dlgIndex.h" />
+    <ClInclude Include="include\dlg\dlgIndexConstraint.h" />
+    <ClInclude Include="include\dlg\dlgLanguage.h" />
+    <ClInclude Include="include\dlg\dlgMainConfig.h" />
+    <ClInclude Include="include\dlg\dlgManageFavourites.h" />
+    <ClInclude Include="include\dlg\dlgManageMacros.h" />
+    <ClInclude Include="include\dlg\dlgOperator.h" />
+    <ClInclude Include="include\dlg\dlgPackage.h" />
+    <ClInclude Include="include\dlg\dlgPgpassConfig.h" />
+    <ClInclude Include="include\dlg\dlgProperty.h" />
+    <ClInclude Include="include\dlg\dlgReassignDropOwned.h" />
+    <ClInclude Include="include\dlg\dlgRole.h" />
+    <ClInclude Include="include\dlg\dlgRule.h" />
+    <ClInclude Include="include\dlg\dlgSchema.h" />
+    <ClInclude Include="include\dlg\dlgSearchObject.h" />
+    <ClInclude Include="include\dlg\dlgSelectConnection.h" />
+    <ClInclude Include="include\dlg\dlgSelectDatabase.h" />
+    <ClInclude Include="include\dlg\dlgSequence.h" />
+    <ClInclude Include="include\dlg\dlgServer.h" />
+    <ClInclude Include="include\dlg\dlgSynonym.h" />
+    <ClInclude Include="include\dlg\dlgTable.h" />
+    <ClInclude Include="include\dlg\dlgTablespace.h" />
+    <ClInclude Include="include\dlg\dlgTextSearchConfiguration.h" />
+    <ClInclude Include="include\dlg\dlgTextSearchDictionary.h" />
+    <ClInclude Include="include\dlg\dlgTextSearchParser.h" />
+    <ClInclude Include="include\dlg\dlgTextSearchTemplate.h" />
+    <ClInclude Include="include\dlg\dlgTrigger.h" />
+    <ClInclude Include="include\dlg\dlgType.h" />
+    <ClInclude Include="include\dlg\dlgUser.h" />
+    <ClInclude Include="include\dlg\dlgUserMapping.h" />
+    <ClInclude Include="include\dlg\dlgView.h" />
+    <ClInclude Include="include\frm\frmAbout.h" />
+    <ClInclude Include="include\frm\frmBackup.h" />
+    <ClInclude Include="include\frm\frmBackupGlobals.h" />
+    <ClInclude Include="include\frm\frmBackupServer.h" />
+    <ClInclude Include="include\frm\frmConfig.h" />
+    <ClInclude Include="include\frm\frmDatabaseDesigner.h" />
+    <ClInclude Include="include\frm\frmEditGrid.h" />
+    <ClInclude Include="include\frm\frmExport.h" />
+    <ClInclude Include="include\frm\frmGrantWizard.h" />
+    <ClInclude Include="include\frm\frmHbaConfig.h" />
+    <ClInclude Include="include\frm\frmHint.h" />
+    <ClInclude Include="include\frm\frmImport.h" />
+    <ClInclude Include="include\frm\frmMain.h" />
+    <ClInclude Include="include\frm\frmMainConfig.h" />
+    <ClInclude Include="include\frm\frmMaintenance.h" />
+    <ClInclude Include="include\frm\frmOptions.h" />
+    <ClInclude Include="include\frm\frmPassword.h" />
+    <ClInclude Include="include\frm\frmPgpassConfig.h" />
+    <ClInclude Include="include\frm\frmQuery.h" />
+    <ClInclude Include="include\frm\frmReport.h" />
+    <ClInclude Include="include\frm\frmRestore.h" />
+    <ClInclude Include="include\frm\frmSplash.h" />
+    <ClInclude Include="include\frm\frmStatus.h" />
+    <ClInclude Include="include\frm\menu.h" />
+    <ClInclude Include="include\schema\edbPackage.h" />
+    <ClInclude Include="include\schema\edbPackageFunction.h" />
+    <ClInclude Include="include\schema\edbPackageVariable.h" />
+    <ClInclude Include="include\schema\edbPrivateSynonym.h" />
+    <ClInclude Include="include\schema\edbSynonym.h" />
+    <ClInclude Include="include\schema\gpExtTable.h" />
+    <ClInclude Include="include\schema\gpPartition.h" />
+    <ClInclude Include="include\schema\gpResQueue.h" />
+    <ClInclude Include="include\schema\pgAggregate.h" />
+    <ClInclude Include="include\schema\pgCast.h" />
+    <ClInclude Include="include\schema\pgCatalogObject.h" />
+    <ClInclude Include="include\schema\pgCheck.h" />
+    <ClInclude Include="include\schema\pgCollation.h" />
+    <ClInclude Include="include\schema\pgCollection.h" />
+    <ClInclude Include="include\schema\pgColumn.h" />
+    <ClInclude Include="include\schema\pgConstraints.h" />
+    <ClInclude Include="include\schema\pgConversion.h" />
+    <ClInclude Include="include\schema\pgDatabase.h" />
+    <ClInclude Include="include\schema\pgDatatype.h" />
+    <ClInclude Include="include\schema\pgDomain.h" />
+    <ClInclude Include="include\schema\pgExtension.h" />
+    <ClInclude Include="include\schema\pgForeignDataWrapper.h" />
+    <ClInclude Include="include\schema\pgForeignKey.h" />
+    <ClInclude Include="include\schema\pgForeignServer.h" />
+    <ClInclude Include="include\schema\pgForeignTable.h" />
+    <ClInclude Include="include\schema\pgFunction.h" />
+    <ClInclude Include="include\schema\pgGroup.h" />
+    <ClInclude Include="include\schema\pgIndex.h" />
+    <ClInclude Include="include\schema\pgIndexConstraint.h" />
+    <ClInclude Include="include\schema\pgLanguage.h" />
+    <ClInclude Include="include\schema\pgObject.h" />
+    <ClInclude Include="include\schema\pgOperator.h" />
+    <ClInclude Include="include\schema\pgOperatorClass.h" />
+    <ClInclude Include="include\schema\pgOperatorFamily.h" />
+    <ClInclude Include="include\schema\pgRole.h" />
+    <ClInclude Include="include\schema\pgRule.h" />
+    <ClInclude Include="include\schema\pgSchema.h" />
+    <ClInclude Include="include\schema\pgSequence.h" />
+    <ClInclude Include="include\schema\pgServer.h" />
+    <ClInclude Include="include\schema\pgTable.h" />
+    <ClInclude Include="include\schema\pgTablespace.h" />
+    <ClInclude Include="include\schema\pgTextSearchConfiguration.h" />
+    <ClInclude Include="include\schema\pgTextSearchDictionary.h" />
+    <ClInclude Include="include\schema\pgTextSearchParser.h" />
+    <ClInclude Include="include\schema\pgTextSearchTemplate.h" />
+    <ClInclude Include="include\schema\pgTrigger.h" />
+    <ClInclude Include="include\schema\pgType.h" />
+    <ClInclude Include="include\schema\pgUser.h" />
+    <ClInclude Include="include\schema\pgUserMapping.h" />
+    <ClInclude Include="include\schema\pgView.h" />
+    <ClInclude Include="include\db\pgConn.h" />
+    <ClInclude Include="include\db\pgQueryThread.h" />
+    <ClInclude Include="include\db\pgSet.h" />
+    <ClInclude Include="include\debugger\ctlCodeWindow.h" />
+    <ClInclude Include="include\debugger\ctlMessageWindow.h" />
+    <ClInclude Include="include\debugger\ctlResultGrid.h" />
+    <ClInclude Include="include\debugger\ctlStackWindow.h" />
+    <ClInclude Include="include\debugger\ctlTabWindow.h" />
+    <ClInclude Include="include\debugger\ctlVarWindow.h" />
+    <ClInclude Include="include\debugger\dbgBreakPoint.h" />
+    <ClInclude Include="include\debugger\dbgConnProp.h" />
+    <ClInclude Include="include\debugger\dbgConst.h" />
+    <ClInclude Include="include\debugger\dbgDbResult.h" />
+    <ClInclude Include="include\debugger\dbgPgConn.h" />
+    <ClInclude Include="include\debugger\dbgPgThread.h" />
+    <ClInclude Include="include\debugger\dbgResultset.h" />
+    <ClInclude Include="include\debugger\dbgTargetInfo.h" />
+    <ClInclude Include="include\debugger\debugger.h" />
+    <ClInclude Include="include\debugger\dlgDirectDbg.h" />
+    <ClInclude Include="include\debugger\frmDebugger.h" />
+    <ClInclude Include="include\gqb\gqbArrayCollection.h" />
+    <ClInclude Include="include\gqb\gqbBrowser.h" />
+    <ClInclude Include="include\gqb\gqbCollection.h" />
+    <ClInclude Include="include\gqb\gqbCollectionBase.h" />
+    <ClInclude Include="include\gqb\gqbColumn.h" />
+    <ClInclude Include="include\gqb\gqbDatabase.h" />
+    <ClInclude Include="include\gqb\gqbEvents.h" />
+    <ClInclude Include="include\gqb\gqbGraphBehavior.h" />
+    <ClInclude Include="include\gqb\gqbGraphSimple.h" />
+    <ClInclude Include="include\gqb\gqbGridJoinTable.h" />
+    <ClInclude Include="include\gqb\gqbGridOrderTable.h" />
+    <ClInclude Include="include\gqb\gqbGridProjTable.h" />
+    <ClInclude Include="include\gqb\gqbGridRestTable.h" />
+    <ClInclude Include="include\gqb\gqbModel.h" />
+    <ClInclude Include="include\gqb\gqbObject.h" />
+    <ClInclude Include="include\gqb\gqbObjectCollection.h" />
+    <ClInclude Include="include\gqb\gqbQueryObjs.h" />
+    <ClInclude Include="include\gqb\gqbSchema.h" />
+    <ClInclude Include="include\gqb\gqbTable.h" />
+    <ClInclude Include="include\gqb\gqbViewController.h" />
+    <ClInclude Include="include\gqb\gqbViewPanels.h" />
+    <ClInclude Include="include\pgscript\FlexLexer.h" />
+    <ClInclude Include="include\pgscript\pgsApplication.h" />
+    <ClInclude Include="include\pgscript\pgScript.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsArithmeticException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsAssertException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsBreakException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsCastException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsContinueException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsInterruptException.h" />
+    <ClInclude Include="include\pgscript\exceptions\pgsParameterException.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsAnd.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsAssign.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsAssignToRecord.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsCast.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsColumns.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsDifferent.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsEqual.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsExecute.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsExpression.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsExpressions.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenDate.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenDateTime.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenDictionary.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenInt.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenReal.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenReference.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenRegex.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenString.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGenTime.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGreater.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsGreaterEqual.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsIdent.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsIdentRecord.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsLines.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsLower.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsLowerEqual.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsMinus.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsModulo.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsNegate.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsNot.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsOperation.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsOr.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsOver.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsParenthesis.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsPlus.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsRemoveLine.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsTimes.h" />
+    <ClInclude Include="include\pgscript\expressions\pgsTrim.h" />
+    <ClInclude Include="include\pgscript\generators\pgsDateGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsDateTimeGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsDictionaryGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsIntegerGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsNumberGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsObjectGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsRealGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsReferenceGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsRegexGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsStringGen.h" />
+    <ClInclude Include="include\pgscript\generators\pgsTimeGen.h" />
+    <ClInclude Include="include\pgscript\objects\pgsGenerator.h" />
+    <ClInclude Include="include\pgscript\objects\pgsNumber.h" />
+    <ClInclude Include="include\pgscript\objects\pgsObjects.h" />
+    <ClInclude Include="include\pgscript\objects\pgsRecord.h" />
+    <ClInclude Include="include\pgscript\objects\pgsString.h" />
+    <ClInclude Include="include\pgscript\objects\pgsVariable.h" />
+    <ClInclude Include="include\pgscript\statements\pgsAssertStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsBreakStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsContinueStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsDeclareRecordStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsExpressionStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsIfStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsPrintStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsProgram.h" />
+    <ClInclude Include="include\pgscript\statements\pgsStatements.h" />
+    <ClInclude Include="include\pgscript\statements\pgsStmt.h" />
+    <ClInclude Include="include\pgscript\statements\pgsStmtList.h" />
+    <ClInclude Include="include\pgscript\statements\pgsWhileStmt.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsAlloc.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsContext.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsCopiedPtr.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsDriver.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsMapm.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsScanner.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsSharedPtr.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsThread.h" />
+    <ClInclude Include="include\pgscript\utilities\pgsUtilities.h" />
+    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm.h" />
+    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm_lc.h" />
+    <ClInclude Include="include\ogl\basic.h" />
+    <ClInclude Include="include\ogl\basicp.h" />
+    <ClInclude Include="include\ogl\bmpshape.h" />
+    <ClInclude Include="include\ogl\canvas.h" />
+    <ClInclude Include="include\ogl\composit.h" />
+    <ClInclude Include="include\ogl\constrnt.h" />
+    <ClInclude Include="include\ogl\divided.h" />
+    <ClInclude Include="include\ogl\drawn.h" />
+    <ClInclude Include="include\ogl\drawnp.h" />
+    <ClInclude Include="include\ogl\lines.h" />
+    <ClInclude Include="include\ogl\linesp.h" />
+    <ClInclude Include="include\ogl\mfutils.h" />
+    <ClInclude Include="include\ogl\misc.h" />
+    <ClInclude Include="include\ogl\ogl.h" />
+    <ClInclude Include="include\ogl\ogldiag.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddColumnFigure.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddColumnKindIcon.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddColumnOptionIcon.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddRelationshipFigure.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddRelationshipItem.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddRelationshipTerminal.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddTableFigure.h" />
+    <ClInclude Include="include\dd\dditems\figures\ddTextTableItemFigure.h" />
+    <ClInclude Include="include\dd\dditems\figures\xml\ddXmlStorage.h" />
+    <ClInclude Include="include\dd\dditems\handles\ddAddColButtonHandle.h" />
+    <ClInclude Include="include\dd\dditems\handles\ddAddFkButtonHandle.h" />
+    <ClInclude Include="include\dd\dditems\handles\ddMinMaxTableButtonHandle.h" />
+    <ClInclude Include="include\dd\dditems\handles\ddRemoveTableButtonHandle.h" />
+    <ClInclude Include="include\dd\dditems\handles\ddScrollBarHandle.h" />
+    <ClInclude Include="include\dd\dditems\handles\ddSouthTableSizeHandle.h" />
+    <ClInclude Include="include\dd\dditems\locators\ddAddColLocator.h" />
+    <ClInclude Include="include\dd\dditems\locators\ddAddFkLocator.h" />
+    <ClInclude Include="include\dd\dditems\locators\ddMinMaxTableLocator.h" />
+    <ClInclude Include="include\dd\dditems\locators\ddRemoveTableLocator.h" />
+    <ClInclude Include="include\dd\dditems\locators\ddScrollBarTableLocator.h" />
+    <ClInclude Include="include\dd\dditems\locators\ddTableBottomLocator.h" />
+    <ClInclude Include="include\dd\dditems\tools\ddColumnFigureTool.h" />
+    <ClInclude Include="include\dd\dditems\tools\ddColumnTextTool.h" />
+    <ClInclude Include="include\dd\dditems\utilities\ddDataType.h" />
+    <ClInclude Include="include\dd\dditems\utilities\ddPrecisionScaleDialog.h" />
+    <ClInclude Include="include\dd\dditems\utilities\ddSelectKindFksDialog.h" />
+    <ClInclude Include="include\dd\dditems\utilities\ddTableNameDialog.h" />
+    <ClInclude Include="include\dd\ddmodel\ddBrowserDataContainer.h" />
+    <ClInclude Include="include\dd\ddmodel\ddDatabaseDesign.h" />
+    <ClInclude Include="include\dd\ddmodel\ddDBReverseEngineering.h" />
+    <ClInclude Include="include\dd\ddmodel\ddDrawingEditor.h" />
+    <ClInclude Include="include\dd\ddmodel\ddDrawingView.h" />
+    <ClInclude Include="include\dd\ddmodel\ddGenerationWizard.h" />
+    <ClInclude Include="include\dd\ddmodel\ddModelBrowser.h" />
+    <ClInclude Include="include\hotdraw\connectors\hdChopBoxConnector.h" />
+    <ClInclude Include="include\hotdraw\connectors\hdIConnector.h" />
+    <ClInclude Include="include\hotdraw\connectors\hdLocatorConnector.h" />
+    <ClInclude Include="include\hotdraw\connectors\hdStickyRectangleConnector.h" />
+    <ClInclude Include="include\hotdraw\figures\hdAbstractFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdAbstractMenuFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdAttribute.h" />
+    <ClInclude Include="include\hotdraw\figures\hdAttributeFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdBitmapFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdCompositeFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdIConnectionFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdIFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdLineConnection.h" />
+    <ClInclude Include="include\hotdraw\figures\hdLineTerminal.h" />
+    <ClInclude Include="include\hotdraw\figures\hdPolyLineFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdRectangleFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\hdSimpleTextFigure.h" />
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFillAttribute.h" />
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontAttribute.h" />
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontColorAttribute.h" />
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdLineAttribute.h" />
+    <ClInclude Include="include\hotdraw\figures\xml\hdStorage.h" />
+    <ClInclude Include="include\hotdraw\handles\hdButtonHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionEndHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionStartHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdIHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdLineConnectionHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdLocatorHandle.h" />
+    <ClInclude Include="include\hotdraw\handles\hdPolyLineHandle.h" />
+    <ClInclude Include="include\hotdraw\locators\hdILocator.h" />
+    <ClInclude Include="include\hotdraw\locators\hdPolyLineLocator.h" />
+    <ClInclude Include="include\hotdraw\main\hdDrawing.h" />
+    <ClInclude Include="include\hotdraw\main\hdDrawingEditor.h" />
+    <ClInclude Include="include\hotdraw\main\hdDrawingView.h" />
+    <ClInclude Include="include\hotdraw\main\hdObject.h" />
+    <ClInclude Include="include\hotdraw\tools\hdAbstractTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdCanvasMenuTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdCompositeFigureTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdConnectionCreationTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdCreationTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdDragCreationTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdDragTrackerTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdFigureTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdHandleTrackerTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdITool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdMenuTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdPolyLineFigureTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdSelectAreaTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdSelectionTool.h" />
+    <ClInclude Include="include\hotdraw\tools\hdSimpleTextTool.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdArrayCollection.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdCollection.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdCollectionBase.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdGeometry.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdKeyEvent.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdMouseEvent.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdMultiPosRect.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdPoint.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdRect.h" />
+    <ClInclude Include="include\hotdraw\utilities\hdRemoveDeleteDialog.h" />
+  </ItemGroup>
+  <ItemGroup>
+    <png2c Include="include\images\aggregate-sm.png" />
+    <png2c Include="include\images\aggregate.png" />
+    <png2c Include="include\images\aggregates.png" />
+    <png2c Include="include\images\back.png" />
+    <png2c Include="include\images\backup.png" />
+    <png2c Include="include\images\baddatabase.png" />
+    <png2c Include="include\images\cast-sm.png" />
+    <png2c Include="include\images\cast.png" />
+    <png2c Include="include\images\casts.png" />
+    <png2c Include="include\images\catalog-sm.png" />
+    <png2c Include="include\images\catalog.png" />
+    <png2c Include="include\images\catalogobject-sm.png" />
+    <png2c Include="include\images\catalogobject.png" />
+    <png2c Include="include\images\catalogobjects.png" />
+    <png2c Include="include\images\catalogs.png" />
+    <png2c Include="include\images\check.png" />
+    <png2c Include="include\images\checkbad.png" />
+    <png2c Include="include\images\checked.png" />
+    <png2c Include="include\images\clearAll.png" />
+    <png2c Include="include\images\clip_copy.png" />
+    <png2c Include="include\images\clip_cut.png" />
+    <png2c Include="include\images\clip_paste.png" />
+    <png2c Include="include\images\closeddatabase-sm.png" />
+    <png2c Include="include\images\closeddatabase.png" />
+    <png2c Include="include\images\collation-sm.png" />
+    <png2c Include="include\images\collation.png" />
+    <png2c Include="include\images\collations.png" />
+    <png2c Include="include\images\column-sm.png" />
+    <png2c Include="include\images\column.png" />
+    <png2c Include="include\images\columns.png" />
+    <png2c Include="include\images\configuration.png" />
+    <png2c Include="include\images\configurations.png" />
+    <png2c Include="include\images\connect.png" />
+    <png2c Include="include\images\constraints.png" />
+    <png2c Include="include\images\continue.png" />
+    <png2c Include="include\images\conversion.png" />
+    <png2c Include="include\images\conversions.png" />
+    <png2c Include="include\images\create.png" />
+    <png2c Include="include\images\database-sm.png" />
+    <png2c Include="include\images\database.png" />
+    <png2c Include="include\images\databases.png" />
+    <png2c Include="include\images\ddAddColumn.png" />
+    <png2c Include="include\images\ddAddColumnCursor.png" />
+    <png2c Include="include\images\ddAddForeignKey.png" />
+    <png2c Include="include\images\ddcancel.png" />
+    <png2c Include="include\images\ddDeleteTableCursor.png" />
+    <png2c Include="include\images\ddDown.png" />
+    <png2c Include="include\images\ddforeignkey.png" />
+    <png2c Include="include\images\ddforeignkeyfromuk.png" />
+    <png2c Include="include\images\ddforeignkeyuniquekey.png" />
+    <png2c Include="include\images\ddforeignkeyuniquekeyfromuk.png" />
+    <png2c Include="include\images\ddgendiagram.png" />
+    <png2c Include="include\images\ddMaximizeTable.png" />
+    <png2c Include="include\images\ddMinimizeTable.png" />
+    <png2c Include="include\images\ddMinMaxCursor.png" />
+    <png2c Include="include\images\ddmodel-32.png" />
+    <png2c Include="include\images\ddnewdiagram.png" />
+    <png2c Include="include\images\ddnotnull.png" />
+    <png2c Include="include\images\ddnull.png" />
+    <png2c Include="include\images\ddprimaryforeignkey.png" />
+    <png2c Include="include\images\ddprimaryforeignkeyfromuk.png" />
+    <png2c Include="include\images\ddprimarykey.png" />
+    <png2c Include="include\images\ddprimarykeyuniquekey.png" />
+    <png2c Include="include\images\ddRelationshipCursor.png" />
+    <png2c Include="include\images\ddRemoveColumn.png" />
+    <png2c Include="include\images\ddRemoveColumnCursor.png" />
+    <png2c Include="include\images\ddRemoveTable.png" />
+    <png2c Include="include\images\ddRemoveTable2.png" />
+    <png2c Include="include\images\ddunique.png" />
+    <png2c Include="include\images\ddUp.png" />
+    <png2c Include="include\images\debugger.png" />
+    <png2c Include="include\images\delete.png" />
+    <png2c Include="include\images\dictionaries.png" />
+    <png2c Include="include\images\dictionary.png" />
+    <png2c Include="include\images\disabled.png" />
+    <png2c Include="include\images\dnd_copy.png" />
+    <png2c Include="include\images\dnd_move.png" />
+    <png2c Include="include\images\dnd_none.png" />
+    <png2c Include="include\images\domain-sm.png" />
+    <png2c Include="include\images\domain.png" />
+    <png2c Include="include\images\domains.png" />
+    <png2c Include="include\images\down.png" />
+    <png2c Include="include\images\drop.png" />
+    <png2c Include="include\images\edit_clear.png" />
+    <png2c Include="include\images\edit_find.png" />
+    <png2c Include="include\images\edit_redo.png" />
+    <png2c Include="include\images\edit_undo.png" />
+    <png2c Include="include\images\enumeration.png" />
+    <png2c Include="include\images\enumerations.png" />
+    <png2c Include="include\images\ex_aggregate.png" />
+    <png2c Include="include\images\ex_append.png" />
+    <png2c Include="include\images\ex_bmp_heap.png" />
+    <png2c Include="include\images\ex_bmp_index.png" />
+    <png2c Include="include\images\ex_broadcast_motion.png" />
+    <png2c Include="include\images\ex_cte_scan.png" />
+    <png2c Include="include\images\ex_gather_motion.png" />
+    <png2c Include="include\images\ex_group.png" />
+    <png2c Include="include\images\ex_hash.png" />
+    <png2c Include="include\images\ex_hash_anti_join.png" />
+    <png2c Include="include\images\ex_hash_semi_join.png" />
+    <png2c Include="include\images\ex_hash_setop_except.png" />
+    <png2c Include="include\images\ex_hash_setop_except_all.png" />
+    <png2c Include="include\images\ex_hash_setop_intersect.png" />
+    <png2c Include="include\images\ex_hash_setop_intersect_all.png" />
+    <png2c Include="include\images\ex_hash_setop_unknown.png" />
+    <png2c Include="include\images\ex_index_scan.png" />
+    <png2c Include="include\images\ex_join.png" />
+    <png2c Include="include\images\ex_limit.png" />
+    <png2c Include="include\images\ex_materialize.png" />
+    <png2c Include="include\images\ex_merge.png" />
+    <png2c Include="include\images\ex_merge_anti_join.png" />
+    <png2c Include="include\images\ex_merge_semi_join.png" />
+    <png2c Include="include\images\ex_nested.png" />
+    <png2c Include="include\images\ex_nested_loop_anti_join.png" />
+    <png2c Include="include\images\ex_nested_loop_semi_join.png" />
+    <png2c Include="include\images\ex_recursive_union.png" />
+    <png2c Include="include\images\ex_redistribute_motion.png" />
+    <png2c Include="include\images\ex_result.png" />
+    <png2c Include="include\images\ex_scan.png" />
+    <png2c Include="include\images\ex_seek.png" />
+    <png2c Include="include\images\ex_setop.png" />
+    <png2c Include="include\images\ex_sort.png" />
+    <png2c Include="include\images\ex_subplan.png" />
+    <png2c Include="include\images\ex_tid_scan.png" />
+    <png2c Include="include\images\ex_unique.png" />
+    <png2c Include="include\images\ex_unknown.png" />
+    <png2c Include="include\images\ex_window_aggregate.png" />
+    <png2c Include="include\images\ex_worktable_scan.png" />
+    <png2c Include="include\images\exclude.png" />
+    <png2c Include="include\images\extension-sm.png" />
+    <png2c Include="include\images\extension.png" />
+    <png2c Include="include\images\extensions.png" />
+    <png2c Include="include\images\exttable-sm.png" />
+    <png2c Include="include\images\exttable.png" />
+    <png2c Include="include\images\exttables.png" />
+    <png2c Include="include\images\favourite.png" />
+    <png2c Include="include\images\file_new.png" />
+    <png2c Include="include\images\file_open.png" />
+    <png2c Include="include\images\file_save.png" />
+    <png2c Include="include\images\folder.png" />
+    <png2c Include="include\images\foreigndatawrapper-sm.png" />
+    <png2c Include="include\images\foreigndatawrapper.png" />
+    <png2c Include="include\images\foreigndatawrappers.png" />
+    <png2c Include="include\images\foreignkey.png" />
+    <png2c Include="include\images\foreignkeybad.png" />
+    <png2c Include="include\images\foreignserver-sm.png" />
+    <png2c Include="include\images\foreignserver.png" />
+    <png2c Include="include\images\foreignservers.png" />
+    <png2c Include="include\images\foreigntable.png" />
+    <png2c Include="include\images\foreigntables.png" />
+    <png2c Include="include\images\forward.png" />
+    <png2c Include="include\images\function.png" />
+    <png2c Include="include\images\functions.png" />
+    <png2c Include="include\images\gqbAdd.png" />
+    <png2c Include="include\images\gqbAddRest.png" />
+    <png2c Include="include\images\gqbColNotSel.png" />
+    <png2c Include="include\images\gqbColSel.png" />
+    <png2c Include="include\images\gqbDown.png" />
+    <png2c Include="include\images\gqbDownBottom.png" />
+    <png2c Include="include\images\gqbJoin.png" />
+    <png2c Include="include\images\gqbJoinCursor.png" />
+    <png2c Include="include\images\gqbOrderAdd.png" />
+    <png2c Include="include\images\gqbOrderAddAll.png" />
+    <png2c Include="include\images\gqbOrderRemove.png" />
+    <png2c Include="include\images\gqbOrderRemoveAll.png" />
+    <png2c Include="include\images\gqbRemove.png" />
+    <png2c Include="include\images\gqbRemoveRest.png" />
+    <png2c Include="include\images\gqbUp.png" />
+    <png2c Include="include\images\gqbUpTop.png" />
+    <png2c Include="include\images\group.png" />
+    <png2c Include="include\images\groups.png" />
+    <png2c Include="include\images\help.png" />
+    <png2c Include="include\images\help2.png" />
+    <png2c Include="include\images\hint.png" />
+    <png2c Include="include\images\hint2.png" />
+    <png2c Include="include\images\index.png" />
+    <png2c Include="include\images\indexes.png" />
+    <png2c Include="include\images\job.png" />
+    <png2c Include="include\images\jobdisabled.png" />
+    <png2c Include="include\images\jobs.png" />
+    <png2c Include="include\images\key.png" />
+    <png2c Include="include\images\language-sm.png" />
+    <png2c Include="include\images\language.png" />
+    <png2c Include="include\images\languages.png" />
+    <png2c Include="include\images\loginroles.png" />
+    <png2c Include="include\images\namespace-sm.png" />
+    <png2c Include="include\images\namespace.png" />
+    <png2c Include="include\images\namespaces.png" />
+    <png2c Include="include\images\operator.png" />
+    <png2c Include="include\images\operatorclass.png" />
+    <png2c Include="include\images\operatorclasses.png" />
+    <png2c Include="include\images\operatorfamilies.png" />
+    <png2c Include="include\images\operatorfamily.png" />
+    <png2c Include="include\images\operators.png" />
+    <png2c Include="include\images\package.png" />
+    <png2c Include="include\images\packages.png" />
+    <png2c Include="include\images\parser.png" />
+    <png2c Include="include\images\parsers.png" />
+    <png2c Include="include\images\pgAdmin3-16.png" />
+    <png2c Include="include\images\pgAdmin3-32.png" />
+    <png2c Include="include\images\pgAdmin3.png" />
+    <png2c Include="include\images\plugins.png" />
+    <png2c Include="include\images\primarykey.png" />
+    <png2c Include="include\images\procedure.png" />
+    <png2c Include="include\images\procedures.png" />
+    <png2c Include="include\images\properties.png" />
+    <png2c Include="include\images\property.png" />
+    <png2c Include="include\images\query_cancel.png" />
+    <png2c Include="include\images\query_execfile.png" />
+    <png2c Include="include\images\query_execute.png" />
+    <png2c Include="include\images\query_explain.png" />
+    <png2c Include="include\images\query_pgscript.png" />
+    <png2c Include="include\images\readdata.png" />
+    <png2c Include="include\images\refresh.png" />
+    <png2c Include="include\images\reload.png" />
+    <png2c Include="include\images\restore.png" />
+    <png2c Include="include\images\roles.png" />
+    <png2c Include="include\images\rule.png" />
+    <png2c Include="include\images\rulebad.png" />
+    <png2c Include="include\images\rules.png" />
+    <png2c Include="include\images\schedule.png" />
+    <png2c Include="include\images\schedules.png" />
+    <png2c Include="include\images\sequence-repl.png" />
+    <png2c Include="include\images\sequence.png" />
+    <png2c Include="include\images\sequences.png" />
+    <png2c Include="include\images\server-sm.png" />
+    <png2c Include="include\images\server.png" />
+    <png2c Include="include\images\serverbad-sm.png" />
+    <png2c Include="include\images\serverbad.png" />
+    <png2c Include="include\images\servers.png" />
+    <png2c Include="include\images\setBreak.png" />
+    <png2c Include="include\images\slcluster.png" />
+    <png2c Include="include\images\slclusters.png" />
+    <png2c Include="include\images\sllisten.png" />
+    <png2c Include="include\images\sllistens.png" />
+    <png2c Include="include\images\slnode-disabled.png" />
+    <png2c Include="include\images\slnode-local.png" />
+    <png2c Include="include\images\slnode.png" />
+    <png2c Include="include\images\slnodes.png" />
+    <png2c Include="include\images\slpath.png" />
+    <png2c Include="include\images\slpaths.png" />
+    <png2c Include="include\images\slset.png" />
+    <png2c Include="include\images\slset2.png" />
+    <png2c Include="include\images\slsets.png" />
+    <png2c Include="include\images\slsubscription.png" />
+    <png2c Include="include\images\slsubscription2.png" />
+    <png2c Include="include\images\slsubscriptions.png" />
+    <png2c Include="include\images\sortfilter.png" />
+    <png2c Include="include\images\splash.png" />
+    <png2c Include="include\images\sql-16.png" />
+    <png2c Include="include\images\sql-32.png" />
+    <png2c Include="include\images\sql.png" />
+    <png2c Include="include\images\statistics.png" />
+    <png2c Include="include\images\step.png" />
+    <png2c Include="include\images\stepInto.png" />
+    <png2c Include="include\images\stepOver.png" />
+    <png2c Include="include\images\steps.png" />
+    <png2c Include="include\images\stop.png" />
+    <png2c Include="include\images\storedata.png" />
+    <png2c Include="include\images\synonym.png" />
+    <png2c Include="include\images\synonyms.png" />
+    <png2c Include="include\images\table-repl-sm.png" />
+    <png2c Include="include\images\table-repl.png" />
+    <png2c Include="include\images\table-sm.png" />
+    <png2c Include="include\images\table.png" />
+    <png2c Include="include\images\tables.png" />
+    <png2c Include="include\images\tablespace.png" />
+    <png2c Include="include\images\tablespaces.png" />
+    <png2c Include="include\images\template.png" />
+    <png2c Include="include\images\templates.png" />
+    <png2c Include="include\images\terminate_backend.png" />
+    <png2c Include="include\images\textsearch.png" />
+    <png2c Include="include\images\trigger.png" />
+    <png2c Include="include\images\triggerbad.png" />
+    <png2c Include="include\images\triggerfunction.png" />
+    <png2c Include="include\images\triggerfunctions.png" />
+    <png2c Include="include\images\triggers.png" />
+    <png2c Include="include\images\type.png" />
+    <png2c Include="include\images\types.png" />
+    <png2c Include="include\images\uncheck.png" />
+    <png2c Include="include\images\unchecked.png" />
+    <png2c Include="include\images\unique.png" />
+    <png2c Include="include\images\up.png" />
+    <png2c Include="include\images\user.png" />
+    <png2c Include="include\images\usermapping-sm.png" />
+    <png2c Include="include\images\usermapping.png" />
+    <png2c Include="include\images\usermappings.png" />
+    <png2c Include="include\images\users.png" />
+    <png2c Include="include\images\vacuum.png" />
+    <png2c Include="include\images\variable.png" />
+    <png2c Include="include\images\variables.png" />
+    <png2c Include="include\images\view-sm.png" />
+    <png2c Include="include\images\view.png" />
+    <png2c Include="include\images\viewdata.png" />
+    <png2c Include="include\images\viewfiltereddata.png" />
+    <png2c Include="include\images\views.png" />
+  </ItemGroup>
+  <ItemGroup>
+    <ResourceCompile Include="pgAdmin3.rc" />
+  </ItemGroup>
+  <ItemGroup>
+    <ProjectReference Include="..\xtra\png2c\png2c.vcxproj">
+      <Project>{01191fb5-0037-4e36-ba56-07ce9d9d8cc0}</Project>
+      <ReferenceOutputAssembly>false</ReferenceOutputAssembly>
+    </ProjectReference>
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+    <Import Project="..\pgAdmin3.targets" />
+  </ImportGroup>
 </Project>
\ No newline at end of file
diff --git a/pgadmin/pgAdmin3.vcxproj.filters b/pgadmin/pgAdmin3.vcxproj.filters
index 252589b..2d67e1c 100644
--- a/pgadmin/pgAdmin3.vcxproj.filters
+++ b/pgadmin/pgAdmin3.vcxproj.filters
@@ -1,4310 +1,4439 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="agent">
-      <UniqueIdentifier>{29d12a68-5623-40b8-b480-224efa6720ce}</UniqueIdentifier>
-      <Extensions>*.cpp</Extensions>
-    </Filter>
-    <Filter Include="ctl">
-      <UniqueIdentifier>{722af890-61ca-44cf-af1b-b17487f78f7c}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="db">
-      <UniqueIdentifier>{b4711a6d-480f-4a6a-8f8a-cbc41a802336}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dlg">
-      <UniqueIdentifier>{a3d5e8ea-cb43-448c-a51a-18fd4d223dd9}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="frm">
-      <UniqueIdentifier>{ff19d9e8-f67b-4fe0-be02-69589832a941}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include">
-      <UniqueIdentifier>{9744a466-c06d-4fef-85e0-be4a27630deb}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\utils">
-      <UniqueIdentifier>{d8a57bb3-01aa-4ef3-94b6-1f2e5c3f07fc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\ctl">
-      <UniqueIdentifier>{efe4d829-5e1e-40ae-8413-85400cf8aff3}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\images">
-      <UniqueIdentifier>{931b2f66-4823-4d4b-a328-6975433316d9}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\parser">
-      <UniqueIdentifier>{1d98451c-d3b1-40a4-abd3-0592146ff0fa}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\agent">
-      <UniqueIdentifier>{3feb5747-6682-4dbf-b082-abb2c794f70e}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\slony">
-      <UniqueIdentifier>{2c3cdfd8-8827-4ac7-8dc6-ee3f72f057e8}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dlg">
-      <UniqueIdentifier>{1d95fb56-f4c0-4205-b804-318d60bf8558}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\frm">
-      <UniqueIdentifier>{3b1b313d-6070-4d95-97fe-046a49b624ad}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\schema">
-      <UniqueIdentifier>{bede4cef-3b80-46aa-90ea-76ec261f03d5}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\db">
-      <UniqueIdentifier>{f9761488-73e8-4f6b-b9e3-55b8cbb6a3a2}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\debugger">
-      <UniqueIdentifier>{8c168e54-f1c4-44ee-85d0-4daec103d4f3}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\gqb">
-      <UniqueIdentifier>{df42f3fa-0ac8-4d56-b9c4-1913d5a2c2f0}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript">
-      <UniqueIdentifier>{9cc76601-f308-4f0b-82be-71f838b858ea}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\exceptions">
-      <UniqueIdentifier>{9ee05a7a-1c91-43e2-a6cf-65837ad81162}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\expressions">
-      <UniqueIdentifier>{685491dc-ad16-4121-94df-ba1ae331c95a}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\generators">
-      <UniqueIdentifier>{3c9dc817-cc28-4bc1-aa75-a9b5ff563a60}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\objects">
-      <UniqueIdentifier>{ec385f56-5a98-47d9-834a-23ddee4662d3}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\statements">
-      <UniqueIdentifier>{e6836e8e-e9b4-4d31-bf2d-53bec570bb0a}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\utilities">
-      <UniqueIdentifier>{5a6cbaf8-e21d-4721-a511-f348f06d5b43}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\pgscript\utilities\m_apm">
-      <UniqueIdentifier>{14d6562a-41a3-4626-943f-2312193634cb}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\ogl">
-      <UniqueIdentifier>{0e4a3fb0-dd45-4c7b-813c-b4ceaf66280f}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd">
-      <UniqueIdentifier>{7d6c4241-1d80-4d6d-bb74-77eb1f97a5bc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems">
-      <UniqueIdentifier>{8303ba8b-33ee-46ba-9ea6-55408815381d}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems\figures">
-      <UniqueIdentifier>{9d006cc1-5afd-4497-8237-26e619952c47}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems\figures\xml">
-      <UniqueIdentifier>{287ed0c1-9708-46eb-96a7-7fb9f31013b6}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems\handles">
-      <UniqueIdentifier>{e6be15c5-878e-4919-8cbb-e5fb0cbbf6a9}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems\locators">
-      <UniqueIdentifier>{6f6ac2df-13ba-4b4d-8380-1a82a4a3e0b2}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems\tools">
-      <UniqueIdentifier>{7b58f0d3-eaa9-4f43-80d4-0962a35e45f2}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\dditems\utilities">
-      <UniqueIdentifier>{4c63ed7e-71d0-436a-b3fd-c7241f69369c}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\dd\ddmodel">
-      <UniqueIdentifier>{731ece13-da12-4792-868a-454029f103d9}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw">
-      <UniqueIdentifier>{31655133-e359-4e58-8486-8b6a509d7801}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\connectors">
-      <UniqueIdentifier>{a5ffb000-00dd-47a1-906c-491faff00c2e}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\figures">
-      <UniqueIdentifier>{42c50033-eebe-4dee-b2ef-6ade6560a444}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\figures\defaultAttributes">
-      <UniqueIdentifier>{cd2ecb72-ced4-492e-8196-b855bb03939d}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\figures\xml">
-      <UniqueIdentifier>{e1243dab-46ce-46ad-b949-18a040ae84cc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\handles">
-      <UniqueIdentifier>{978d5148-e038-457c-b332-7db2ff0979fc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\locators">
-      <UniqueIdentifier>{50055ec9-0424-4d82-9ce8-5e77b0dbfa8c}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\main">
-      <UniqueIdentifier>{73c21a26-f48b-4333-b321-c31a2b161e89}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\tools">
-      <UniqueIdentifier>{df9631db-f808-4c98-acc0-cce1b9d4ac5f}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="include\hotdraw\utilities">
-      <UniqueIdentifier>{c0a6ed32-2b3e-4f8a-aa48-5d12472536ec}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="ui">
-      <UniqueIdentifier>{e5220fd8-f837-4fbe-ac01-ef346e8b2d22}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="utils">
-      <UniqueIdentifier>{d8a57bb3-01aa-4ef3-94b6-1f2e5c3f07fc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="slony">
-      <UniqueIdentifier>{2c3cdfd8-8827-4fef-8dc6-ee3f72f057e8}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="debugger">
-      <UniqueIdentifier>{8c168e54-f1c4-8dc6-85d0-4daec103d4f3}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="gqb">
-      <UniqueIdentifier>{df42f3fa-0ac8-4d56-b9c4-1913d5a2c2f0}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript">
-      <UniqueIdentifier>{9cc76601-f308-4f0b-82be-1913d5a2c2f0}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\exceptions">
-      <UniqueIdentifier>{9ee05a7a-1c91-43e2-c06d-65837ad81162}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\expressions">
-      <UniqueIdentifier>{685491dc-ad16-4121-4bc1-ba1ae331c95a}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\generators">
-      <UniqueIdentifier>{3c9dc817-cc28-4bc1-4121-a9b5ff563a60}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\objects">
-      <UniqueIdentifier>{ec385f56-5a98-cc28-834a-23ddee4662d3}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\statements">
-      <UniqueIdentifier>{e6836e8e-e9b4-834a-bf2d-53bec570bb0a}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\utilities">
-      <UniqueIdentifier>{5a6cbaf8-e51d-4721-a511-f348f06d5b43}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="pgscript\utilities\m_apm">
-      <UniqueIdentifier>{14d6562a-41a3-4346-943f-2312193634cb}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="ogl">
-      <UniqueIdentifier>{0e4d3fb0-dd45-4c7b-813c-b4ceaf66280f}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd">
-      <UniqueIdentifier>{7d6c4241-1d80-4d6d-ee74-77eb1f97a5bc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems">
-      <UniqueIdentifier>{8303ba8b-33bb-46ba-9ea6-55408815381d}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems\figures">
-      <UniqueIdentifier>{9d006cc1-5abd-4497-8237-26e619952c47}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems\figures\xml">
-      <UniqueIdentifier>{287ed0c1-2508-46eb-96a7-7fb9f31013b6}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems\handles">
-      <UniqueIdentifier>{e6be15c5-873a-4919-8cbb-e5fb0cbbf6a9}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems\locators">
-      <UniqueIdentifier>{6f6ac2df-13ba-4b4d-8321-1a82a4a3e0b2}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems\tools">
-      <UniqueIdentifier>{7b58f0d3-eaa9-4f23-40d4-0962a35e45f2}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\dditems\utilities">
-      <UniqueIdentifier>{4c63ed7e-71d0-562a-b3fd-c7241f69369c}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="dd\ddmodel">
-      <UniqueIdentifier>{731ece13-cb12-4792-868a-454029f103d9}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw">
-      <UniqueIdentifier>{31655331-e359-4e58-8486-8b6a509d7801}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\connectors">
-      <UniqueIdentifier>{a5ffb112-00dd-47a1-906c-491faff00c2e}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\figures">
-      <UniqueIdentifier>{42c54433-eebe-4dee-b2ef-6ade6560a444}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\figures\defaultAttributes">
-      <UniqueIdentifier>{cd2ecb72-ced4-492e-8196-b855bb03429d}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\figures\xml">
-      <UniqueIdentifier>{e1243dab-46ce-46ad-b949-18a181ae84cc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\handles">
-      <UniqueIdentifier>{978d5153-e038-457c-b332-7db2ff0979fc}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\locators">
-      <UniqueIdentifier>{50123ec9-0424-4d82-9ce8-5e77b0dbfa8c}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\main">
-      <UniqueIdentifier>{73c56a26-f48b-4333-b321-c31a2b161e89}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\tools">
-      <UniqueIdentifier>{df9631db-f808-4c98-acc0-aab1b9d4ac5f}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="hotdraw\utilities">
-      <UniqueIdentifier>{c0a6ed25-2b3e-4f8a-aa48-5d12472536ec}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="ui">
-      <UniqueIdentifier>{e5220fd8-f837-4fbe-ac01-ef346e8b2d22}</UniqueIdentifier>
-    </Filter>
-    <Filter Include="schema">
-      <UniqueIdentifier>{d4220fd8-f837-4fbe-ac01-ef346e8b2d22}</UniqueIdentifier>
-    </Filter>
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="agent\dlgJob.cpp">
-      <Filter>agent</Filter>
-    </ClCompile>
-    <ClCompile Include="agent\dlgSchedule.cpp">
-      <Filter>agent</Filter>
-    </ClCompile>
-    <ClCompile Include="agent\dlgStep.cpp">
-      <Filter>agent</Filter>
-    </ClCompile>
-    <ClCompile Include="agent\pgaJob.cpp">
-      <Filter>agent</Filter>
-    </ClCompile>
-    <ClCompile Include="agent\pgaSchedule.cpp">
-      <Filter>agent</Filter>
-    </ClCompile>
-    <ClCompile Include="agent\pgaStep.cpp">
-      <Filter>agent</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\calbox.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlAuiNotebook.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlCheckTreeView.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlColourPicker.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlComboBox.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlDefaultSecurityPanel.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlListView.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlMenuToolbar.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlSeclabelPanel.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlSecurityPanel.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlSQLBox.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlSQLGrid.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlSQLResult.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\ctlTree.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\explainCanvas.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\explainShape.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\timespin.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_calb.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_ctlchecktreeview.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_ctlcolourpicker.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_ctlcombo.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_ctltree.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_sqlbox.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="ctl\xh_timespin.cpp">
-      <Filter>ctl</Filter>
-    </ClCompile>
-    <ClCompile Include="db\keywords.c">
-      <Filter>db</Filter>
-    </ClCompile>
-    <ClCompile Include="db\pgConn.cpp">
-      <Filter>db</Filter>
-    </ClCompile>
-    <ClCompile Include="db\pgQueryThread.cpp">
-      <Filter>db</Filter>
-    </ClCompile>
-    <ClCompile Include="db\pgSet.cpp">
-      <Filter>db</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgAddFavourite.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgAggregate.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgCast.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgCheck.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgClasses.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgCollation.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgColumn.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgConnect.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgConversion.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgDatabase.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgDomain.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgEditGridOptions.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgExtension.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgExtTable.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgFindReplace.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgForeignDataWrapper.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgForeignKey.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgForeignServer.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgForeignTable.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgFunction.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgGroup.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgHbaConfig.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgIndex.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgIndexConstraint.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgLanguage.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgMainConfig.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgManageFavourites.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgManageMacros.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgOperator.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgPackage.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgPgpassConfig.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgProperty.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgReassignDropOwned.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgRole.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgRule.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgSchema.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgSearchObject.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgSelectConnection.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgSelectDatabase.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgSequence.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgServer.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgSynonym.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTable.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTablespace.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTextSearchConfiguration.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTextSearchDictionary.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTextSearchParser.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTextSearchTemplate.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgTrigger.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgType.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgUser.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgUserMapping.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="dlg\dlgView.cpp">
-      <Filter>dlg</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\events.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmAbout.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmBackup.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmBackupGlobals.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmBackupServer.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmConfig.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmDatabaseDesigner.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmEditGrid.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmExport.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmGrantWizard.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmHbaConfig.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmHint.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmImport.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmMain.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmMainConfig.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmMaintenance.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmOptions.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmPassword.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmPgpassConfig.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmQuery.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmReport.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmRestore.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmSplash.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\frmStatus.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="frm\plugins.cpp">
-      <Filter>frm</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\edbPackage.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\edbPackageFunction.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\edbPackageVariable.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\edbPrivateSynonym.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\edbSynonym.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\gpExtTable.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\gpPartition.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\gpResQueue.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgAggregate.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgCast.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgCatalogObject.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgCheck.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgCollation.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgCollection.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgColumn.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgConstraints.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgConversion.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgDatabase.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgDatatype.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgDomain.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgExtension.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgForeignDataWrapper.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgForeignKey.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgForeignServer.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgForeignTable.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgFunction.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgGroup.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgIndex.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgIndexConstraint.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgLanguage.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgObject.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgOperator.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgOperatorClass.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgOperatorFamily.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgRole.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgRule.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgSchema.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgSequence.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgServer.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTable.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTablespace.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTextSearchConfiguration.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTextSearchDictionary.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTextSearchParser.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTextSearchTemplate.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgTrigger.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgType.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgUser.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgUserMapping.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="schema\pgView.cpp">
-      <Filter>schema</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepCluster.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepListen.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepNode.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepPath.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepProperty.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepSequence.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepSet.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepSubscription.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\dlgRepTable.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slCluster.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slListen.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slNode.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slPath.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slSequence.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slSet.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slSubscription.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="slony\slTable.cpp">
-      <Filter>slony</Filter>
-    </ClCompile>
-    <ClCompile Include="ui\xrcDialogs.cpp">
-      <Filter>ui</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\csvfiles.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\factory.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\favourites.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\macros.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\misc.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\pgconfig.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\registry.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\sysLogger.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\sysProcess.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\sysSettings.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\tabcomplete.c">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="utils\utffile.cpp">
-      <Filter>utils</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\ctlCodeWindow.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\ctlMessageWindow.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\ctlResultGrid.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\ctlStackWindow.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\ctlTabWindow.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\ctlVarWindow.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dbgBreakPoint.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dbgDbResult.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dbgPgConn.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dbgPgThread.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dbgResultset.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dbgTargetInfo.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\debugger.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\dlgDirectDbg.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="debugger\frmDebugger.cpp">
-      <Filter>debugger</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbArrayCollection.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbBrowser.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbCollection.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbColumn.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbController.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbDatabase.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbGraphSimple.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbGridJoinTable.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbGridOrderTable.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbGridProjTable.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbGridRestTable.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbModel.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbObject.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbObjectCollection.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbQueryObjs.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbSchema.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbTable.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbView.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="gqb\gqbViewPanels.cpp">
-      <Filter>gqb</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\lex.pgs.cc">
-      <Filter>pgscript</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\parser.tab.cc">
-      <Filter>pgscript</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\pgsApplication.cpp">
-      <Filter>pgscript</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsArithmeticException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsAssertException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsBreakException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsCastException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsContinueException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsInterruptException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\exceptions\pgsParameterException.cpp">
-      <Filter>pgscript\exceptions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsAnd.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsAssign.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsAssignToRecord.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsCast.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsColumns.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsDifferent.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsEqual.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsExecute.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsExpression.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenDate.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenDateTime.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenDictionary.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenInt.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenReal.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenReference.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenRegex.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenString.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGenTime.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGreater.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsGreaterEqual.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsIdent.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsIdentRecord.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsLines.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsLower.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsLowerEqual.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsMinus.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsModulo.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsNegate.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsNot.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsOperation.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsOr.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsOver.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsParenthesis.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsPlus.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsRemoveLine.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsTimes.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\expressions\pgsTrim.cpp">
-      <Filter>pgscript\expressions</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsDateGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsDateTimeGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsDictionaryGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsIntegerGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsNumberGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsObjectGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsRealGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsReferenceGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsRegexGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsStringGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\generators\pgsTimeGen.cpp">
-      <Filter>pgscript\generators</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\objects\pgsGenerator.cpp">
-      <Filter>pgscript\objects</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\objects\pgsNumber.cpp">
-      <Filter>pgscript\objects</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\objects\pgsRecord.cpp">
-      <Filter>pgscript\objects</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\objects\pgsString.cpp">
-      <Filter>pgscript\objects</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\objects\pgsVariable.cpp">
-      <Filter>pgscript\objects</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsAssertStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsBreakStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsContinueStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsDeclareRecordStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsExpressionStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsIfStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsPrintStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsProgram.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsStmtList.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\statements\pgsWhileStmt.cpp">
-      <Filter>pgscript\statements</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\pgsAlloc.cpp">
-      <Filter>pgscript\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\pgsContext.cpp">
-      <Filter>pgscript\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\pgsDriver.cpp">
-      <Filter>pgscript\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\pgsMapm.cpp">
-      <Filter>pgscript\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\pgsThread.cpp">
-      <Filter>pgscript\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\pgsUtilities.cpp">
-      <Filter>pgscript\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm5sin.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_add.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_cpi.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_div.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_exp.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_fam.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_fft.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_flr.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_fpf.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_gcd.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg2.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg3.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg4.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_log.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_mul.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_pow.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_rcp.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_rnd.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_set.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapm_sin.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmasin.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmasn0.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmcbrt.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmcnst.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmfact.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmfmul.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmgues.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmhasn.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmhsin.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmipwr.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmistr.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmpwr2.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmrsin.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmsqrt.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmstck.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmutil.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmutl1.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="pgscript\utilities\m_apm\mapmutl2.cpp">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\basic.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\basic2.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\bmpshape.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\canvas.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\composit.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\constrnt.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\divided.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\drawn.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\lines.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\mfutils.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\ogldiag.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="ogl\oglmisc.cpp">
-      <Filter>ogl</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddColumnFigure.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddColumnKindIcon.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddColumnOptionIcon.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddRelationshipFigure.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddRelationshipItem.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddRelationshipTerminal.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddTableFigure.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\ddTextTableItemFigure.cpp">
-      <Filter>dd\dditems\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\figures\xml\ddXmlStorage.cpp">
-      <Filter>dd\dditems\figures\xml</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\handles\ddAddColButtonHandle.cpp">
-      <Filter>dd\dditems\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\handles\ddAddFkButtonHandle.cpp">
-      <Filter>dd\dditems\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\handles\ddMinMaxTableButtonHandle.cpp">
-      <Filter>dd\dditems\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\handles\ddRemoveTableButtonHandle.cpp">
-      <Filter>dd\dditems\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\handles\ddScrollBarHandle.cpp">
-      <Filter>dd\dditems\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\handles\ddSouthTableSizeHandle.cpp">
-      <Filter>dd\dditems\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\locators\ddAddColLocator.cpp">
-      <Filter>dd\dditems\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\locators\ddAddFkLocator.cpp">
-      <Filter>dd\dditems\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\locators\ddMinMaxTableLocator.cpp">
-      <Filter>dd\dditems\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\locators\ddRemoveTableLocator.cpp">
-      <Filter>dd\dditems\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\locators\ddScrollBarTableLocator.cpp">
-      <Filter>dd\dditems\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\locators\ddTableBottomLocator.cpp">
-      <Filter>dd\dditems\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\tools\ddColumnFigureTool.cpp">
-      <Filter>dd\dditems\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\tools\ddColumnTextTool.cpp">
-      <Filter>dd\dditems\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\utilities\ddPrecisionScaleDialog.cpp">
-      <Filter>dd\dditems\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\utilities\ddSelectKindFksDialog.cpp">
-      <Filter>dd\dditems\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\dditems\utilities\ddTableNameDialog.cpp">
-      <Filter>dd\dditems\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddBrowserDataContainer.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddDatabaseDesign.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddDBReverseEnginering.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddDrawingEditor.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddDrawingView.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddGenerationWizard.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="dd\ddmodel\ddModelBrowser.cpp">
-      <Filter>dd\ddmodel</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\connectors\hdChopBoxConnector.cpp">
-      <Filter>hotdraw\connectors</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\connectors\hdIConnector.cpp">
-      <Filter>hotdraw\connectors</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\connectors\hdLocatorConnector.cpp">
-      <Filter>hotdraw\connectors</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\connectors\hdStickyRectangleConnector.cpp">
-      <Filter>hotdraw\connectors</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdAbstractFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdAbstractMenuFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdAttribute.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdAttributeFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdBitmapFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdCompositeFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdIConnectionFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdIFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdLineConnection.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdLineTerminal.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdPolyLineFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdRectangleFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\hdSimpleTextFigure.cpp">
-      <Filter>hotdraw\figures</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFillAttribute.cpp">
-      <Filter>hotdraw\figures\defaultAttributes</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontAttribute.cpp">
-      <Filter>hotdraw\figures\defaultAttributes</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontColorAttribute.cpp">
-      <Filter>hotdraw\figures\defaultAttributes</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\defaultAttributes\hdLineAttribute.cpp">
-      <Filter>hotdraw\figures\defaultAttributes</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\figures\xml\hdStorage.cpp">
-      <Filter>hotdraw\figures\xml</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdButtonHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdChangeConnectionEndHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdChangeConnectionHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdChangeConnectionStartHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdIHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdLineConnectionHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdLocatorHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\handles\hdPolyLineHandle.cpp">
-      <Filter>hotdraw\handles</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\locators\hdILocator.cpp">
-      <Filter>hotdraw\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\locators\hdPolyLineLocator.cpp">
-      <Filter>hotdraw\locators</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\main\hdDrawing.cpp">
-      <Filter>hotdraw\main</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\main\hdDrawingEditor.cpp">
-      <Filter>hotdraw\main</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\main\hdDrawingView.cpp">
-      <Filter>hotdraw\main</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdAbstractTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdCanvasMenuTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdCompositeFigureTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdConnectionCreationTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdCreationTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdDragCreationTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdDragTrackerTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdFigureTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdHandleTrackerTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdITool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdMenuTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdPolyLineFigureTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdSelectAreaTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdSelectionTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\tools\hdSimpleTextTool.cpp">
-      <Filter>hotdraw\tools</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdArrayCollection.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdCollection.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdGeometry.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdKeyEvent.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdMouseEvent.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdMultiPosRect.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdPoint.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdRect.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="hotdraw\utilities\hdRemoveDeleteDialog.cpp">
-      <Filter>hotdraw\utilities</Filter>
-    </ClCompile>
-    <ClCompile Include="pgAdmin3.cpp" />
-    <ClCompile Include="precomp.cpp" />
-  </ItemGroup>
-  <ItemGroup>
-    <None Include="agent\module.mk">
-      <Filter>agent</Filter>
-    </None>
-    <None Include="ctl\module.mk">
-      <Filter>ctl</Filter>
-    </None>
-    <None Include="db\module.mk">
-      <Filter>db</Filter>
-    </None>
-    <None Include="dlg\module.mk">
-      <Filter>dlg</Filter>
-    </None>
-    <None Include="frm\module.mk">
-      <Filter>frm</Filter>
-    </None>
-    <None Include="include\module.mk">
-      <Filter>include</Filter>
-    </None>
-    <None Include="include\utils\module.mk">
-      <Filter>include\utils</Filter>
-    </None>
-    <None Include="include\ctl\module.mk">
-      <Filter>include\ctl</Filter>
-    </None>
-    <None Include="include\images\module.mk">
-      <Filter>include\images</Filter>
-    </None>
-    <None Include="include\images\pgAdmin3.ico">
-      <Filter>include\images</Filter>
-    </None>
-    <None Include="include\images\sql.ico">
-      <Filter>include\images</Filter>
-    </None>
-    <None Include="include\parser\module.mk">
-      <Filter>include\parser</Filter>
-    </None>
-    <None Include="include\agent\module.mk">
-      <Filter>include\agent</Filter>
-    </None>
-    <None Include="include\slony\module.mk">
-      <Filter>include\slony</Filter>
-    </None>
-    <None Include="include\dlg\module.mk">
-      <Filter>include\dlg</Filter>
-    </None>
-    <None Include="include\frm\module.mk">
-      <Filter>include\frm</Filter>
-    </None>
-    <None Include="include\schema\module.mk">
-      <Filter>include\schema</Filter>
-    </None>
-    <None Include="include\db\module.mk">
-      <Filter>include\db</Filter>
-    </None>
-    <None Include="include\gqb\module.mk">
-      <Filter>include\gqb</Filter>
-    </None>
-    <None Include="include\pgscript\location.hh">
-      <Filter>include\pgscript</Filter>
-    </None>
-    <None Include="include\pgscript\parser.tab.hh">
-      <Filter>include\pgscript</Filter>
-    </None>
-    <None Include="include\pgscript\position.hh">
-      <Filter>include\pgscript</Filter>
-    </None>
-    <None Include="include\pgscript\stack.hh">
-      <Filter>include\pgscript</Filter>
-    </None>
-    <None Include="include\pgscript\exceptions\module.mk">
-      <Filter>include\pgscript\exceptions</Filter>
-    </None>
-    <None Include="include\pgscript\expressions\module.mk">
-      <Filter>include\pgscript\expressions</Filter>
-    </None>
-    <None Include="include\pgscript\generators\module.mk">
-      <Filter>include\pgscript\generators</Filter>
-    </None>
-    <None Include="include\pgscript\objects\module.mk">
-      <Filter>include\pgscript\objects</Filter>
-    </None>
-    <None Include="include\pgscript\statements\module.mk">
-      <Filter>include\pgscript\statements</Filter>
-    </None>
-    <None Include="include\pgscript\utilities\module.mk">
-      <Filter>include\pgscript\utilities</Filter>
-    </None>
-    <None Include="include\pgscript\utilities\mapm-lib\license.txt">
-      <Filter>include\pgscript\utilities\m_apm</Filter>
-    </None>
-    <None Include="include\pgscript\utilities\mapm-lib\module.mk">
-      <Filter>include\pgscript\utilities\m_apm</Filter>
-    </None>
-    <None Include="include\ogl\module.mk">
-      <Filter>include\ogl</Filter>
-    </None>
-    <None Include="include\ogl\README">
-      <Filter>include\ogl</Filter>
-    </None>
-    <None Include="include\dd\module.mk">
-      <Filter>include\dd</Filter>
-    </None>
-    <None Include="include\dd\dditems\module.mk">
-      <Filter>include\dd\dditems</Filter>
-    </None>
-    <None Include="include\dd\dditems\figures\module.mk">
-      <Filter>include\dd\dditems\figures</Filter>
-    </None>
-    <None Include="include\dd\dditems\figures\xml\module.mk">
-      <Filter>include\dd\dditems\figures\xml</Filter>
-    </None>
-    <None Include="include\dd\dditems\handles\module.mk">
-      <Filter>include\dd\dditems\handles</Filter>
-    </None>
-    <None Include="include\dd\dditems\locators\module.mk">
-      <Filter>include\dd\dditems\locators</Filter>
-    </None>
-    <None Include="include\dd\dditems\tools\module.mk">
-      <Filter>include\dd\dditems\tools</Filter>
-    </None>
-    <None Include="include\dd\dditems\utilities\module.mk">
-      <Filter>include\dd\dditems\utilities</Filter>
-    </None>
-    <None Include="include\dd\ddmodel\module.mk">
-      <Filter>include\dd\ddmodel</Filter>
-    </None>
-    <None Include="include\hotdraw\module.mk">
-      <Filter>include\hotdraw</Filter>
-    </None>
-    <None Include="include\hotdraw\connectors\module.mk">
-      <Filter>include\hotdraw\connectors</Filter>
-    </None>
-    <None Include="include\hotdraw\figures\module.mk">
-      <Filter>include\hotdraw\figures</Filter>
-    </None>
-    <None Include="include\hotdraw\figures\defaultAttributes\module.mk">
-      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
-    </None>
-    <None Include="include\hotdraw\handles\module.mk">
-      <Filter>include\hotdraw\handles</Filter>
-    </None>
-    <None Include="include\hotdraw\locators\module.mk">
-      <Filter>include\hotdraw\locators</Filter>
-    </None>
-    <None Include="include\hotdraw\main\module.mk">
-      <Filter>include\hotdraw\main</Filter>
-    </None>
-    <None Include="include\hotdraw\tools\module.mk">
-      <Filter>include\hotdraw\tools</Filter>
-    </None>
-    <None Include="include\hotdraw\utilities\module.mk">
-      <Filter>include\hotdraw\utilities</Filter>
-    </None>
-    <None Include="schema\module.mk">
-      <Filter>schema</Filter>
-    </None>
-    <None Include="slony\module.mk">
-      <Filter>slony</Filter>
-    </None>
-    <None Include="ui\dlgAddFavourite.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgAggregate.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgCast.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgCheck.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgCollation.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgColumn.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgConnect.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgConversion.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgDatabase.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgDirectDbg.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgDomain.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgEditGridOptions.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgExtension.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgExtTable.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgFindReplace.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgForeignDataWrapper.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgForeignKey.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgForeignServer.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgForeignTable.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgFunction.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgGroup.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgHbaConfig.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgIndex.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgIndexConstraint.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgJob.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgLanguage.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgMainConfig.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgManageFavourites.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgManageMacros.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgOperator.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgPackage.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgPgpassConfig.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgReassignDropOwned.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepCluster.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepClusterUpgrade.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepListen.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepNode.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepPath.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepSequence.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepSet.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepSetMerge.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepSetMove.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepSubscription.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRepTable.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRole.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgRule.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgSchedule.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgSchema.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgSearchObject.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgSelectConnection.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgSequence.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgServer.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgStep.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgSynonym.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTable.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTablespace.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTextSearchConfiguration.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTextSearchDictionary.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTextSearchParser.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTextSearchTemplate.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgTrigger.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgType.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgUser.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgUserMapping.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\dlgView.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\embed-xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\embed-xrc.bat">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmBackup.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmBackupGlobals.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmBackupServer.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmExport.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmGrantWizard.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmHint.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmMaintenance.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmOptions.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmPassword.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmReport.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\frmRestore.xrc">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="ui\module.mk">
-      <Filter>ui</Filter>
-    </None>
-    <None Include="utils\module.mk">
-      <Filter>utils</Filter>
-    </None>
-    <None Include="utils\tab-complete.inc">
-      <Filter>utils</Filter>
-    </None>
-    <None Include="utils\tabcomplete.pl">
-      <Filter>utils</Filter>
-    </None>
-    <None Include="gqb\module.mk">
-      <Filter>gqb</Filter>
-    </None>
-    <None Include="pgscript\module.mk">
-      <Filter>pgscript</Filter>
-    </None>
-    <None Include="pgscript\parser.sh">
-      <Filter>pgscript</Filter>
-    </None>
-    <None Include="pgscript\pgsParser.yy">
-      <Filter>pgscript</Filter>
-    </None>
-    <None Include="pgscript\pgsScanner.ll">
-      <Filter>pgscript</Filter>
-    </None>
-    <None Include="pgscript\README">
-      <Filter>pgscript</Filter>
-    </None>
-    <None Include="pgscript\exceptions\module.mk">
-      <Filter>pgscript\exceptions</Filter>
-    </None>
-    <None Include="pgscript\expressions\module.mk">
-      <Filter>pgscript\expressions</Filter>
-    </None>
-    <None Include="pgscript\generators\module.mk">
-      <Filter>pgscript\generators</Filter>
-    </None>
-    <None Include="pgscript\objects\module.mk">
-      <Filter>pgscript\objects</Filter>
-    </None>
-    <None Include="pgscript\statements\module.mk">
-      <Filter>pgscript\statements</Filter>
-    </None>
-    <None Include="pgscript\utilities\module.mk">
-      <Filter>pgscript\utilities</Filter>
-    </None>
-    <None Include="pgscript\utilities\m_apm\module.mk">
-      <Filter>pgscript\utilities\m_apm</Filter>
-    </None>
-    <None Include="ogl\module.mk">
-      <Filter>ogl</Filter>
-    </None>
-    <None Include="ogl\README">
-      <Filter>ogl</Filter>
-    </None>
-    <None Include="dd\module.mk">
-      <Filter>dd</Filter>
-    </None>
-    <None Include="dd\dditems\module.mk">
-      <Filter>dd\dditems</Filter>
-    </None>
-    <None Include="dd\dditems\figures\module.mk">
-      <Filter>dd\dditems\figures</Filter>
-    </None>
-    <None Include="dd\dditems\handles\module.mk">
-      <Filter>dd\dditems\handles</Filter>
-    </None>
-    <None Include="dd\dditems\locators\module.mk">
-      <Filter>dd\dditems\locators</Filter>
-    </None>
-    <None Include="dd\dditems\tools\module.mk">
-      <Filter>dd\dditems\tools</Filter>
-    </None>
-    <None Include="dd\dditems\utilities\module.mk">
-      <Filter>dd\dditems\utilities</Filter>
-    </None>
-    <None Include="dd\ddmodel\module.mk">
-      <Filter>dd\ddmodel</Filter>
-    </None>
-    <None Include="hotdraw\module.mk">
-      <Filter>hotdraw</Filter>
-    </None>
-    <None Include="hotdraw\connectors\module.mk">
-      <Filter>hotdraw\connectors</Filter>
-    </None>
-    <None Include="hotdraw\figures\module.mk">
-      <Filter>hotdraw\figures</Filter>
-    </None>
-    <None Include="hotdraw\figures\defaultAttributes\module.mk">
-      <Filter>hotdraw\figures\defaultAttributes</Filter>
-    </None>
-    <None Include="hotdraw\figures\xml\module.mk">
-      <Filter>hotdraw\figures\xml</Filter>
-    </None>
-    <None Include="hotdraw\handles\module.mk">
-      <Filter>hotdraw\handles</Filter>
-    </None>
-    <None Include="hotdraw\locators\module.mk">
-      <Filter>hotdraw\locators</Filter>
-    </None>
-    <None Include="hotdraw\main\module.mk">
-      <Filter>hotdraw\main</Filter>
-    </None>
-    <None Include="hotdraw\tools\module.mk">
-      <Filter>hotdraw\tools</Filter>
-    </None>
-    <None Include="hotdraw\utilities\module.mk">
-      <Filter>hotdraw\utilities</Filter>
-    </None>
-    <None Include="Makefile.am" />
-    <None Include="plugins.ini" />
-    <None Include="settings.ini" />
-    <None Include="ver_svn.bat" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClInclude Include="include\copyright.h">
-      <Filter>include</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgAdmin3.h">
-      <Filter>include</Filter>
-    </ClInclude>
-    <ClInclude Include="include\postgres.h">
-      <Filter>include</Filter>
-    </ClInclude>
-    <ClInclude Include="include\precomp.h">
-      <Filter>include</Filter>
-    </ClInclude>
-    <ClInclude Include="include\svnversion.h">
-      <Filter>include</Filter>
-    </ClInclude>
-    <ClInclude Include="include\version.h">
-      <Filter>include</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\csvfiles.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\factory.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\favourites.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\macros.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\misc.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\pgconfig.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\pgDefs.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\pgfeatures.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\registr.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\registry.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\sysLogger.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\sysProcess.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\sysSettings.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\utils\utffile.h">
-      <Filter>include\utils</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\calbox.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlAuiNotebook.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlCheckTreeView.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlColourPicker.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlComboBox.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlDefaultSecurityPanel.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlListView.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlMenuToolbar.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlSeclabelPanel.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlSecurityPanel.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlSQLBox.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlSQLGrid.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlSQLResult.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\ctlTree.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\explainCanvas.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\timespin.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\wxgridsel.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_calb.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_ctlchecktreeview.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_ctlcolourpicker.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_ctlcombo.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_ctltree.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_sqlbox.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ctl\xh_timespin.h">
-      <Filter>include\ctl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\parser\keywords.h">
-      <Filter>include\parser</Filter>
-    </ClInclude>
-    <ClInclude Include="include\agent\dlgJob.h">
-      <Filter>include\agent</Filter>
-    </ClInclude>
-    <ClInclude Include="include\agent\dlgSchedule.h">
-      <Filter>include\agent</Filter>
-    </ClInclude>
-    <ClInclude Include="include\agent\dlgStep.h">
-      <Filter>include\agent</Filter>
-    </ClInclude>
-    <ClInclude Include="include\agent\pgaJob.h">
-      <Filter>include\agent</Filter>
-    </ClInclude>
-    <ClInclude Include="include\agent\pgaSchedule.h">
-      <Filter>include\agent</Filter>
-    </ClInclude>
-    <ClInclude Include="include\agent\pgaStep.h">
-      <Filter>include\agent</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepCluster.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepListen.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepNode.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepPath.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepProperty.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepSequence.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepSet.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepSubscription.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\dlgRepTable.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slCluster.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slListen.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slNode.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slPath.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slSequence.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slSet.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slSubscription.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\slony\slTable.h">
-      <Filter>include\slony</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgAddFavourite.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgAggregate.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgCast.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgCheck.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgClasses.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgCollation.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgColumn.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgConnect.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgConversion.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgDatabase.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgDomain.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgEditGridOptions.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgExtension.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgExtTable.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgFindReplace.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgForeignDataWrapper.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgForeignKey.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgForeignServer.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgForeignTable.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgFunction.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgGroup.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgHbaConfig.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgIndex.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgIndexConstraint.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgLanguage.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgMainConfig.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgManageFavourites.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgManageMacros.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgOperator.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgPackage.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgPgpassConfig.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgProperty.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgReassignDropOwned.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgRole.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgRule.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgSchema.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgSearchObject.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgSelectConnection.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgSelectDatabase.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgSequence.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgServer.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgSynonym.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTable.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTablespace.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTextSearchConfiguration.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTextSearchDictionary.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTextSearchParser.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTextSearchTemplate.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgTrigger.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgType.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgUser.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgUserMapping.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dlg\dlgView.h">
-      <Filter>include\dlg</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmAbout.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmBackup.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmBackupGlobals.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmBackupServer.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmConfig.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmDatabaseDesigner.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmEditGrid.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmExport.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmGrantWizard.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmHbaConfig.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmHint.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmImport.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmMain.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmMainConfig.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmMaintenance.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmOptions.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmPassword.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmPgpassConfig.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmQuery.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmReport.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmRestore.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmSplash.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\frmStatus.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\frm\menu.h">
-      <Filter>include\frm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\edbPackage.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\edbPackageFunction.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\edbPackageVariable.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\edbPrivateSynonym.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\edbSynonym.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\gpExtTable.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\gpPartition.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\gpResQueue.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgAggregate.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgCast.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgCatalogObject.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgCheck.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgCollation.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgCollection.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgColumn.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgConstraints.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgConversion.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgDatabase.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgDatatype.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgDomain.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgExtension.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgForeignDataWrapper.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgForeignKey.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgForeignServer.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgForeignTable.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgFunction.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgGroup.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgIndex.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgIndexConstraint.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgLanguage.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgObject.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgOperator.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgOperatorClass.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgOperatorFamily.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgRole.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgRule.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgSchema.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgSequence.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgServer.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTable.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTablespace.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTextSearchConfiguration.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTextSearchDictionary.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTextSearchParser.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTextSearchTemplate.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgTrigger.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgType.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgUser.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgUserMapping.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\schema\pgView.h">
-      <Filter>include\schema</Filter>
-    </ClInclude>
-    <ClInclude Include="include\db\pgConn.h">
-      <Filter>include\db</Filter>
-    </ClInclude>
-    <ClInclude Include="include\db\pgQueryThread.h">
-      <Filter>include\db</Filter>
-    </ClInclude>
-    <ClInclude Include="include\db\pgSet.h">
-      <Filter>include\db</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\ctlCodeWindow.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\ctlMessageWindow.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\ctlResultGrid.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\ctlStackWindow.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\ctlTabWindow.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\ctlVarWindow.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgBreakPoint.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgConnProp.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgConst.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgDbResult.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgPgConn.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgPgThread.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgResultset.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dbgTargetInfo.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\debugger.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\dlgDirectDbg.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\debugger\frmDebugger.h">
-      <Filter>include\debugger</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbArrayCollection.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbBrowser.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbCollection.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbCollectionBase.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbColumn.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbDatabase.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbEvents.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbGraphBehavior.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbGraphSimple.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbGridJoinTable.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbGridOrderTable.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbGridProjTable.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbGridRestTable.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbModel.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbObject.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbObjectCollection.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbQueryObjs.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbSchema.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbTable.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbViewController.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\gqb\gqbViewPanels.h">
-      <Filter>include\gqb</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\FlexLexer.h">
-      <Filter>include\pgscript</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\pgsApplication.h">
-      <Filter>include\pgscript</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\pgScript.h">
-      <Filter>include\pgscript</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsArithmeticException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsAssertException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsBreakException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsCastException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsContinueException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsInterruptException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\exceptions\pgsParameterException.h">
-      <Filter>include\pgscript\exceptions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsAnd.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsAssign.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsAssignToRecord.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsCast.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsColumns.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsDifferent.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsEqual.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsExecute.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsExpression.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsExpressions.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenDate.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenDateTime.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenDictionary.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenInt.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenReal.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenReference.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenRegex.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenString.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGenTime.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGreater.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsGreaterEqual.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsIdent.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsIdentRecord.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsLines.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsLower.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsLowerEqual.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsMinus.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsModulo.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsNegate.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsNot.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsOperation.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsOr.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsOver.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsParenthesis.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsPlus.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsRemoveLine.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsTimes.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\expressions\pgsTrim.h">
-      <Filter>include\pgscript\expressions</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsDateGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsDateTimeGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsDictionaryGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsIntegerGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsNumberGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsObjectGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsRealGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsReferenceGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsRegexGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsStringGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\generators\pgsTimeGen.h">
-      <Filter>include\pgscript\generators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\objects\pgsGenerator.h">
-      <Filter>include\pgscript\objects</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\objects\pgsNumber.h">
-      <Filter>include\pgscript\objects</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\objects\pgsObjects.h">
-      <Filter>include\pgscript\objects</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\objects\pgsRecord.h">
-      <Filter>include\pgscript\objects</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\objects\pgsString.h">
-      <Filter>include\pgscript\objects</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\objects\pgsVariable.h">
-      <Filter>include\pgscript\objects</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsAssertStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsBreakStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsContinueStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsDeclareRecordStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsExpressionStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsIfStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsPrintStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsProgram.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsStatements.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsStmtList.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\statements\pgsWhileStmt.h">
-      <Filter>include\pgscript\statements</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsAlloc.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsContext.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsCopiedPtr.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsDriver.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsMapm.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsScanner.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsSharedPtr.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsThread.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\pgsUtilities.h">
-      <Filter>include\pgscript\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm.h">
-      <Filter>include\pgscript\utilities\m_apm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm_lc.h">
-      <Filter>include\pgscript\utilities\m_apm</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\basic.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\basicp.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\bmpshape.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\canvas.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\composit.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\constrnt.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\divided.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\drawn.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\drawnp.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\lines.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\linesp.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\mfutils.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\misc.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\ogl.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\ogl\ogldiag.h">
-      <Filter>include\ogl</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddColumnFigure.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddColumnKindIcon.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddColumnOptionIcon.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddRelationshipFigure.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddRelationshipItem.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddRelationshipTerminal.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddTableFigure.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\ddTextTableItemFigure.h">
-      <Filter>include\dd\dditems\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\figures\xml\ddXmlStorage.h">
-      <Filter>include\dd\dditems\figures\xml</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\handles\ddAddColButtonHandle.h">
-      <Filter>include\dd\dditems\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\handles\ddAddFkButtonHandle.h">
-      <Filter>include\dd\dditems\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\handles\ddMinMaxTableButtonHandle.h">
-      <Filter>include\dd\dditems\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\handles\ddRemoveTableButtonHandle.h">
-      <Filter>include\dd\dditems\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\handles\ddScrollBarHandle.h">
-      <Filter>include\dd\dditems\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\handles\ddSouthTableSizeHandle.h">
-      <Filter>include\dd\dditems\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\locators\ddAddColLocator.h">
-      <Filter>include\dd\dditems\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\locators\ddAddFkLocator.h">
-      <Filter>include\dd\dditems\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\locators\ddMinMaxTableLocator.h">
-      <Filter>include\dd\dditems\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\locators\ddRemoveTableLocator.h">
-      <Filter>include\dd\dditems\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\locators\ddScrollBarTableLocator.h">
-      <Filter>include\dd\dditems\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\locators\ddTableBottomLocator.h">
-      <Filter>include\dd\dditems\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\tools\ddColumnFigureTool.h">
-      <Filter>include\dd\dditems\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\tools\ddColumnTextTool.h">
-      <Filter>include\dd\dditems\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\utilities\ddDataType.h">
-      <Filter>include\dd\dditems\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\utilities\ddPrecisionScaleDialog.h">
-      <Filter>include\dd\dditems\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\utilities\ddSelectKindFksDialog.h">
-      <Filter>include\dd\dditems\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\dditems\utilities\ddTableNameDialog.h">
-      <Filter>include\dd\dditems\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddBrowserDataContainer.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddDatabaseDesign.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddDBReverseEngineering.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddDrawingEditor.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddDrawingView.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddGenerationWizard.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\dd\ddmodel\ddModelBrowser.h">
-      <Filter>include\dd\ddmodel</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\connectors\hdChopBoxConnector.h">
-      <Filter>include\hotdraw\connectors</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\connectors\hdIConnector.h">
-      <Filter>include\hotdraw\connectors</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\connectors\hdLocatorConnector.h">
-      <Filter>include\hotdraw\connectors</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\connectors\hdStickyRectangleConnector.h">
-      <Filter>include\hotdraw\connectors</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdAbstractFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdAbstractMenuFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdAttribute.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdAttributeFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdBitmapFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdCompositeFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdIConnectionFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdIFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdLineConnection.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdLineTerminal.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdPolyLineFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdRectangleFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\hdSimpleTextFigure.h">
-      <Filter>include\hotdraw\figures</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFillAttribute.h">
-      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontAttribute.h">
-      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontColorAttribute.h">
-      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdLineAttribute.h">
-      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\figures\xml\hdStorage.h">
-      <Filter>include\hotdraw\figures\xml</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdButtonHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionEndHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionStartHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdIHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdLineConnectionHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdLocatorHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\handles\hdPolyLineHandle.h">
-      <Filter>include\hotdraw\handles</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\locators\hdILocator.h">
-      <Filter>include\hotdraw\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\locators\hdPolyLineLocator.h">
-      <Filter>include\hotdraw\locators</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\main\hdDrawing.h">
-      <Filter>include\hotdraw\main</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\main\hdDrawingEditor.h">
-      <Filter>include\hotdraw\main</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\main\hdDrawingView.h">
-      <Filter>include\hotdraw\main</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\main\hdObject.h">
-      <Filter>include\hotdraw\main</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdAbstractTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdCanvasMenuTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdCompositeFigureTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdConnectionCreationTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdCreationTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdDragCreationTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdDragTrackerTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdFigureTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdHandleTrackerTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdITool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdMenuTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdPolyLineFigureTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdSelectAreaTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdSelectionTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\tools\hdSimpleTextTool.h">
-      <Filter>include\hotdraw\tools</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdArrayCollection.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdCollection.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdCollectionBase.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdGeometry.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdKeyEvent.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdMouseEvent.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdMultiPosRect.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdPoint.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdRect.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-    <ClInclude Include="include\hotdraw\utilities\hdRemoveDeleteDialog.h">
-      <Filter>include\hotdraw\utilities</Filter>
-    </ClInclude>
-  </ItemGroup>
-  <ItemGroup>
-    <png2c Include="include\images\aggregate-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\aggregate.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\aggregates.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\back.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\backup.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\baddatabase.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\cast-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\cast.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\casts.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\catalog-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\catalog.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\catalogobject-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\catalogobject.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\catalogobjects.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\catalogs.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\check.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\checkbad.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\checked.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\clearAll.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\clip_copy.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\clip_cut.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\clip_paste.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\closeddatabase-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\closeddatabase.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\collation-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\collation.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\collations.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\column-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\column.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\columns.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\configuration.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\configurations.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\connect.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\constraints.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\continue.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\conversion.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\conversions.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\create.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\database-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\database.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\databases.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddAddColumn.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddAddColumnCursor.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddAddForeignKey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddcancel.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddDeleteTableCursor.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddDown.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddforeignkey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddforeignkeyfromuk.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddforeignkeyuniquekey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddforeignkeyuniquekeyfromuk.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddgendiagram.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddMaximizeTable.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddMinimizeTable.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddMinMaxCursor.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddmodel-32.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddnewdiagram.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddnotnull.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddnull.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddprimaryforeignkey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddprimaryforeignkeyfromuk.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddprimarykey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddprimarykeyuniquekey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddRelationshipCursor.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddRemoveColumn.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddRemoveColumnCursor.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddRemoveTable.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddRemoveTable2.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddunique.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ddUp.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\debugger.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\delete.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\dictionaries.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\dictionary.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\disabled.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\dnd_copy.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\dnd_move.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\dnd_none.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\domain-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\domain.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\domains.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\down.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\drop.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\edit_clear.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\edit_find.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\edit_redo.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\edit_undo.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\enumeration.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\enumerations.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_aggregate.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_append.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_bmp_heap.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_bmp_index.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_broadcast_motion.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_cte_scan.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_gather_motion.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_group.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_anti_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_semi_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_setop_except.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_setop_except_all.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_setop_intersect.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_setop_intersect_all.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_hash_setop_unknown.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_index_scan.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_limit.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_materialize.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_merge.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_merge_anti_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_merge_semi_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_nested.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_nested_loop_anti_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_nested_loop_semi_join.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_recursive_union.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_redistribute_motion.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_result.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_scan.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_seek.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_setop.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_sort.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_subplan.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_tid_scan.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_unique.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_unknown.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_window_aggregate.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\ex_worktable_scan.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\exclude.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\extension-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\extension.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\extensions.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\exttable-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\exttable.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\exttables.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\favourite.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\file_new.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\file_open.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\file_save.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\folder.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreigndatawrapper-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreigndatawrapper.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreigndatawrappers.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreignkey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreignkeybad.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreignserver-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreignserver.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreignservers.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreigntable.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\foreigntables.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\forward.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\function.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\functions.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbAdd.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbAddRest.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbColNotSel.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbColSel.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbDown.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbDownBottom.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbJoin.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbJoinCursor.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbOrderAdd.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbOrderAddAll.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbOrderRemove.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbOrderRemoveAll.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbRemove.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbRemoveRest.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbUp.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\gqbUpTop.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\group.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\groups.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\help.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\help2.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\hint.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\hint2.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\index.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\indexes.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\job.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\jobdisabled.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\jobs.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\key.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\language-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\language.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\languages.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\loginroles.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\namespace-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\namespace.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\namespaces.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\operator.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\operatorclass.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\operatorclasses.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\operatorfamilies.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\operatorfamily.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\operators.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\package.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\packages.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\parser.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\parsers.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\pgAdmin3-16.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\pgAdmin3-32.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\pgAdmin3.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\plugins.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\primarykey.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\procedure.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\procedures.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\properties.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\property.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\query_cancel.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\query_execfile.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\query_execute.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\query_explain.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\query_pgscript.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\readdata.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\refresh.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\reload.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\restore.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\roles.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\rule.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\rulebad.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\rules.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\schedule.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\schedules.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sequence-repl.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sequence.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sequences.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\server-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\server.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\serverbad-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\serverbad.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\servers.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\setBreak.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slcluster.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slclusters.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sllisten.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sllistens.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slnode-disabled.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slnode-local.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slnode.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slnodes.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slpath.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slpaths.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slset.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slset2.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slsets.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slsubscription.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slsubscription2.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\slsubscriptions.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sortfilter.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\splash.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sql-16.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sql-32.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\sql.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\statistics.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\step.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\stepInto.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\stepOver.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\steps.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\stop.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\storedata.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\synonym.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\synonyms.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\table-repl-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\table-repl.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\table-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\table.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\tables.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\tablespace.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\tablespaces.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\template.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\templates.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\terminate_backend.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\textsearch.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\trigger.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\triggerbad.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\triggerfunction.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\triggerfunctions.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\triggers.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\type.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\types.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\uncheck.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\unchecked.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\unique.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\up.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\user.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\usermapping-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\usermapping.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\usermappings.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\users.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\vacuum.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\variable.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\variables.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\view-sm.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\view.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\viewdata.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\viewfiltereddata.png">
-      <Filter>include\images</Filter>
-    </png2c>
-    <png2c Include="include\images\views.png">
-      <Filter>include\images</Filter>
-    </png2c>
-  </ItemGroup>
-  <ItemGroup>
-    <ResourceCompile Include="pgAdmin3.rc" />
-  </ItemGroup>
+﻿<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup>
+    <Filter Include="agent">
+      <UniqueIdentifier>{29d12a68-5623-40b8-b480-224efa6720ce}</UniqueIdentifier>
+      <Extensions>*.cpp</Extensions>
+    </Filter>
+    <Filter Include="ctl">
+      <UniqueIdentifier>{722af890-61ca-44cf-af1b-b17487f78f7c}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="db">
+      <UniqueIdentifier>{b4711a6d-480f-4a6a-8f8a-cbc41a802336}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dlg">
+      <UniqueIdentifier>{a3d5e8ea-cb43-448c-a51a-18fd4d223dd9}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="frm">
+      <UniqueIdentifier>{ff19d9e8-f67b-4fe0-be02-69589832a941}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include">
+      <UniqueIdentifier>{9744a466-c06d-4fef-85e0-be4a27630deb}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\utils">
+      <UniqueIdentifier>{d8a57bb3-01aa-4ef3-94b6-1f2e5c3f07fc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\ctl">
+      <UniqueIdentifier>{efe4d829-5e1e-40ae-8413-85400cf8aff3}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\images">
+      <UniqueIdentifier>{931b2f66-4823-4d4b-a328-6975433316d9}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\parser">
+      <UniqueIdentifier>{1d98451c-d3b1-40a4-abd3-0592146ff0fa}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\agent">
+      <UniqueIdentifier>{3feb5747-6682-4dbf-b082-abb2c794f70e}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\slony">
+      <UniqueIdentifier>{2c3cdfd8-8827-4ac7-8dc6-ee3f72f057e8}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dlg">
+      <UniqueIdentifier>{1d95fb56-f4c0-4205-b804-318d60bf8558}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\frm">
+      <UniqueIdentifier>{3b1b313d-6070-4d95-97fe-046a49b624ad}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\schema">
+      <UniqueIdentifier>{bede4cef-3b80-46aa-90ea-76ec261f03d5}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\db">
+      <UniqueIdentifier>{f9761488-73e8-4f6b-b9e3-55b8cbb6a3a2}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\debugger">
+      <UniqueIdentifier>{8c168e54-f1c4-44ee-85d0-4daec103d4f3}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\gqb">
+      <UniqueIdentifier>{df42f3fa-0ac8-4d56-b9c4-1913d5a2c2f0}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript">
+      <UniqueIdentifier>{9cc76601-f308-4f0b-82be-71f838b858ea}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\exceptions">
+      <UniqueIdentifier>{9ee05a7a-1c91-43e2-a6cf-65837ad81162}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\expressions">
+      <UniqueIdentifier>{685491dc-ad16-4121-94df-ba1ae331c95a}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\generators">
+      <UniqueIdentifier>{3c9dc817-cc28-4bc1-aa75-a9b5ff563a60}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\objects">
+      <UniqueIdentifier>{ec385f56-5a98-47d9-834a-23ddee4662d3}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\statements">
+      <UniqueIdentifier>{e6836e8e-e9b4-4d31-bf2d-53bec570bb0a}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\utilities">
+      <UniqueIdentifier>{5a6cbaf8-e21d-4721-a511-f348f06d5b43}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\pgscript\utilities\m_apm">
+      <UniqueIdentifier>{14d6562a-41a3-4626-943f-2312193634cb}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\ogl">
+      <UniqueIdentifier>{0e4a3fb0-dd45-4c7b-813c-b4ceaf66280f}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd">
+      <UniqueIdentifier>{7d6c4241-1d80-4d6d-bb74-77eb1f97a5bc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems">
+      <UniqueIdentifier>{8303ba8b-33ee-46ba-9ea6-55408815381d}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems\figures">
+      <UniqueIdentifier>{9d006cc1-5afd-4497-8237-26e619952c47}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems\figures\xml">
+      <UniqueIdentifier>{287ed0c1-9708-46eb-96a7-7fb9f31013b6}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems\handles">
+      <UniqueIdentifier>{e6be15c5-878e-4919-8cbb-e5fb0cbbf6a9}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems\locators">
+      <UniqueIdentifier>{6f6ac2df-13ba-4b4d-8380-1a82a4a3e0b2}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems\tools">
+      <UniqueIdentifier>{7b58f0d3-eaa9-4f43-80d4-0962a35e45f2}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\dditems\utilities">
+      <UniqueIdentifier>{4c63ed7e-71d0-436a-b3fd-c7241f69369c}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\dd\ddmodel">
+      <UniqueIdentifier>{731ece13-da12-4792-868a-454029f103d9}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw">
+      <UniqueIdentifier>{31655133-e359-4e58-8486-8b6a509d7801}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\connectors">
+      <UniqueIdentifier>{a5ffb000-00dd-47a1-906c-491faff00c2e}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\figures">
+      <UniqueIdentifier>{42c50033-eebe-4dee-b2ef-6ade6560a444}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\figures\defaultAttributes">
+      <UniqueIdentifier>{cd2ecb72-ced4-492e-8196-b855bb03939d}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\figures\xml">
+      <UniqueIdentifier>{e1243dab-46ce-46ad-b949-18a040ae84cc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\handles">
+      <UniqueIdentifier>{978d5148-e038-457c-b332-7db2ff0979fc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\locators">
+      <UniqueIdentifier>{50055ec9-0424-4d82-9ce8-5e77b0dbfa8c}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\main">
+      <UniqueIdentifier>{73c21a26-f48b-4333-b321-c31a2b161e89}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\tools">
+      <UniqueIdentifier>{df9631db-f808-4c98-acc0-cce1b9d4ac5f}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\hotdraw\utilities">
+      <UniqueIdentifier>{c0a6ed32-2b3e-4f8a-aa48-5d12472536ec}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="ui">
+      <UniqueIdentifier>{e5220fd8-f837-4fbe-ac01-ef346e8b2d22}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="utils">
+      <UniqueIdentifier>{d8a57bb3-01aa-4ef3-94b6-1f2e5c3f07fc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="slony">
+      <UniqueIdentifier>{2c3cdfd8-8827-4fef-8dc6-ee3f72f057e8}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="debugger">
+      <UniqueIdentifier>{8c168e54-f1c4-8dc6-85d0-4daec103d4f3}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="gqb">
+      <UniqueIdentifier>{df42f3fa-0ac8-4d56-b9c4-1913d5a2c2f0}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript">
+      <UniqueIdentifier>{9cc76601-f308-4f0b-82be-1913d5a2c2f0}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\exceptions">
+      <UniqueIdentifier>{9ee05a7a-1c91-43e2-c06d-65837ad81162}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\expressions">
+      <UniqueIdentifier>{685491dc-ad16-4121-4bc1-ba1ae331c95a}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\generators">
+      <UniqueIdentifier>{3c9dc817-cc28-4bc1-4121-a9b5ff563a60}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\objects">
+      <UniqueIdentifier>{ec385f56-5a98-cc28-834a-23ddee4662d3}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\statements">
+      <UniqueIdentifier>{e6836e8e-e9b4-834a-bf2d-53bec570bb0a}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\utilities">
+      <UniqueIdentifier>{5a6cbaf8-e51d-4721-a511-f348f06d5b43}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="pgscript\utilities\m_apm">
+      <UniqueIdentifier>{14d6562a-41a3-4346-943f-2312193634cb}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="ogl">
+      <UniqueIdentifier>{0e4d3fb0-dd45-4c7b-813c-b4ceaf66280f}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd">
+      <UniqueIdentifier>{7d6c4241-1d80-4d6d-ee74-77eb1f97a5bc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems">
+      <UniqueIdentifier>{8303ba8b-33bb-46ba-9ea6-55408815381d}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems\figures">
+      <UniqueIdentifier>{9d006cc1-5abd-4497-8237-26e619952c47}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems\figures\xml">
+      <UniqueIdentifier>{287ed0c1-2508-46eb-96a7-7fb9f31013b6}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems\handles">
+      <UniqueIdentifier>{e6be15c5-873a-4919-8cbb-e5fb0cbbf6a9}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems\locators">
+      <UniqueIdentifier>{6f6ac2df-13ba-4b4d-8321-1a82a4a3e0b2}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems\tools">
+      <UniqueIdentifier>{7b58f0d3-eaa9-4f23-40d4-0962a35e45f2}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\dditems\utilities">
+      <UniqueIdentifier>{4c63ed7e-71d0-562a-b3fd-c7241f69369c}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="dd\ddmodel">
+      <UniqueIdentifier>{731ece13-cb12-4792-868a-454029f103d9}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw">
+      <UniqueIdentifier>{31655331-e359-4e58-8486-8b6a509d7801}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\connectors">
+      <UniqueIdentifier>{a5ffb112-00dd-47a1-906c-491faff00c2e}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\figures">
+      <UniqueIdentifier>{42c54433-eebe-4dee-b2ef-6ade6560a444}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\figures\defaultAttributes">
+      <UniqueIdentifier>{cd2ecb72-ced4-492e-8196-b855bb03429d}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\figures\xml">
+      <UniqueIdentifier>{e1243dab-46ce-46ad-b949-18a181ae84cc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\handles">
+      <UniqueIdentifier>{978d5153-e038-457c-b332-7db2ff0979fc}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\locators">
+      <UniqueIdentifier>{50123ec9-0424-4d82-9ce8-5e77b0dbfa8c}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\main">
+      <UniqueIdentifier>{73c56a26-f48b-4333-b321-c31a2b161e89}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\tools">
+      <UniqueIdentifier>{df9631db-f808-4c98-acc0-aab1b9d4ac5f}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="hotdraw\utilities">
+      <UniqueIdentifier>{c0a6ed25-2b3e-4f8a-aa48-5d12472536ec}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="ui">
+      <UniqueIdentifier>{e5220fd8-f837-4fbe-ac01-ef346e8b2d22}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="schema">
+      <UniqueIdentifier>{d4220fd8-f837-4fbe-ac01-ef346e8b2d22}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="libssh2">
+      <UniqueIdentifier>{7bb1646b-f0e2-47a3-a91c-0c0257a7ba63}</UniqueIdentifier>
+    </Filter>
+    <Filter Include="include\libssh2">
+      <UniqueIdentifier>{cdefa395-ff9b-4499-aa5d-916694e8d189}</UniqueIdentifier>
+    </Filter>
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="agent\dlgJob.cpp">
+      <Filter>agent</Filter>
+    </ClCompile>
+    <ClCompile Include="agent\dlgSchedule.cpp">
+      <Filter>agent</Filter>
+    </ClCompile>
+    <ClCompile Include="agent\dlgStep.cpp">
+      <Filter>agent</Filter>
+    </ClCompile>
+    <ClCompile Include="agent\pgaJob.cpp">
+      <Filter>agent</Filter>
+    </ClCompile>
+    <ClCompile Include="agent\pgaSchedule.cpp">
+      <Filter>agent</Filter>
+    </ClCompile>
+    <ClCompile Include="agent\pgaStep.cpp">
+      <Filter>agent</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\calbox.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlAuiNotebook.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlCheckTreeView.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlColourPicker.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlComboBox.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlDefaultSecurityPanel.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlListView.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlMenuToolbar.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlSeclabelPanel.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlSecurityPanel.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlSQLBox.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlSQLGrid.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlSQLResult.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\ctlTree.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\explainCanvas.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\explainShape.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\timespin.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_calb.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_ctlchecktreeview.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_ctlcolourpicker.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_ctlcombo.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_ctltree.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_sqlbox.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="ctl\xh_timespin.cpp">
+      <Filter>ctl</Filter>
+    </ClCompile>
+    <ClCompile Include="db\keywords.c">
+      <Filter>db</Filter>
+    </ClCompile>
+    <ClCompile Include="db\pgConn.cpp">
+      <Filter>db</Filter>
+    </ClCompile>
+    <ClCompile Include="db\pgQueryThread.cpp">
+      <Filter>db</Filter>
+    </ClCompile>
+    <ClCompile Include="db\pgSet.cpp">
+      <Filter>db</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgAddFavourite.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgAggregate.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgCast.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgCheck.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgClasses.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgCollation.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgColumn.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgConnect.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgConversion.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgDatabase.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgDomain.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgEditGridOptions.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgExtension.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgExtTable.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgFindReplace.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgForeignDataWrapper.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgForeignKey.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgForeignServer.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgForeignTable.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgFunction.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgGroup.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgHbaConfig.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgIndex.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgIndexConstraint.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgLanguage.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgMainConfig.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgManageFavourites.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgManageMacros.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgOperator.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgPackage.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgPgpassConfig.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgProperty.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgReassignDropOwned.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgRole.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgRule.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgSchema.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgSearchObject.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgSelectConnection.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgSelectDatabase.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgSequence.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgServer.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgSynonym.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTable.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTablespace.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTextSearchConfiguration.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTextSearchDictionary.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTextSearchParser.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTextSearchTemplate.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgTrigger.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgType.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgUser.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgUserMapping.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="dlg\dlgView.cpp">
+      <Filter>dlg</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\events.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmAbout.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmBackup.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmBackupGlobals.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmBackupServer.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmConfig.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmDatabaseDesigner.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmEditGrid.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmExport.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmGrantWizard.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmHbaConfig.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmHint.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmImport.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmMain.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmMainConfig.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmMaintenance.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmOptions.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmPassword.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmPgpassConfig.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmQuery.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmReport.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmRestore.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmSplash.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\frmStatus.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="frm\plugins.cpp">
+      <Filter>frm</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\edbPackage.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\edbPackageFunction.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\edbPackageVariable.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\edbPrivateSynonym.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\edbSynonym.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\gpExtTable.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\gpPartition.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\gpResQueue.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgAggregate.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgCast.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgCatalogObject.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgCheck.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgCollation.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgCollection.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgColumn.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgConstraints.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgConversion.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgDatabase.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgDatatype.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgDomain.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgExtension.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgForeignDataWrapper.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgForeignKey.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgForeignServer.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgForeignTable.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgFunction.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgGroup.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgIndex.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgIndexConstraint.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgLanguage.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgObject.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgOperator.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgOperatorClass.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgOperatorFamily.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgRole.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgRule.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgSchema.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgSequence.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgServer.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTable.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTablespace.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTextSearchConfiguration.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTextSearchDictionary.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTextSearchParser.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTextSearchTemplate.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgTrigger.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgType.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgUser.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgUserMapping.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="schema\pgView.cpp">
+      <Filter>schema</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepCluster.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepListen.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepNode.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepPath.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepProperty.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepSequence.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepSet.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepSubscription.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\dlgRepTable.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slCluster.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slListen.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slNode.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slPath.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slSequence.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slSet.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slSubscription.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="slony\slTable.cpp">
+      <Filter>slony</Filter>
+    </ClCompile>
+    <ClCompile Include="ui\xrcDialogs.cpp">
+      <Filter>ui</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\csvfiles.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\factory.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\favourites.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\macros.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\misc.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\pgconfig.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\registry.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\sysLogger.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\sysProcess.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\sysSettings.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\tabcomplete.c">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="utils\utffile.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\ctlCodeWindow.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\ctlMessageWindow.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\ctlResultGrid.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\ctlStackWindow.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\ctlTabWindow.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\ctlVarWindow.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dbgBreakPoint.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dbgDbResult.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dbgPgConn.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dbgPgThread.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dbgResultset.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dbgTargetInfo.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\debugger.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\dlgDirectDbg.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="debugger\frmDebugger.cpp">
+      <Filter>debugger</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbArrayCollection.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbBrowser.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbCollection.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbColumn.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbController.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbDatabase.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbGraphSimple.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbGridJoinTable.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbGridOrderTable.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbGridProjTable.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbGridRestTable.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbModel.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbObject.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbObjectCollection.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbQueryObjs.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbSchema.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbTable.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbView.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="gqb\gqbViewPanels.cpp">
+      <Filter>gqb</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\lex.pgs.cc">
+      <Filter>pgscript</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\parser.tab.cc">
+      <Filter>pgscript</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\pgsApplication.cpp">
+      <Filter>pgscript</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsArithmeticException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsAssertException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsBreakException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsCastException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsContinueException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsInterruptException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\exceptions\pgsParameterException.cpp">
+      <Filter>pgscript\exceptions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsAnd.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsAssign.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsAssignToRecord.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsCast.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsColumns.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsDifferent.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsEqual.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsExecute.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsExpression.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenDate.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenDateTime.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenDictionary.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenInt.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenReal.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenReference.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenRegex.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenString.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGenTime.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGreater.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsGreaterEqual.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsIdent.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsIdentRecord.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsLines.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsLower.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsLowerEqual.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsMinus.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsModulo.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsNegate.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsNot.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsOperation.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsOr.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsOver.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsParenthesis.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsPlus.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsRemoveLine.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsTimes.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\expressions\pgsTrim.cpp">
+      <Filter>pgscript\expressions</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsDateGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsDateTimeGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsDictionaryGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsIntegerGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsNumberGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsObjectGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsRealGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsReferenceGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsRegexGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsStringGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\generators\pgsTimeGen.cpp">
+      <Filter>pgscript\generators</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\objects\pgsGenerator.cpp">
+      <Filter>pgscript\objects</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\objects\pgsNumber.cpp">
+      <Filter>pgscript\objects</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\objects\pgsRecord.cpp">
+      <Filter>pgscript\objects</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\objects\pgsString.cpp">
+      <Filter>pgscript\objects</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\objects\pgsVariable.cpp">
+      <Filter>pgscript\objects</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsAssertStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsBreakStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsContinueStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsDeclareRecordStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsExpressionStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsIfStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsPrintStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsProgram.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsStmtList.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\statements\pgsWhileStmt.cpp">
+      <Filter>pgscript\statements</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\pgsAlloc.cpp">
+      <Filter>pgscript\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\pgsContext.cpp">
+      <Filter>pgscript\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\pgsDriver.cpp">
+      <Filter>pgscript\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\pgsMapm.cpp">
+      <Filter>pgscript\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\pgsThread.cpp">
+      <Filter>pgscript\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\pgsUtilities.cpp">
+      <Filter>pgscript\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm5sin.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_add.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_cpi.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_div.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_exp.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_fam.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_fft.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_flr.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_fpf.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_gcd.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg2.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg3.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_lg4.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_log.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_mul.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_pow.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_rcp.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_rnd.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_set.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapm_sin.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmasin.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmasn0.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmcbrt.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmcnst.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmfact.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmfmul.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmgues.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmhasn.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmhsin.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmipwr.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmistr.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmpwr2.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmrsin.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmsqrt.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmstck.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmutil.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmutl1.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="pgscript\utilities\m_apm\mapmutl2.cpp">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\basic.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\basic2.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\bmpshape.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\canvas.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\composit.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\constrnt.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\divided.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\drawn.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\lines.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\mfutils.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\ogldiag.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="ogl\oglmisc.cpp">
+      <Filter>ogl</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddColumnFigure.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddColumnKindIcon.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddColumnOptionIcon.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddRelationshipFigure.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddRelationshipItem.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddRelationshipTerminal.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddTableFigure.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\ddTextTableItemFigure.cpp">
+      <Filter>dd\dditems\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\figures\xml\ddXmlStorage.cpp">
+      <Filter>dd\dditems\figures\xml</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\handles\ddAddColButtonHandle.cpp">
+      <Filter>dd\dditems\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\handles\ddAddFkButtonHandle.cpp">
+      <Filter>dd\dditems\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\handles\ddMinMaxTableButtonHandle.cpp">
+      <Filter>dd\dditems\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\handles\ddRemoveTableButtonHandle.cpp">
+      <Filter>dd\dditems\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\handles\ddScrollBarHandle.cpp">
+      <Filter>dd\dditems\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\handles\ddSouthTableSizeHandle.cpp">
+      <Filter>dd\dditems\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\locators\ddAddColLocator.cpp">
+      <Filter>dd\dditems\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\locators\ddAddFkLocator.cpp">
+      <Filter>dd\dditems\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\locators\ddMinMaxTableLocator.cpp">
+      <Filter>dd\dditems\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\locators\ddRemoveTableLocator.cpp">
+      <Filter>dd\dditems\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\locators\ddScrollBarTableLocator.cpp">
+      <Filter>dd\dditems\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\locators\ddTableBottomLocator.cpp">
+      <Filter>dd\dditems\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\tools\ddColumnFigureTool.cpp">
+      <Filter>dd\dditems\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\tools\ddColumnTextTool.cpp">
+      <Filter>dd\dditems\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\utilities\ddPrecisionScaleDialog.cpp">
+      <Filter>dd\dditems\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\utilities\ddSelectKindFksDialog.cpp">
+      <Filter>dd\dditems\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\dditems\utilities\ddTableNameDialog.cpp">
+      <Filter>dd\dditems\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddBrowserDataContainer.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddDatabaseDesign.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddDBReverseEnginering.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddDrawingEditor.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddDrawingView.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddGenerationWizard.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="dd\ddmodel\ddModelBrowser.cpp">
+      <Filter>dd\ddmodel</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\connectors\hdChopBoxConnector.cpp">
+      <Filter>hotdraw\connectors</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\connectors\hdIConnector.cpp">
+      <Filter>hotdraw\connectors</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\connectors\hdLocatorConnector.cpp">
+      <Filter>hotdraw\connectors</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\connectors\hdStickyRectangleConnector.cpp">
+      <Filter>hotdraw\connectors</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdAbstractFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdAbstractMenuFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdAttribute.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdAttributeFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdBitmapFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdCompositeFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdIConnectionFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdIFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdLineConnection.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdLineTerminal.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdPolyLineFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdRectangleFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\hdSimpleTextFigure.cpp">
+      <Filter>hotdraw\figures</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFillAttribute.cpp">
+      <Filter>hotdraw\figures\defaultAttributes</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontAttribute.cpp">
+      <Filter>hotdraw\figures\defaultAttributes</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdFontColorAttribute.cpp">
+      <Filter>hotdraw\figures\defaultAttributes</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\defaultAttributes\hdLineAttribute.cpp">
+      <Filter>hotdraw\figures\defaultAttributes</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\figures\xml\hdStorage.cpp">
+      <Filter>hotdraw\figures\xml</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdButtonHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdChangeConnectionEndHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdChangeConnectionHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdChangeConnectionStartHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdIHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdLineConnectionHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdLocatorHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\handles\hdPolyLineHandle.cpp">
+      <Filter>hotdraw\handles</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\locators\hdILocator.cpp">
+      <Filter>hotdraw\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\locators\hdPolyLineLocator.cpp">
+      <Filter>hotdraw\locators</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\main\hdDrawing.cpp">
+      <Filter>hotdraw\main</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\main\hdDrawingEditor.cpp">
+      <Filter>hotdraw\main</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\main\hdDrawingView.cpp">
+      <Filter>hotdraw\main</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdAbstractTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdCanvasMenuTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdCompositeFigureTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdConnectionCreationTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdCreationTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdDragCreationTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdDragTrackerTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdFigureTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdHandleTrackerTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdITool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdMenuTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdPolyLineFigureTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdSelectAreaTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdSelectionTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\tools\hdSimpleTextTool.cpp">
+      <Filter>hotdraw\tools</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdArrayCollection.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdCollection.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdGeometry.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdKeyEvent.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdMouseEvent.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdMultiPosRect.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdPoint.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdRect.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="hotdraw\utilities\hdRemoveDeleteDialog.cpp">
+      <Filter>hotdraw\utilities</Filter>
+    </ClCompile>
+    <ClCompile Include="pgAdmin3.cpp" />
+    <ClCompile Include="precomp.cpp" />
+    <ClCompile Include="utils\sshTunnel.cpp">
+      <Filter>utils</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\agent.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\channel.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\comp.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\crypt.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\global.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\hostkey.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\keepalive.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\kex.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\knownhost.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\libgcrypt.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\mac.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\misc.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\openssl.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\packet.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\pem.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\publickey.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\scp.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\session.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\sftp.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\transport.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\userauth.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+    <ClCompile Include="libssh2\version.c">
+      <Filter>libssh2</Filter>
+    </ClCompile>
+  </ItemGroup>
+  <ItemGroup>
+    <None Include="agent\module.mk">
+      <Filter>agent</Filter>
+    </None>
+    <None Include="ctl\module.mk">
+      <Filter>ctl</Filter>
+    </None>
+    <None Include="db\module.mk">
+      <Filter>db</Filter>
+    </None>
+    <None Include="dlg\module.mk">
+      <Filter>dlg</Filter>
+    </None>
+    <None Include="frm\module.mk">
+      <Filter>frm</Filter>
+    </None>
+    <None Include="include\module.mk">
+      <Filter>include</Filter>
+    </None>
+    <None Include="include\utils\module.mk">
+      <Filter>include\utils</Filter>
+    </None>
+    <None Include="include\ctl\module.mk">
+      <Filter>include\ctl</Filter>
+    </None>
+    <None Include="include\images\module.mk">
+      <Filter>include\images</Filter>
+    </None>
+    <None Include="include\images\pgAdmin3.ico">
+      <Filter>include\images</Filter>
+    </None>
+    <None Include="include\images\sql.ico">
+      <Filter>include\images</Filter>
+    </None>
+    <None Include="include\parser\module.mk">
+      <Filter>include\parser</Filter>
+    </None>
+    <None Include="include\agent\module.mk">
+      <Filter>include\agent</Filter>
+    </None>
+    <None Include="include\slony\module.mk">
+      <Filter>include\slony</Filter>
+    </None>
+    <None Include="include\dlg\module.mk">
+      <Filter>include\dlg</Filter>
+    </None>
+    <None Include="include\frm\module.mk">
+      <Filter>include\frm</Filter>
+    </None>
+    <None Include="include\schema\module.mk">
+      <Filter>include\schema</Filter>
+    </None>
+    <None Include="include\db\module.mk">
+      <Filter>include\db</Filter>
+    </None>
+    <None Include="include\gqb\module.mk">
+      <Filter>include\gqb</Filter>
+    </None>
+    <None Include="include\pgscript\location.hh">
+      <Filter>include\pgscript</Filter>
+    </None>
+    <None Include="include\pgscript\parser.tab.hh">
+      <Filter>include\pgscript</Filter>
+    </None>
+    <None Include="include\pgscript\position.hh">
+      <Filter>include\pgscript</Filter>
+    </None>
+    <None Include="include\pgscript\stack.hh">
+      <Filter>include\pgscript</Filter>
+    </None>
+    <None Include="include\pgscript\exceptions\module.mk">
+      <Filter>include\pgscript\exceptions</Filter>
+    </None>
+    <None Include="include\pgscript\expressions\module.mk">
+      <Filter>include\pgscript\expressions</Filter>
+    </None>
+    <None Include="include\pgscript\generators\module.mk">
+      <Filter>include\pgscript\generators</Filter>
+    </None>
+    <None Include="include\pgscript\objects\module.mk">
+      <Filter>include\pgscript\objects</Filter>
+    </None>
+    <None Include="include\pgscript\statements\module.mk">
+      <Filter>include\pgscript\statements</Filter>
+    </None>
+    <None Include="include\pgscript\utilities\module.mk">
+      <Filter>include\pgscript\utilities</Filter>
+    </None>
+    <None Include="include\pgscript\utilities\mapm-lib\license.txt">
+      <Filter>include\pgscript\utilities\m_apm</Filter>
+    </None>
+    <None Include="include\pgscript\utilities\mapm-lib\module.mk">
+      <Filter>include\pgscript\utilities\m_apm</Filter>
+    </None>
+    <None Include="include\ogl\module.mk">
+      <Filter>include\ogl</Filter>
+    </None>
+    <None Include="include\ogl\README">
+      <Filter>include\ogl</Filter>
+    </None>
+    <None Include="include\dd\module.mk">
+      <Filter>include\dd</Filter>
+    </None>
+    <None Include="include\dd\dditems\module.mk">
+      <Filter>include\dd\dditems</Filter>
+    </None>
+    <None Include="include\dd\dditems\figures\module.mk">
+      <Filter>include\dd\dditems\figures</Filter>
+    </None>
+    <None Include="include\dd\dditems\figures\xml\module.mk">
+      <Filter>include\dd\dditems\figures\xml</Filter>
+    </None>
+    <None Include="include\dd\dditems\handles\module.mk">
+      <Filter>include\dd\dditems\handles</Filter>
+    </None>
+    <None Include="include\dd\dditems\locators\module.mk">
+      <Filter>include\dd\dditems\locators</Filter>
+    </None>
+    <None Include="include\dd\dditems\tools\module.mk">
+      <Filter>include\dd\dditems\tools</Filter>
+    </None>
+    <None Include="include\dd\dditems\utilities\module.mk">
+      <Filter>include\dd\dditems\utilities</Filter>
+    </None>
+    <None Include="include\dd\ddmodel\module.mk">
+      <Filter>include\dd\ddmodel</Filter>
+    </None>
+    <None Include="include\hotdraw\module.mk">
+      <Filter>include\hotdraw</Filter>
+    </None>
+    <None Include="include\hotdraw\connectors\module.mk">
+      <Filter>include\hotdraw\connectors</Filter>
+    </None>
+    <None Include="include\hotdraw\figures\module.mk">
+      <Filter>include\hotdraw\figures</Filter>
+    </None>
+    <None Include="include\hotdraw\figures\defaultAttributes\module.mk">
+      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
+    </None>
+    <None Include="include\hotdraw\handles\module.mk">
+      <Filter>include\hotdraw\handles</Filter>
+    </None>
+    <None Include="include\hotdraw\locators\module.mk">
+      <Filter>include\hotdraw\locators</Filter>
+    </None>
+    <None Include="include\hotdraw\main\module.mk">
+      <Filter>include\hotdraw\main</Filter>
+    </None>
+    <None Include="include\hotdraw\tools\module.mk">
+      <Filter>include\hotdraw\tools</Filter>
+    </None>
+    <None Include="include\hotdraw\utilities\module.mk">
+      <Filter>include\hotdraw\utilities</Filter>
+    </None>
+    <None Include="schema\module.mk">
+      <Filter>schema</Filter>
+    </None>
+    <None Include="slony\module.mk">
+      <Filter>slony</Filter>
+    </None>
+    <None Include="ui\dlgAddFavourite.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgAggregate.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgCast.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgCheck.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgCollation.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgColumn.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgConnect.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgConversion.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgDatabase.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgDirectDbg.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgDomain.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgEditGridOptions.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgExtension.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgExtTable.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgFindReplace.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgForeignDataWrapper.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgForeignKey.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgForeignServer.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgForeignTable.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgFunction.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgGroup.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgHbaConfig.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgIndex.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgIndexConstraint.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgJob.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgLanguage.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgMainConfig.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgManageFavourites.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgManageMacros.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgOperator.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgPackage.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgPgpassConfig.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgReassignDropOwned.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepCluster.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepClusterUpgrade.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepListen.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepNode.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepPath.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepSequence.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepSet.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepSetMerge.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepSetMove.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepSubscription.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRepTable.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRole.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgRule.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgSchedule.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgSchema.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgSearchObject.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgSelectConnection.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgSequence.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgServer.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgStep.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgSynonym.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTable.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTablespace.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTextSearchConfiguration.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTextSearchDictionary.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTextSearchParser.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTextSearchTemplate.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgTrigger.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgType.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgUser.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgUserMapping.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\dlgView.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\embed-xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\embed-xrc.bat">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmBackup.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmBackupGlobals.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmBackupServer.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmExport.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmGrantWizard.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmHint.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmMaintenance.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmOptions.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmPassword.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmReport.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\frmRestore.xrc">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="ui\module.mk">
+      <Filter>ui</Filter>
+    </None>
+    <None Include="utils\module.mk">
+      <Filter>utils</Filter>
+    </None>
+    <None Include="utils\tab-complete.inc">
+      <Filter>utils</Filter>
+    </None>
+    <None Include="utils\tabcomplete.pl">
+      <Filter>utils</Filter>
+    </None>
+    <None Include="gqb\module.mk">
+      <Filter>gqb</Filter>
+    </None>
+    <None Include="pgscript\module.mk">
+      <Filter>pgscript</Filter>
+    </None>
+    <None Include="pgscript\parser.sh">
+      <Filter>pgscript</Filter>
+    </None>
+    <None Include="pgscript\pgsParser.yy">
+      <Filter>pgscript</Filter>
+    </None>
+    <None Include="pgscript\pgsScanner.ll">
+      <Filter>pgscript</Filter>
+    </None>
+    <None Include="pgscript\README">
+      <Filter>pgscript</Filter>
+    </None>
+    <None Include="pgscript\exceptions\module.mk">
+      <Filter>pgscript\exceptions</Filter>
+    </None>
+    <None Include="pgscript\expressions\module.mk">
+      <Filter>pgscript\expressions</Filter>
+    </None>
+    <None Include="pgscript\generators\module.mk">
+      <Filter>pgscript\generators</Filter>
+    </None>
+    <None Include="pgscript\objects\module.mk">
+      <Filter>pgscript\objects</Filter>
+    </None>
+    <None Include="pgscript\statements\module.mk">
+      <Filter>pgscript\statements</Filter>
+    </None>
+    <None Include="pgscript\utilities\module.mk">
+      <Filter>pgscript\utilities</Filter>
+    </None>
+    <None Include="pgscript\utilities\m_apm\module.mk">
+      <Filter>pgscript\utilities\m_apm</Filter>
+    </None>
+    <None Include="ogl\module.mk">
+      <Filter>ogl</Filter>
+    </None>
+    <None Include="ogl\README">
+      <Filter>ogl</Filter>
+    </None>
+    <None Include="dd\module.mk">
+      <Filter>dd</Filter>
+    </None>
+    <None Include="dd\dditems\module.mk">
+      <Filter>dd\dditems</Filter>
+    </None>
+    <None Include="dd\dditems\figures\module.mk">
+      <Filter>dd\dditems\figures</Filter>
+    </None>
+    <None Include="dd\dditems\handles\module.mk">
+      <Filter>dd\dditems\handles</Filter>
+    </None>
+    <None Include="dd\dditems\locators\module.mk">
+      <Filter>dd\dditems\locators</Filter>
+    </None>
+    <None Include="dd\dditems\tools\module.mk">
+      <Filter>dd\dditems\tools</Filter>
+    </None>
+    <None Include="dd\dditems\utilities\module.mk">
+      <Filter>dd\dditems\utilities</Filter>
+    </None>
+    <None Include="dd\ddmodel\module.mk">
+      <Filter>dd\ddmodel</Filter>
+    </None>
+    <None Include="hotdraw\module.mk">
+      <Filter>hotdraw</Filter>
+    </None>
+    <None Include="hotdraw\connectors\module.mk">
+      <Filter>hotdraw\connectors</Filter>
+    </None>
+    <None Include="hotdraw\figures\module.mk">
+      <Filter>hotdraw\figures</Filter>
+    </None>
+    <None Include="hotdraw\figures\defaultAttributes\module.mk">
+      <Filter>hotdraw\figures\defaultAttributes</Filter>
+    </None>
+    <None Include="hotdraw\figures\xml\module.mk">
+      <Filter>hotdraw\figures\xml</Filter>
+    </None>
+    <None Include="hotdraw\handles\module.mk">
+      <Filter>hotdraw\handles</Filter>
+    </None>
+    <None Include="hotdraw\locators\module.mk">
+      <Filter>hotdraw\locators</Filter>
+    </None>
+    <None Include="hotdraw\main\module.mk">
+      <Filter>hotdraw\main</Filter>
+    </None>
+    <None Include="hotdraw\tools\module.mk">
+      <Filter>hotdraw\tools</Filter>
+    </None>
+    <None Include="hotdraw\utilities\module.mk">
+      <Filter>hotdraw\utilities</Filter>
+    </None>
+    <None Include="Makefile.am" />
+    <None Include="plugins.ini" />
+    <None Include="settings.ini" />
+    <None Include="ver_svn.bat" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClInclude Include="include\copyright.h">
+      <Filter>include</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgAdmin3.h">
+      <Filter>include</Filter>
+    </ClInclude>
+    <ClInclude Include="include\postgres.h">
+      <Filter>include</Filter>
+    </ClInclude>
+    <ClInclude Include="include\precomp.h">
+      <Filter>include</Filter>
+    </ClInclude>
+    <ClInclude Include="include\svnversion.h">
+      <Filter>include</Filter>
+    </ClInclude>
+    <ClInclude Include="include\version.h">
+      <Filter>include</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\csvfiles.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\factory.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\favourites.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\macros.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\misc.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\pgconfig.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\pgDefs.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\pgfeatures.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\registr.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\registry.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\sysLogger.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\sysProcess.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\sysSettings.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\utffile.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\calbox.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlAuiNotebook.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlCheckTreeView.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlColourPicker.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlComboBox.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlDefaultSecurityPanel.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlListView.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlMenuToolbar.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlSeclabelPanel.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlSecurityPanel.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlSQLBox.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlSQLGrid.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlSQLResult.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\ctlTree.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\explainCanvas.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\timespin.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\wxgridsel.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_calb.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_ctlchecktreeview.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_ctlcolourpicker.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_ctlcombo.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_ctltree.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_sqlbox.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ctl\xh_timespin.h">
+      <Filter>include\ctl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\parser\keywords.h">
+      <Filter>include\parser</Filter>
+    </ClInclude>
+    <ClInclude Include="include\agent\dlgJob.h">
+      <Filter>include\agent</Filter>
+    </ClInclude>
+    <ClInclude Include="include\agent\dlgSchedule.h">
+      <Filter>include\agent</Filter>
+    </ClInclude>
+    <ClInclude Include="include\agent\dlgStep.h">
+      <Filter>include\agent</Filter>
+    </ClInclude>
+    <ClInclude Include="include\agent\pgaJob.h">
+      <Filter>include\agent</Filter>
+    </ClInclude>
+    <ClInclude Include="include\agent\pgaSchedule.h">
+      <Filter>include\agent</Filter>
+    </ClInclude>
+    <ClInclude Include="include\agent\pgaStep.h">
+      <Filter>include\agent</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepCluster.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepListen.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepNode.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepPath.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepProperty.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepSequence.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepSet.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepSubscription.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\dlgRepTable.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slCluster.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slListen.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slNode.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slPath.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slSequence.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slSet.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slSubscription.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\slony\slTable.h">
+      <Filter>include\slony</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgAddFavourite.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgAggregate.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgCast.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgCheck.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgClasses.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgCollation.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgColumn.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgConnect.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgConversion.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgDatabase.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgDomain.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgEditGridOptions.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgExtension.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgExtTable.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgFindReplace.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgForeignDataWrapper.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgForeignKey.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgForeignServer.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgForeignTable.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgFunction.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgGroup.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgHbaConfig.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgIndex.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgIndexConstraint.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgLanguage.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgMainConfig.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgManageFavourites.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgManageMacros.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgOperator.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgPackage.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgPgpassConfig.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgProperty.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgReassignDropOwned.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgRole.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgRule.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgSchema.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgSearchObject.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgSelectConnection.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgSelectDatabase.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgSequence.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgServer.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgSynonym.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTable.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTablespace.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTextSearchConfiguration.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTextSearchDictionary.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTextSearchParser.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTextSearchTemplate.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgTrigger.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgType.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgUser.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgUserMapping.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dlg\dlgView.h">
+      <Filter>include\dlg</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmAbout.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmBackup.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmBackupGlobals.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmBackupServer.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmConfig.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmDatabaseDesigner.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmEditGrid.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmExport.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmGrantWizard.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmHbaConfig.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmHint.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmImport.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmMain.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmMainConfig.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmMaintenance.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmOptions.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmPassword.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmPgpassConfig.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmQuery.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmReport.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmRestore.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmSplash.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\frmStatus.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\frm\menu.h">
+      <Filter>include\frm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\edbPackage.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\edbPackageFunction.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\edbPackageVariable.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\edbPrivateSynonym.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\edbSynonym.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\gpExtTable.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\gpPartition.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\gpResQueue.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgAggregate.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgCast.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgCatalogObject.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgCheck.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgCollation.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgCollection.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgColumn.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgConstraints.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgConversion.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgDatabase.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgDatatype.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgDomain.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgExtension.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgForeignDataWrapper.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgForeignKey.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgForeignServer.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgForeignTable.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgFunction.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgGroup.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgIndex.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgIndexConstraint.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgLanguage.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgObject.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgOperator.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgOperatorClass.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgOperatorFamily.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgRole.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgRule.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgSchema.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgSequence.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgServer.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTable.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTablespace.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTextSearchConfiguration.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTextSearchDictionary.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTextSearchParser.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTextSearchTemplate.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgTrigger.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgType.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgUser.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgUserMapping.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\schema\pgView.h">
+      <Filter>include\schema</Filter>
+    </ClInclude>
+    <ClInclude Include="include\db\pgConn.h">
+      <Filter>include\db</Filter>
+    </ClInclude>
+    <ClInclude Include="include\db\pgQueryThread.h">
+      <Filter>include\db</Filter>
+    </ClInclude>
+    <ClInclude Include="include\db\pgSet.h">
+      <Filter>include\db</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\ctlCodeWindow.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\ctlMessageWindow.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\ctlResultGrid.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\ctlStackWindow.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\ctlTabWindow.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\ctlVarWindow.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgBreakPoint.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgConnProp.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgConst.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgDbResult.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgPgConn.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgPgThread.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgResultset.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dbgTargetInfo.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\debugger.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\dlgDirectDbg.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\debugger\frmDebugger.h">
+      <Filter>include\debugger</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbArrayCollection.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbBrowser.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbCollection.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbCollectionBase.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbColumn.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbDatabase.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbEvents.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbGraphBehavior.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbGraphSimple.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbGridJoinTable.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbGridOrderTable.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbGridProjTable.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbGridRestTable.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbModel.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbObject.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbObjectCollection.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbQueryObjs.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbSchema.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbTable.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbViewController.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\gqb\gqbViewPanels.h">
+      <Filter>include\gqb</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\FlexLexer.h">
+      <Filter>include\pgscript</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\pgsApplication.h">
+      <Filter>include\pgscript</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\pgScript.h">
+      <Filter>include\pgscript</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsArithmeticException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsAssertException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsBreakException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsCastException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsContinueException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsInterruptException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\exceptions\pgsParameterException.h">
+      <Filter>include\pgscript\exceptions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsAnd.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsAssign.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsAssignToRecord.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsCast.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsColumns.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsDifferent.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsEqual.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsExecute.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsExpression.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsExpressions.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenDate.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenDateTime.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenDictionary.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenInt.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenReal.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenReference.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenRegex.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenString.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGenTime.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGreater.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsGreaterEqual.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsIdent.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsIdentRecord.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsLines.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsLower.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsLowerEqual.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsMinus.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsModulo.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsNegate.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsNot.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsOperation.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsOr.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsOver.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsParenthesis.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsPlus.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsRemoveLine.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsTimes.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\expressions\pgsTrim.h">
+      <Filter>include\pgscript\expressions</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsDateGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsDateTimeGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsDictionaryGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsIntegerGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsNumberGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsObjectGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsRealGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsReferenceGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsRegexGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsStringGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\generators\pgsTimeGen.h">
+      <Filter>include\pgscript\generators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\objects\pgsGenerator.h">
+      <Filter>include\pgscript\objects</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\objects\pgsNumber.h">
+      <Filter>include\pgscript\objects</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\objects\pgsObjects.h">
+      <Filter>include\pgscript\objects</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\objects\pgsRecord.h">
+      <Filter>include\pgscript\objects</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\objects\pgsString.h">
+      <Filter>include\pgscript\objects</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\objects\pgsVariable.h">
+      <Filter>include\pgscript\objects</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsAssertStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsBreakStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsContinueStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsDeclareRecordStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsExpressionStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsIfStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsPrintStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsProgram.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsStatements.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsStmtList.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\statements\pgsWhileStmt.h">
+      <Filter>include\pgscript\statements</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsAlloc.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsContext.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsCopiedPtr.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsDriver.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsMapm.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsScanner.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsSharedPtr.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsThread.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\pgsUtilities.h">
+      <Filter>include\pgscript\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm.h">
+      <Filter>include\pgscript\utilities\m_apm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\pgscript\utilities\mapm-lib\m_apm_lc.h">
+      <Filter>include\pgscript\utilities\m_apm</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\basic.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\basicp.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\bmpshape.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\canvas.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\composit.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\constrnt.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\divided.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\drawn.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\drawnp.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\lines.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\linesp.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\mfutils.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\misc.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\ogl.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\ogl\ogldiag.h">
+      <Filter>include\ogl</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddColumnFigure.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddColumnKindIcon.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddColumnOptionIcon.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddRelationshipFigure.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddRelationshipItem.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddRelationshipTerminal.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddTableFigure.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\ddTextTableItemFigure.h">
+      <Filter>include\dd\dditems\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\figures\xml\ddXmlStorage.h">
+      <Filter>include\dd\dditems\figures\xml</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\handles\ddAddColButtonHandle.h">
+      <Filter>include\dd\dditems\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\handles\ddAddFkButtonHandle.h">
+      <Filter>include\dd\dditems\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\handles\ddMinMaxTableButtonHandle.h">
+      <Filter>include\dd\dditems\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\handles\ddRemoveTableButtonHandle.h">
+      <Filter>include\dd\dditems\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\handles\ddScrollBarHandle.h">
+      <Filter>include\dd\dditems\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\handles\ddSouthTableSizeHandle.h">
+      <Filter>include\dd\dditems\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\locators\ddAddColLocator.h">
+      <Filter>include\dd\dditems\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\locators\ddAddFkLocator.h">
+      <Filter>include\dd\dditems\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\locators\ddMinMaxTableLocator.h">
+      <Filter>include\dd\dditems\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\locators\ddRemoveTableLocator.h">
+      <Filter>include\dd\dditems\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\locators\ddScrollBarTableLocator.h">
+      <Filter>include\dd\dditems\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\locators\ddTableBottomLocator.h">
+      <Filter>include\dd\dditems\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\tools\ddColumnFigureTool.h">
+      <Filter>include\dd\dditems\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\tools\ddColumnTextTool.h">
+      <Filter>include\dd\dditems\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\utilities\ddDataType.h">
+      <Filter>include\dd\dditems\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\utilities\ddPrecisionScaleDialog.h">
+      <Filter>include\dd\dditems\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\utilities\ddSelectKindFksDialog.h">
+      <Filter>include\dd\dditems\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\dditems\utilities\ddTableNameDialog.h">
+      <Filter>include\dd\dditems\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddBrowserDataContainer.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddDatabaseDesign.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddDBReverseEngineering.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddDrawingEditor.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddDrawingView.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddGenerationWizard.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\dd\ddmodel\ddModelBrowser.h">
+      <Filter>include\dd\ddmodel</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\connectors\hdChopBoxConnector.h">
+      <Filter>include\hotdraw\connectors</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\connectors\hdIConnector.h">
+      <Filter>include\hotdraw\connectors</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\connectors\hdLocatorConnector.h">
+      <Filter>include\hotdraw\connectors</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\connectors\hdStickyRectangleConnector.h">
+      <Filter>include\hotdraw\connectors</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdAbstractFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdAbstractMenuFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdAttribute.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdAttributeFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdBitmapFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdCompositeFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdIConnectionFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdIFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdLineConnection.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdLineTerminal.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdPolyLineFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdRectangleFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\hdSimpleTextFigure.h">
+      <Filter>include\hotdraw\figures</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFillAttribute.h">
+      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontAttribute.h">
+      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdFontColorAttribute.h">
+      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\defaultAttributes\hdLineAttribute.h">
+      <Filter>include\hotdraw\figures\defaultAttributes</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\figures\xml\hdStorage.h">
+      <Filter>include\hotdraw\figures\xml</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdButtonHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionEndHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdChangeConnectionStartHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdIHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdLineConnectionHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdLocatorHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\handles\hdPolyLineHandle.h">
+      <Filter>include\hotdraw\handles</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\locators\hdILocator.h">
+      <Filter>include\hotdraw\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\locators\hdPolyLineLocator.h">
+      <Filter>include\hotdraw\locators</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\main\hdDrawing.h">
+      <Filter>include\hotdraw\main</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\main\hdDrawingEditor.h">
+      <Filter>include\hotdraw\main</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\main\hdDrawingView.h">
+      <Filter>include\hotdraw\main</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\main\hdObject.h">
+      <Filter>include\hotdraw\main</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdAbstractTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdCanvasMenuTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdCompositeFigureTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdConnectionCreationTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdCreationTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdDragCreationTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdDragTrackerTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdFigureTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdHandleTrackerTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdITool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdMenuTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdPolyLineFigureTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdSelectAreaTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdSelectionTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\tools\hdSimpleTextTool.h">
+      <Filter>include\hotdraw\tools</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdArrayCollection.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdCollection.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdCollectionBase.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdGeometry.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdKeyEvent.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdMouseEvent.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdMultiPosRect.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdPoint.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdRect.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\hotdraw\utilities\hdRemoveDeleteDialog.h">
+      <Filter>include\hotdraw\utilities</Filter>
+    </ClInclude>
+    <ClInclude Include="include\utils\sshTunnel.h">
+      <Filter>include\utils</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\channel.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\comp.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\crypto.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\libgcrypt.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\libssh2.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\libssh2_priv.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\libssh2_publickey.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\libssh2_sftp.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\mac.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\misc.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\openssl.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\packet.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\session.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\sftp.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\transport.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\userauth.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+    <ClInclude Include="include\libssh2\Win32\libssh2_config.h">
+      <Filter>include\libssh2</Filter>
+    </ClInclude>
+  </ItemGroup>
+  <ItemGroup>
+    <png2c Include="include\images\aggregate-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\aggregate.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\aggregates.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\back.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\backup.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\baddatabase.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\cast-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\cast.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\casts.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\catalog-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\catalog.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\catalogobject-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\catalogobject.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\catalogobjects.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\catalogs.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\check.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\checkbad.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\checked.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\clearAll.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\clip_copy.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\clip_cut.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\clip_paste.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\closeddatabase-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\closeddatabase.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\collation-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\collation.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\collations.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\column-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\column.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\columns.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\configuration.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\configurations.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\connect.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\constraints.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\continue.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\conversion.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\conversions.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\create.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\database-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\database.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\databases.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddAddColumn.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddAddColumnCursor.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddAddForeignKey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddcancel.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddDeleteTableCursor.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddDown.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddforeignkey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddforeignkeyfromuk.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddforeignkeyuniquekey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddforeignkeyuniquekeyfromuk.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddgendiagram.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddMaximizeTable.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddMinimizeTable.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddMinMaxCursor.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddmodel-32.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddnewdiagram.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddnotnull.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddnull.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddprimaryforeignkey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddprimaryforeignkeyfromuk.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddprimarykey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddprimarykeyuniquekey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddRelationshipCursor.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddRemoveColumn.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddRemoveColumnCursor.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddRemoveTable.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddRemoveTable2.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddunique.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ddUp.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\debugger.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\delete.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\dictionaries.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\dictionary.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\disabled.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\dnd_copy.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\dnd_move.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\dnd_none.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\domain-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\domain.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\domains.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\down.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\drop.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\edit_clear.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\edit_find.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\edit_redo.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\edit_undo.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\enumeration.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\enumerations.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_aggregate.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_append.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_bmp_heap.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_bmp_index.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_broadcast_motion.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_cte_scan.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_gather_motion.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_group.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_anti_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_semi_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_setop_except.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_setop_except_all.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_setop_intersect.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_setop_intersect_all.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_hash_setop_unknown.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_index_scan.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_limit.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_materialize.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_merge.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_merge_anti_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_merge_semi_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_nested.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_nested_loop_anti_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_nested_loop_semi_join.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_recursive_union.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_redistribute_motion.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_result.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_scan.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_seek.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_setop.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_sort.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_subplan.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_tid_scan.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_unique.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_unknown.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_window_aggregate.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\ex_worktable_scan.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\exclude.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\extension-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\extension.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\extensions.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\exttable-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\exttable.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\exttables.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\favourite.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\file_new.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\file_open.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\file_save.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\folder.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreigndatawrapper-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreigndatawrapper.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreigndatawrappers.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreignkey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreignkeybad.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreignserver-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreignserver.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreignservers.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreigntable.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\foreigntables.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\forward.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\function.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\functions.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbAdd.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbAddRest.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbColNotSel.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbColSel.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbDown.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbDownBottom.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbJoin.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbJoinCursor.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbOrderAdd.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbOrderAddAll.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbOrderRemove.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbOrderRemoveAll.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbRemove.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbRemoveRest.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbUp.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\gqbUpTop.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\group.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\groups.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\help.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\help2.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\hint.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\hint2.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\index.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\indexes.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\job.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\jobdisabled.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\jobs.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\key.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\language-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\language.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\languages.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\loginroles.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\namespace-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\namespace.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\namespaces.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\operator.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\operatorclass.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\operatorclasses.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\operatorfamilies.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\operatorfamily.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\operators.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\package.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\packages.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\parser.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\parsers.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\pgAdmin3-16.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\pgAdmin3-32.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\pgAdmin3.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\plugins.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\primarykey.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\procedure.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\procedures.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\properties.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\property.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\query_cancel.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\query_execfile.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\query_execute.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\query_explain.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\query_pgscript.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\readdata.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\refresh.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\reload.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\restore.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\roles.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\rule.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\rulebad.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\rules.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\schedule.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\schedules.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sequence-repl.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sequence.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sequences.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\server-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\server.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\serverbad-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\serverbad.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\servers.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\setBreak.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slcluster.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slclusters.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sllisten.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sllistens.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slnode-disabled.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slnode-local.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slnode.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slnodes.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slpath.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slpaths.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slset.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slset2.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slsets.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slsubscription.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slsubscription2.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\slsubscriptions.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sortfilter.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\splash.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sql-16.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sql-32.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\sql.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\statistics.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\step.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\stepInto.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\stepOver.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\steps.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\stop.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\storedata.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\synonym.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\synonyms.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\table-repl-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\table-repl.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\table-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\table.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\tables.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\tablespace.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\tablespaces.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\template.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\templates.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\terminate_backend.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\textsearch.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\trigger.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\triggerbad.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\triggerfunction.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\triggerfunctions.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\triggers.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\type.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\types.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\uncheck.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\unchecked.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\unique.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\up.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\user.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\usermapping-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\usermapping.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\usermappings.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\users.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\vacuum.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\variable.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\variables.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\view-sm.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\view.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\viewdata.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\viewfiltereddata.png">
+      <Filter>include\images</Filter>
+    </png2c>
+    <png2c Include="include\images\views.png">
+      <Filter>include\images</Filter>
+    </png2c>
+  </ItemGroup>
+  <ItemGroup>
+    <ResourceCompile Include="pgAdmin3.rc" />
+  </ItemGroup>
 </Project>
\ No newline at end of file
diff --git a/pgadmin/precomp.cpp b/pgadmin/precomp.cpp
index 58d2abb..edee794 100644
--- a/pgadmin/precomp.cpp
+++ b/pgadmin/precomp.cpp
@@ -9,6 +9,10 @@
 //
 //////////////////////////////////////////////////////////////////////////
 
+#ifdef WIN32
+#define WIN32_LEAN_AND_MEAN
+#endif
+
 #include <wx/wxprec.h>
 
 #include "pgAdmin3.h"
diff --git a/pgadmin/schema/pgServer.cpp b/pgadmin/schema/pgServer.cpp
index d6e51e1..09b8b53 100644
--- a/pgadmin/schema/pgServer.cpp
+++ b/pgadmin/schema/pgServer.cpp
@@ -38,9 +38,16 @@
 #include "frm/frmReport.h"
 #include "dlg/dlgServer.h"
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+#include "utils/sshTunnel.h"
+#endif
+
 #define DEFAULT_PG_DATABASE wxT("postgres")
 
-pgServer::pgServer(const wxString &newName, const wxString &newHostAddr, const wxString &newDescription, const wxString &newService, const wxString &newDatabase, const wxString &newUsername, int newPort, bool _storePwd, const wxString &newRolename, bool _restore, int _ssl, const wxString &_colour, const wxString &_group)
+pgServer::pgServer(const wxString &newName, const wxString &newHostAddr, const wxString &newDescription, const wxString &newService,
+                   const wxString &newDatabase, const wxString &newUsername, int newPort, bool _storePwd, const wxString &newRolename, bool _restore,
+                   int _ssl, const wxString &_colour, const wxString &_group, bool _sshTunnel, const wxString &newTunnelHost, const wxString &newTunnelUserName,
+                   bool _authModePwd, const wxString &newTunnelPassword, const wxString &newPublicKey, const wxString &newIdentity)
 	: pgObject(serverFactory, newName)
 {
 	description = newDescription;
@@ -65,6 +72,19 @@ pgServer::pgServer(const wxString &newName, const wxString &newHostAddr, const w
 	restore = _restore;
 	superUser = false;
 	createPrivilege = false;
+	sshTunnel = _sshTunnel;
+
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	// SSH Tunnel
+	tunnelObj = NULL;
+	tunnelHost = newTunnelHost;
+	tunnelUserName = newTunnelUserName;
+	authModePwd = _authModePwd;
+	tunnelPassword = newTunnelPassword;
+	publicKeyFile = newPublicKey;
+	identityFile = newIdentity;
+#endif
+
 #ifdef WIN32
 	scmHandle = 0;
 	serviceHandle = 0;
@@ -76,6 +96,17 @@ pgServer::~pgServer()
 	if (conn)
 		delete conn;
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	if(tunnelObj)
+	{
+		if(tunnelObj->IsAlive())
+		{
+			tunnelObj->Cleanup();
+		}
+		tunnelObj = NULL;
+	}
+#endif
+
 #ifdef WIN32
 	if (serviceHandle)
 		CloseServiceHandle(serviceHandle);
@@ -188,7 +219,18 @@ pgConn *pgServer::CreateConn(wxString dbName, OID oid, wxString applicationname)
 		dbName = GetDatabaseName();
 		oid = dbOid;
 	}
-	pgConn *conn = new pgConn(GetName(), service, hostaddr, dbName, username, password, port, rolename, ssl, oid, applicationname, sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
+
+	pgConn *conn = NULL;
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	if(sshTunnel)
+	{
+		conn = new pgConn(local_listenhost, service, hostaddr, dbName, username, password, local_listenport, rolename, ssl, oid, applicationname, sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
+	}
+	else
+#endif
+	{
+		conn = new pgConn(GetName(), service, hostaddr, dbName, username, password, port, rolename, ssl, oid, applicationname, sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
+	}
 
 	if (conn && conn->GetStatus() != PGCONN_OK)
 	{
@@ -215,6 +257,17 @@ wxString pgServer::GetFullIdentifier()
 
 bool pgServer::Disconnect(frmMain *form)
 {
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	if(tunnelObj)
+	{
+		if(tunnelObj->IsAlive())
+		{
+			tunnelObj->Cleanup();
+		}
+		tunnelObj = NULL;
+	}
+#endif
+
 	if (conn)
 	{
 		delete conn;
@@ -611,7 +664,7 @@ void pgServer::StorePassword()
 }
 
 
-int pgServer::Connect(frmMain *form, bool askPassword, const wxString &pwd, bool forceStorePassword)
+int pgServer::Connect(frmMain *form, bool askPassword, const wxString &pwd, bool forceStorePassword, bool askTunnelPassword)
 {
 	wxLogInfo(wxT("Attempting to create a connection object..."));
 
@@ -626,13 +679,18 @@ int pgServer::Connect(frmMain *form, bool askPassword, const wxString &pwd, bool
 		}
 		if (askPassword)
 		{
-			if (!passwordValid || !GetPasswordIsStored() || !GetStorePwd())
+			if (sshTunnel || !passwordValid || !GetPasswordIsStored() || !GetStorePwd())
 			{
 				wxString txt;
 				txt.Printf(_("Please enter password for user %s\non server %s (%s)"), username.c_str(), description.c_str(), GetName().c_str());
-				dlgConnect dlg(form, txt, GetStorePwd());
+				dlgConnect *dlg = NULL;
+				// if sshTunnel is true then we have to hide 'Stored Password' option
+				if(sshTunnel)
+					dlg = new dlgConnect(NULL, txt, false);
+				else
+					dlg = new dlgConnect(form, txt, GetStorePwd());
 
-				switch (dlg.Go())
+				switch (dlg->Go())
 				{
 					case wxID_OK:
 						// Give the UI a chance to redraw
@@ -656,9 +714,14 @@ int pgServer::Connect(frmMain *form, bool askPassword, const wxString &pwd, bool
 						return PGCONN_BAD;
 				}
 
-				iSetStorePwd(dlg.GetStorePwd());
-				password = dlg.GetPassword();
+				iSetStorePwd(dlg->GetStorePwd());
+				password = dlg->GetPassword();
 				storePassword = true;
+				if(dlg)
+				{
+					delete dlg;
+					dlg = NULL;
+				}
 			}
 		}
 		else
@@ -666,23 +729,82 @@ int pgServer::Connect(frmMain *form, bool askPassword, const wxString &pwd, bool
 
 		form->StartMsg(_("Connecting to database"));
 
+		wxString host;
+		int iPort;
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+		if(sshTunnel)
+		{
+			//Ask Tunnel Password
+			if(askTunnelPassword)
+			{
+				wxString txt;
+				if(GetAuthModePwd())
+				{
+					txt.Printf(_("Please enter the SSH tunnel password for user %s\non server %s"), tunnelUserName.c_str(), tunnelHost.c_str());
+				}
+				else
+				{
+					txt.Printf(_("Please enter the pass phrase for the identity file\n%s"), identityFile.c_str());
+				}
+				dlgConnect dlg(NULL, txt, false);
+
+				switch (dlg.Go())
+				{
+					case wxID_OK:
+						// Give the UI a chance to redraw
+						wxSafeYield();
+						wxMilliSleep(100);
+						wxSafeYield();
+						tunnelPassword = dlg.GetPassword();
+						break;
+					case wxID_CANCEL:
+					case -1:
+					default:
+						// Give the UI a chance to redraw
+						wxSafeYield();
+						wxMilliSleep(100);
+						wxSafeYield();
+						form->EndMsg(false);
+						return PGCONN_ABORTED;
+				}
+			}
+			// Create SSH Tunnel if required
+			if(!tunnelObj)
+			{
+				if(!createSSHTunnel())
+				{
+					form->EndMsg(false);
+					return PGCONN_ABORTED;
+				}
+			}
+
+			host = local_listenhost;
+			iPort = local_listenport;
+		}
+		else
+#endif
+		{
+			host = GetName();
+			iPort = port;
+		}
+
 		if (database.IsEmpty())
 		{
-			conn = new pgConn(GetName(), service, hostaddr, DEFAULT_PG_DATABASE, username, password, port, rolename, ssl, 0, appearanceFactory->GetLongAppName() + _(" - Browser"), sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
+			conn = new pgConn(host, service, hostaddr, DEFAULT_PG_DATABASE, username, password, iPort, rolename, ssl, 0, appearanceFactory->GetLongAppName() + _(" - Browser"), sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
 			if (conn->GetStatus() == PGCONN_OK)
 				database = DEFAULT_PG_DATABASE;
 			else if (conn->GetStatus() == PGCONN_BAD && conn->GetLastError().Find(
 			             wxT("database \"") DEFAULT_PG_DATABASE wxT("\" does not exist")) >= 0)
 			{
 				delete conn;
-				conn = new pgConn(GetName(), service, hostaddr, wxT("template1"), username, password, port, rolename, ssl, 0, appearanceFactory->GetLongAppName() + _(" - Browser"), sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
+				conn = new pgConn(host, service, hostaddr, wxT("template1"), username, password, iPort, rolename, ssl, 0, appearanceFactory->GetLongAppName() + _(" - Browser"), sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
 				if (conn && conn->GetStatus() == PGCONN_OK)
 					database = wxT("template1");
 			}
 		}
 		else
 		{
-			conn = new pgConn(GetName(), service, hostaddr, database, username, password, port, rolename, ssl, 0, appearanceFactory->GetLongAppName() + _(" - Browser"), sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
+			conn = new pgConn(host, service, hostaddr, database, username, password, iPort, rolename, ssl, 0, appearanceFactory->GetLongAppName() + _(" - Browser"), sslcert, sslkey, sslrootcert, sslcrl, sslcompression);
 			if (!conn)
 			{
 				form->EndMsg(false);
@@ -1008,7 +1130,7 @@ void pgServer::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prop
 				properties->AppendItem(_("Port"), wxEmptyString);
 			else
 				properties->AppendItem(_("Port"), (long)GetPort());
-#ifdef SSL
+#ifdef PG_SSL
 			if (GetConnected())
 			{
 				properties->AppendItem(_("Encryption"),
@@ -1057,6 +1179,7 @@ void pgServer::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prop
 		properties->AppendItem(_("Username"), GetUsername());
 		if (!GetRolename().IsEmpty())
 			properties->AppendItem(_("Default role"), GetRolename());
+
 		properties->AppendYesNoItem(_("Store password?"), GetStorePwd());
 		properties->AppendYesNoItem(_("Restore environment?"), GetRestore());
 		if (GetConnected())
@@ -1105,6 +1228,49 @@ void pgServer::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prop
 	}
 }
 
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+
+bool pgServer::createSSHTunnel()
+{
+	bool retVal = false;
+
+	tunnelObj = new CSSHTunnelThread(tunnelHost, GetName(), port, tunnelUserName, tunnelPassword, publicKeyFile,
+	                                 identityFile, authModePwd ? AUTH_PASSWORD : AUTH_PUBLICKEY);
+
+	if(tunnelObj)
+	{
+		if(tunnelObj->Initialize())
+		{
+			if ( tunnelObj->Create() != wxTHREAD_NO_ERROR )
+			{
+				delete tunnelObj;
+				tunnelObj = NULL;
+				wxLogError(_("SSH Error: Unable to create SSH Tunnling Thread"));
+			}
+			else
+			{
+				if (tunnelObj->Run() != wxTHREAD_NO_ERROR )
+				{
+					delete tunnelObj;
+					tunnelObj = NULL;
+					wxLogError(_("SSH Error: Unable to start SSH Tunnling Thread"));
+				}
+
+				SetLocalListenHost(tunnelObj->GetLocalListenIP());
+				SetLocalListenPort(tunnelObj->GetLocalListenPort());
+				retVal = true;
+			}
+		}
+		else
+		{
+			delete tunnelObj;
+			tunnelObj = NULL;
+		}
+	}
+
+	return retVal;
+}
+#endif
 
 void pgServer::ShowStatistics(frmMain *form, ctlListView *statistics)
 {
@@ -1216,7 +1382,6 @@ bool pgServer::AddNamedRestorePoint()
 	return false;
 }
 
-
 pgServerCollection::pgServerCollection(pgaFactory *factory)
 	: pgCollection(factory)
 {
@@ -1289,6 +1454,10 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
 	wxString key, servername, hostaddr, description, service, database, username, lastDatabase, lastSchema;
 	wxString storePwd, rolename, restore, serviceID, discoveryID, dbRestriction, colour;
 	wxString group, sslcert, sslkey, sslrootcert, sslcrl, sslcompression;
+
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+	wxString sshTunnel, authModePwd, tunnelHost, tunnelUserName, tunnelPassword, publicKeyFile, identityFile;
+#endif
 	pgServer *server = 0;
 
 	wxArrayString discoveredServers;
@@ -1327,7 +1496,14 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
 		settings->Read(key + wxT("SSLRootCert"), &sslrootcert, wxEmptyString);
 		settings->Read(key + wxT("SSLCrl"), &sslcrl, wxEmptyString);
 		settings->Read(key + wxT("SSLCompression"), &sslcompression, wxT("true"));
-
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+		settings->Read(key + wxT("SSHTunnel"), &sshTunnel, wxT("false"));
+		settings->Read(key + wxT("TunnelHost"), &tunnelHost, wxEmptyString);
+		settings->Read(key + wxT("TunnelUserName"), &tunnelUserName, wxEmptyString);
+		settings->Read(key + wxT("TunnelModePwd"), &authModePwd, wxT("true"));
+		settings->Read(key + wxT("PublicKeyFile"), &publicKeyFile, wxEmptyString);
+		settings->Read(key + wxT("IdentityFile"), &identityFile, wxEmptyString);
+#endif
 		// Sanitize the colour
 		colour = colour.Trim();
 
@@ -1350,7 +1526,7 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
 		}
 
 		// SSL mode
-#ifdef SSL
+#ifdef PG_SSL
 		settings->Read(key + wxT("SSL"), &ssl, 0);
 #endif
 
@@ -1361,7 +1537,13 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
 		}
 
 		// Add the Server node
-		server = new pgServer(servername, hostaddr, description, service, database, username, port, StrToBool(storePwd), rolename, StrToBool(restore), ssl);
+#if defined(HAVE_OPENSSL_CRYPTO) || defined(HAVE_GCRYPT)
+		server = new pgServer(servername, hostaddr, description, service, database, username, port, StrToBool(storePwd), rolename, StrToBool(restore), ssl,
+		                      colour, group, StrToBool(sshTunnel), tunnelHost, tunnelUserName, StrToBool(authModePwd), tunnelPassword, publicKeyFile, identityFile);
+#else
+		server = new pgServer(servername, hostaddr, description, service, database, username, port, StrToBool(storePwd), rolename, StrToBool(restore), ssl,
+		                      colour, group);
+#endif
 		server->iSetLastDatabase(lastDatabase);
 		server->iSetLastSchema(lastSchema);
 		server->iSetService(service);
@@ -1369,8 +1551,6 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
 		server->iSetDiscoveryID(discoveryID);
 		server->iSetDiscovered(false);
 		server->iSetDbRestriction(dbRestriction);
-		server->iSetColour(colour);
-		server->iSetGroup(group);
 		server->iSetServerIndex(loop);
 		server->SetSSLCert(sslcert);
 		server->SetSSLKey(sslkey);
diff --git a/pgadmin/ui/dlgServer.xrc b/pgadmin/ui/dlgServer.xrc
index c0bbd77..60f5ef5 100644
--- a/pgadmin/ui/dlgServer.xrc
+++ b/pgadmin/ui/dlgServer.xrc
@@ -257,6 +257,130 @@
             </object>
           </object>
           <object class="notebookpage">
+            <label>SSH Tunnel</label>
+            <object class="wxPanel" name="pnlSSH">
+              <object class="wxFlexGridSizer">
+                <cols>2</cols>
+                <vgap>5</vgap>
+                <hgap>5</hgap>
+                <growablecols>1</growablecols>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stSSHTunnel">
+                    <label>Use SSH tunneling</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxCheckBox" name="chkSSHTunnel">
+                    <label></label>
+                    <checked>0</checked>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stTunnelHost">
+                    <label>Tunnel host</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxTextCtrl" name="txtTunnelHost"/>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stTunnelUsername">
+                    <label>Username</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxTextCtrl" name="txtTunnelUsername"/>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stAuthentication">
+                    <label>Authentication</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFlexGridSizer">
+                    <cols>2</cols>
+                    <vgap>10</vgap>
+                    <hgap>10</hgap>
+                    <growablecols>1</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxRadioButton" name="radioBtnPassword">
+                        <label>Password</label>
+                        <style>wxRB_GROUP</style>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL</flag>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxRadioButton" name="radioBtnKeyfile">
+                        <label>Identity file</label>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL</flag>
+                    </object>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stIdentityFile">
+                    <label>Identity file</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFilePickerCtrl" name="pickerIdentityFile">
+                    <message>Select identity file</message>
+                    <wildcard>*</wildcard>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stPublicKeyFile">
+                    <label>Public key</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFilePickerCtrl" name="pickerPublicKeyFile">
+                    <message>Select public key file</message>
+                    <wildcard>*.pub</wildcard>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTER_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stTunnelPassword">
+                    <label>Password/Passphrase</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxTextCtrl" name="txtTunnelPassword">
+                    <style>wxTE_PASSWORD</style>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+              </object>
+            </object>
+          </object>
+          <object class="notebookpage">
             <label>Advanced</label>
             <object class="wxPanel" name="pnlOptional">
               <object class="wxFlexGridSizer">
diff --git a/pgadmin/ui/xrcDialogs.cpp b/pgadmin/ui/xrcDialogs.cpp
index 9d92349..4a09d7f 100644
--- a/pgadmin/ui/xrcDialogs.cpp
+++ b/pgadmin/ui/xrcDialogs.cpp
@@ -20529,7 +20529,7 @@ static unsigned char xml_res_file_52[] = {
 32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,101,99,116,
 62,10,60,47,114,101,115,111,117,114,99,101,62,10};
 
-static size_t xml_res_size_53 = 17391;
+static size_t xml_res_size_53 = 23179;
 static unsigned char xml_res_file_53[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -21069,74 +21069,60 @@ static unsigned char xml_res_file_53[] = {
 10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
 34,110,111,116,101,98,111,111,107,112,97,103,101,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,60,108,97,98,101,108,62,65,100,118,97,110,99,101,100,
-60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,80,97,110,101,108,
-34,32,110,97,109,101,61,34,112,110,108,79,112,116,105,111,110,97,108,34,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,
-122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-99,111,108,115,62,50,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,
-53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,103,114,111,119,97,98,108,101,114,111,119,115,62,52,60,47,103,
-114,111,119,97,98,108,101,114,111,119,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,
-62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,
-32,110,97,109,101,61,34,115,116,72,111,115,116,65,100,100,114,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,
-101,108,62,72,111,115,116,32,65,100,100,114,101,115,115,60,47,108,97,98,
-101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,
-82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,
-70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,
-52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,108,97,98,101,108,62,83,83,72,32,84,117,110,110,
+101,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,80,97,110,
+101,108,34,32,110,97,109,101,61,34,112,110,108,83,83,72,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,
+115,62,50,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,
+103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,
+114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,111,119,97,
+98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,
+101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,
+116,83,83,72,84,117,110,110,101,108,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,85,115,101,32,
+83,83,72,32,116,117,110,110,101,108,105,110,103,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,
+98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,
-34,116,120,116,72,111,115,116,65,100,100,114,34,47,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,
-88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,
-82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
-120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
-114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
-84,114,121,67,111,110,110,101,99,116,34,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,67,111,110,110,
-101,99,116,32,110,111,119,60,47,108,97,98,101,108,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,
-76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
-84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,
-101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,
-99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,84,114,121,67,111,
-110,110,101,99,116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,108,97,98,101,108,47,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,101,100,62,49,60,
-47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,
-65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,
+34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,
+107,83,83,72,84,117,110,110,101,108,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,47,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,
+101,100,62,48,60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
+120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,
+98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,
+34,115,116,84,117,110,110,101,108,72,111,115,116,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,84,
+117,110,110,101,108,32,104,111,115,116,60,47,108,97,98,101,108,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,
 73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,
 73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
@@ -21144,13 +21130,52 @@ static unsigned char xml_res_file_53[] = {
 98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
 105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,
-97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,82,101,
-115,116,111,114,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,108,97,98,101,108,62,82,101,115,116,111,114,101,32,
-101,110,118,63,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,
+120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,84,117,110,
+110,101,108,72,111,115,116,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,
+99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,84,117,110,110,101,
+108,85,115,101,114,110,97,109,101,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,85,115,101,114,110,
+97,109,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,
+76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,
+84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,
+32,110,97,109,101,61,34,116,120,116,84,117,110,110,101,108,85,115,101,114,
+110,97,109,101,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,
+76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,
+84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,
+116,34,32,110,97,109,101,61,34,115,116,65,117,116,104,101,110,116,105,99,
+97,116,105,111,110,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,108,97,98,101,108,62,65,117,116,104,101,110,116,105,99,
+97,116,105,111,110,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
 65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
 120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
 108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
@@ -21159,55 +21184,95 @@ static unsigned char xml_res_file_53[] = {
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
 116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,
-120,34,32,110,97,109,101,61,34,99,104,107,82,101,115,116,111,114,101,34,
+101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,
+100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,47,99,111,108,115,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,
+97,112,62,49,48,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,49,48,60,47,104,103,
+97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,111,
+119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,119,120,82,97,100,105,111,66,117,116,116,111,110,
+34,32,110,97,109,101,61,34,114,97,100,105,111,66,116,110,80,97,115,115,
+119,111,114,100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,80,97,115,115,119,111,114,
+100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,82,66,
+95,71,82,79,85,80,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,
+78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,60,47,102,108,97,103,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,82,97,100,105,111,66,117,116,116,111,110,34,32,
+110,97,109,101,61,34,114,97,100,105,111,66,116,110,75,101,121,102,105,108,
+101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,73,100,101,110,116,105,116,121,32,102,
+105,108,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,69,82,95,86,69,82,84,73,67,65,76,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,
+84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,
+109,101,61,34,115,116,73,100,101,110,116,105,116,121,70,105,108,101,34,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
-97,98,101,108,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,99,104,101,99,107,101,100,62,49,60,47,99,104,101,99,107,
-101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
-120,116,34,32,110,97,109,101,61,34,115,116,82,111,108,101,110,97,109,101,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-108,97,98,101,108,62,82,111,108,101,110,97,109,101,60,47,108,97,98,101,
-108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,
-95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,
-124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,
-47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+97,98,101,108,62,73,100,101,110,116,105,116,121,32,102,105,108,101,60,47,
+108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,
+69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,70,105,108,101,80,105,99,107,101,114,67,116,114,
+108,34,32,110,97,109,101,61,34,112,105,99,107,101,114,73,100,101,110,116,
+105,116,121,70,105,108,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,109,101,115,115,97,103,101,62,83,101,108,101,
+99,116,32,105,100,101,110,116,105,116,121,32,102,105,108,101,60,47,109,
+101,115,115,97,103,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,119,105,108,100,99,97,114,100,62,42,60,47,119,105,
+108,100,99,97,114,100,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,
-120,116,82,111,108,101,110,97,109,101,34,47,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,
-65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,
-73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,
-73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
-105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,
-97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,68,98,82,
-101,115,116,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,108,97,98,101,108,62,68,66,32,114,101,115,116,114,105,99,
-116,105,111,110,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,
+124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,
+76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,
+101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,
+105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,80,117,98,108,
+105,99,75,101,121,70,105,108,101,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,80,117,98,108,105,
+99,32,107,101,121,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
 65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
 120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
 108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
@@ -21216,114 +21281,312 @@ static unsigned char xml_res_file_53[] = {
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
 116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,
-108,34,32,110,97,109,101,61,34,116,120,116,68,98,82,101,115,116,114,105,
-99,116,105,111,110,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,69,95,77,85,76,84,73,
-76,73,78,69,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
-69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
-69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
-120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
-114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
-83,101,114,118,105,99,101,73,68,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,83,101,114,118,105,
-99,101,32,73,68,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
-120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
-105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,
-120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,83,101,114,
-118,105,99,101,73,68,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
-120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
-68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,124,119,120,65,76,76,
-60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
-114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+101,99,116,32,99,108,97,115,115,61,34,119,120,70,105,108,101,80,105,99,
+107,101,114,67,116,114,108,34,32,110,97,109,101,61,34,112,105,99,107,101,
+114,80,117,98,108,105,99,75,101,121,70,105,108,101,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,109,101,115,115,97,103,
+101,62,83,101,108,101,99,116,32,112,117,98,108,105,99,32,107,101,121,32,
+102,105,108,101,60,47,109,101,115,115,97,103,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,119,105,108,100,99,97,114,
+100,62,42,46,112,117,98,60,47,119,105,108,100,99,97,114,100,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,
+69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,
+97,109,101,61,34,115,116,84,117,110,110,101,108,80,97,115,115,119,111,114,
+100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,108,97,98,101,108,62,80,97,115,115,119,111,114,100,47,80,97,115,115,
+112,104,114,97,115,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,
+116,114,108,34,32,110,97,109,101,61,34,116,120,116,84,117,110,110,101,108,
+80,97,115,115,119,111,114,100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,69,95,80,
+65,83,83,87,79,82,68,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,
+69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
+60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,110,111,116,101,98,111,111,
+107,112,97,103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
+97,98,101,108,62,65,100,118,97,110,99,101,100,60,47,108,97,98,101,108,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,80,97,110,101,108,34,32,110,97,109,101,61,34,112,
+110,108,79,112,116,105,111,110,97,108,34,62,10,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
 120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,
-32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,99,111,108,115,62,10,
-32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,
-115,62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,47,99,
+111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,
+103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,
+108,101,114,111,119,115,62,52,60,47,103,114,111,119,97,98,108,101,114,111,
+119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,
+111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,111,119,97,98,
+108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,
-76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
-108,62,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,
-32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
+72,111,115,116,65,100,100,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,72,111,115,116,32,65,
+100,100,114,101,115,115,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,
+116,114,108,34,32,110,97,109,101,61,34,116,120,116,72,111,115,116,65,100,
+100,114,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,
+71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,
+80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,
+103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,
+114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,
+34,32,110,97,109,101,61,34,115,116,84,114,121,67,111,110,110,101,99,116,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+108,97,98,101,108,62,67,111,110,110,101,99,116,32,110,111,119,60,47,108,
+97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,
+61,34,99,104,107,84,114,121,67,111,110,110,101,99,116,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
+47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+99,104,101,99,107,101,100,62,49,60,47,99,104,101,99,107,101,100,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,
+69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,
+97,109,101,61,34,115,116,82,101,115,116,111,114,101,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,
+82,101,115,116,111,114,101,32,101,110,118,63,60,47,108,97,98,101,108,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
+69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
+120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
+114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,82,101,
+115,116,111,114,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,108,97,98,101,108,47,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,101,100,62,49,
+60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
+80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,
+84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,
+82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,
+100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
+82,111,108,101,110,97,109,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,82,111,108,101,110,97,
+109,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,
+73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,
+79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,
+32,110,97,109,101,61,34,116,120,116,82,111,108,101,110,97,109,101,34,47,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,
+109,101,61,34,115,116,68,98,82,101,115,116,114,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,68,
+66,32,114,101,115,116,114,105,99,116,105,111,110,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,
+98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-112,97,99,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,
-122,101,62,48,44,48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,
+120,116,68,98,82,101,115,116,114,105,99,116,105,111,110,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,
+101,62,119,120,84,69,95,77,85,76,84,73,76,73,78,69,60,47,115,116,121,108,
+101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,
+73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,
+79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,
+116,34,32,110,97,109,101,61,34,115,116,83,101,114,118,105,99,101,73,68,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+108,97,98,101,108,62,83,101,114,118,105,99,101,32,73,68,60,47,108,97,98,
+101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,
+82,69,95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,
+103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,
+114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,
+110,97,109,101,61,34,116,120,116,83,101,114,118,105,99,101,73,68,34,47,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
+102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,
+95,67,69,78,84,82,69,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,
+122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,
+105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,99,
+111,108,115,62,52,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,
+32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,
+111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,
 60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
 105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
 106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,
-34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,
-79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,100,101,102,97,117,108,116,62,49,60,47,100,101,102,97,117,108,
-116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,76,80,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,72,101,108,
+112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,76,60,47,102,
+108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,
+101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,
+111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,112,97,99,101,114,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,48,44,
+48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,
+101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,79,75,60,47,108,97,
+98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,100,101,102,
+97,117,108,116,62,49,60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
+119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,67,65,
+78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
+98,101,108,62,38,97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,
+108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
 69,88,80,65,78,68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,
 111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
-34,119,120,73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,67,97,110,99,
-101,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,76,60,
-47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
-100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,69,88,80,65,78,68,124,119,120,84,79,80,124,119,120,76,69,70,
-84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,
-99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
-62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,83,116,97,116,117,115,66,97,114,34,32,110,97,109,101,
-61,34,117,110,107,83,116,97,116,117,115,66,97,114,34,62,10,32,32,32,32,
-32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,83,84,95,83,73,90,69,
-71,82,73,80,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
-82,69,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,
-100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-60,47,111,98,106,101,99,116,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
-62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,
-114,99,101,62,10};
+101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
+68,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,
+116,117,115,66,97,114,34,32,110,97,109,101,61,34,117,110,107,83,116,97,
+116,117,115,66,97,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,115,116,
+121,108,101,62,119,120,83,84,95,83,73,90,69,71,82,73,80,60,47,115,116,121,
+108,101,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,
+124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,60,47,102,108,97,103,62,
+10,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,
+114,100,101,114,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,
+101,99,116,62,10,60,47,114,101,115,111,117,114,99,101,62,10};
 
 static size_t xml_res_size_54 = 10963;
 static unsigned char xml_res_file_54[] = {
diff --git a/pgadmin/utils/module.mk b/pgadmin/utils/module.mk
index c307647..45193f6 100644
--- a/pgadmin/utils/module.mk
+++ b/pgadmin/utils/module.mk
@@ -23,6 +23,11 @@ pgadmin3_SOURCES += \
 	utils/utffile.cpp \
 	utils/macros.cpp
 
+if BUILD_SSH_TUNNEL
+pgadmin3_SOURCES += \
+	utils/sshTunnel.cpp
+endif
+
 EXTRA_DIST += \
 	utils/module.mk \
 	utils/tab-complete.inc \